(function ($) {
    'use strict';

    var factora = factora || {};

    factora.init = function () {
        factora.$body = $(document.body),
            factora.$window = $(window),
            factora.$header = $('#masthead');
        this.imagesCarousel();
        this.portfolioCarousel();
        this.imageBoxCarousel();
        this.portfolioMasonry();
        this.portfolioGrid();
        this.toggleFaq();
        this.mapBox();
        this.partnerCarousel();
        this.teamCarousel();
        this.iconBoxCarousel();
        this.factoraCounter();
        this.testimonialCarousel();
        this.testimonialCarousel2();
        this.iconScoll();

    };
    factora.imagesCarousel = function () {
        if (factoraShortCode.length === 0 || typeof factoraShortCode.imagesCarousel === 'undefined') {
            return;
        }

        $.each(factoraShortCode.imagesCarousel, function (id, imagesData) {

            var $sliders = $(document.getElementById(id));
            $sliders.not('.slick-initialized').slick({
                infinite: true,
                arrows: imagesData.nav,
                autoplay: imagesData.autoplay,
                autoplaySpeed: imagesData.speed,
                dots: false,
                prevArrow: '<div class="slide-arrow slide-button-prev"><i class="arrow_carrot-left"></i></div>',
                nextArrow: '<div class="slide-arrow slide-button-next"><i class="arrow_carrot-right"></i></div>',
                slidesToShow: imagesData.columns,
            });
        });
    };

    factora.portfolioCarousel = function () {
        $.each(factoraShortCode.portfolioCarousel, function (id, imagesData) {
            var $sliders = $(document.getElementById(id)),
                width = $(window).width(),
                centerPadding = (width - 1220) / 2;

            $sliders.not('.slick-initialized').slick({
                centerMode: imagesData.centerMode,
                slidesToShow: parseInt(imagesData.slidesToShow),
                slidesToScroll: parseInt(imagesData.slidesToShow),
                arrows: imagesData.nav,
                dots: imagesData.dots,
                centerPadding: centerPadding.toString() + 'px',
                autoplay: imagesData.autoplay,
                prevArrow: imagesData.prevArrow,
                nextArrow: imagesData.nextArrow,
                responsive: [
                    {
                        breakpoint: 1200,
                        settings: {
                            centerMode: false,
                            arrows: false,
                            dots: true,
                            slidesToShow: 2,
                            slidesToScroll: 1,
                        }
                    },
                    {
                        breakpoint: 768,
                        settings: {
                            centerMode: false,
                            arrows: false,
                            dots: true,
                            slidesToShow: 2,
                            slidesToScroll: 1,
                        }
                    },
	                {
		                breakpoint: 480,
		                settings: {
			                centerMode: false,
			                arrows: false,
			                dots: true,
			                slidesToShow: 1,
			                slidesToScroll: 1,
		                }
	                }
                ]
            });
        });
    };

    factora.imageBoxCarousel = function () {
        $.each(factoraShortCode.imageBoxCarousel, function (id, imagesData) {
            var $sliders = $(document.getElementById(id));

            $sliders.not('.slick-initialized').slick({
                slidesToShow: parseInt(imagesData.slidesToShow),
                slidesToScroll: parseInt(imagesData.slidesToShow),
                arrows:  false,
                dots: imagesData.dots,
                autoplay: imagesData.autoplay,
                prevArrow: imagesData.prevArrow,
                nextArrow: imagesData.nextArrow,
                responsive: [
                    {
                        breakpoint: 1200,
                        settings: {
                            arrows: false,
                            dots: true
                        }
                    },
                    {
                        breakpoint: 768,
                        settings: {
                            arrows: false,
                            dots: true,
                            slidesToShow: 2,
                            slidesToScroll: 1,
                        }
                    },
                    {
                        breakpoint: 500,
                        settings: {
                            arrows: false,
                            dots: true,
                            slidesToShow: 1,
                            slidesToScroll: 1,
                        }
                    }
                ]
            });
        });
    };

    factora.portfolioMasonry = function () {
        factora.$body.imagesLoaded(function () {
            factora.$body.find('.factora-portfolio-masonry .list-items').isotope({
                itemSelector: '.portfolio-item',
                layoutMode: 'masonry',
                masonry: {
                    columnWidth: '.grid-sizer'
                }
            });

        });
    };

    factora.portfolioGrid = function () {

        var $portfolioList = $('.factora_portfolio_grid'),
            options = {
                itemSelector: '.portfolio-wrapper',
                layoutMode: 'fitRows',
            };

        $portfolioList.imagesLoaded(function () {
            $portfolioList.isotope(options);
        });


        $('.portfolio-cats-filters').on('click', '.button', function () {
            var filterValue = $(this).attr('data-filter');

            $portfolioList.isotope({filter: filterValue});
        });

        $('.button-group').each(function (i, buttonGroup) {
            var $buttonGroup = $(buttonGroup);
            $buttonGroup.on('click', 'span', function () {
                $buttonGroup.find('.active').removeClass('active');
                $(this).addClass('active');
            });
        });

        if (factora.$body.hasClass('portfolio_full-width')) {
            $('#filters').addClass('container');
        }

        // Blog page
        factora.$body.on('click', '.factora-portfolio-shortcode .numeric-navigation .next', function (e) {
            e.preventDefault();

            if ($(this).data('requestRunning')) {
                return;
            }

            $(this).data('requestRunning', true);

            var $postList = $('.factora-portfolio-shortcode .factora_portfolio_grid'),
                $pagination = $(this).parents('.navigation'),
                $parent = $(this).parent();

            $parent.addClass('loader');

            $.get(
                $(this).attr('href'),
                function (response) {
                    var $content = $(response).find('#factora_portfolio_grid').children('.portfolio-wrapper'),
                        pagination_html = $(response).find('.navigation').html();

                    $pagination.html(pagination_html);

                    $postList.append($content);

                    $content.imagesLoaded(function () {
                        $postList.isotope('appended', $content);
                        $pagination.find('.next').data('requestRunning', false);
                        $parent.removeClass('loader');
                    });
                }
            );
        });

    };

    factora.toggleFaq = function () {

        if ($('div').hasClass('factora-faq')) {
            var active = $('.factora-faq').data('active');

            $('.factora-faq__box:nth-child( ' + active + ' )').addClass('active');

            $('.factora-faq__box.active .factora-faq__answer').slideDown();

            $('.factora-faq__question').on('click', function (e) {
                e.preventDefault();

                var $this = $(this),
                    $parent = $this.closest('.factora-faq__box');

                if ($parent.hasClass('active')) {
                    return;
                }

                $parent.addClass('active');
                $parent.find('.factora-faq__answer').slideDown();
                $parent.siblings('.factora-faq__box').removeClass('active');
                $parent.siblings('.factora-faq__box').find('.factora-faq__answer').slideUp();
            });
        }
        else {
            return false;
        }
    };

    factora.mapBox = function () {
        if (factoraShortCode.length === 0 || typeof factoraShortCode.mapBox === 'undefined') {
            return;
        }

        $.each(factoraShortCode.mapBox, function (id, imagesData) {

            var wrapper = $(document.getElementById(id));

            if (wrapper.hasClass('factora-map')) {
                mapboxgl.accessToken = imagesData.token;

                var mapboxClient = mapboxSdk({accessToken: mapboxgl.accessToken}),
                    local = imagesData.local;

                mapboxClient.geocoding.forwardGeocode({
                    query: local,
                    autocomplete: false,
                    limit: 1
                })
                    .send()
                    .then(function (response) {
                        if (response && response.body && response.body.features && response.body.features.length) {
                            var feature = response.body.features[0];

                            var map = new mapboxgl.Map({
                                container: 'map',
                                style: 'mapbox://styles/mapbox/light-v9',
                                center: feature.center,
                                zoom: imagesData.zom
                            });
                            map.on('load', function () {
                                map.loadImage(imagesData.marker, function (error, image) {
                                    if (error) throw error;
                                    map.addImage('marker', image);
                                    map.addLayer({
                                        "id": "points",
                                        "type": "symbol",
                                        "source": {
                                            "type": "geojson",
                                            "data": {
                                                "type": "FeatureCollection",
                                                "features": [{
                                                    "type": "Feature",
                                                    "geometry": {
                                                        "type": "Point",
                                                        "coordinates": feature.center
                                                    }
                                                }]
                                            }
                                        },
                                        "layout": {
                                            "icon-image": "marker",
                                            "icon-size": 1
                                        }
                                    });
                                });
                            });

                            var geocoder = new MapboxGeocoder({
                                accessToken: mapboxgl.accessToken
                            });

                            map.addControl(geocoder);

                            // After the map style has loaded on the page, add a source layer and default
                            // styling for a single point.
                            map.on('load', function () {
                                map.addSource('single-point', {
                                    "type": "geojson",
                                    "data": {
                                        "type": "FeatureCollection",
                                        "features": []
                                    }
                                });

                                map.addLayer({
                                    "id": "point",
                                    "source": "single-point",
                                    "type": "circle",
                                    "paint": {
                                        "circle-radius": 10,
                                        "circle-color": "#007cbf"
                                    }
                                });

                                map.setPaintProperty('water', 'fill-color', imagesData.color_1);
                                map.setPaintProperty('building', 'fill-color', imagesData.color_2);

                                map.addControl(new mapboxgl.NavigationControl());
                                // Listen for the `result` event from the MapboxGeocoder that is triggered when a user
                                // makes a selection and add a symbol that matches the result.
                                geocoder.on('result', function (ev) {
                                    map.getSource('single-point').setData(ev.result.geometry);
                                });
                            });
                        }
                    });
            }
        });
    };

    factora.partnerCarousel = function () {
        if (factoraShortCode.length === 0 || typeof factoraShortCode.partnerCarousel === 'undefined') {
            return;
        }

        $.each(factoraShortCode.partnerCarousel, function (id, imagesData) {

            var $sliders = $(document.getElementById(id));
            $sliders.not('.slick-initialized').slick({
                infinite: true,
                arrows: imagesData.nav,
                autoplay: imagesData.autoplay,
                autoplaySpeed: imagesData.speed,
                prevArrow: '<div class="slide-arrow slide-button-prev"><i class="arrow_carrot-left"></i></div>',
                nextArrow: '<div class="slide-arrow slide-button-next"><i class="arrow_carrot-right"></i></div>',
                slidesToShow: parseInt(imagesData.columns),
                slidesToScroll: parseInt(imagesData.columns),

            });
        });
    };

    factora.iconBoxCarousel = function () {
        if (factoraShortCode.length === 0 || typeof factoraShortCode.iconBoxCarousel === 'undefined') {
            return;
        }

        $.each(factoraShortCode.iconBoxCarousel, function (id, imagesData) {

            var $sliders = $(document.getElementById(id));
            $sliders.not('.slick-initialized').slick({
                infinite: true,
                slidesToShow: 1,
                arrows: false,
                slidesToScroll: 1,

            });
        });
    };

    factora.teamCarousel = function () {
        $.each(factoraShortCode.teamCarousel, function (id, slideData) {
            var $sliders = $(document.getElementById(id));

            $sliders.not('.slick-initialized').slick({
                slidesToShow: parseInt(slideData.slidesToShow),
                slidesToScroll: parseInt(slideData.slidesToShow),
                arrows: slideData.nav,
                dots: slideData.dots,
                autoplay: slideData.autoplay,
                prevArrow: slideData.prevArrow,
                nextArrow: slideData.nextArrow,
                responsive: [
                    {
                        breakpoint: 1200,
                        settings: {
                            arrows: false,
                            dots: true,
                            slidesToShow: 2,
                            slidesToScroll: 1,
                        }
                    },
                    {
                        breakpoint: 768,
                        settings: {
                            arrows: false,
                            dots: true,
                            slidesToShow: 2,
                            slidesToScroll: 1,
                        }
                    },
                    {
                        breakpoint: 480,
                        settings: {
                            arrows: false,
                            dots: true,
                            slidesToShow: 1,
                            slidesToScroll: 1,
                        }
                    }
                ]
            });
        });
    };

    factora.factoraCounter = function () {
        if (factoraShortCode.length === 0 || typeof factoraShortCode.factoraCounter === 'undefined') {
            return;
        }

        $.each(factoraShortCode.factoraCounter, function (id, imagesData) {
            var wrapper = $(document.getElementById(id)),
                counter = wrapper.find('.number'),
                duaration = parseFloat(imagesData.dua);

            if (counter.length < 1 || duaration <= 0) {
                return;
            }

            duaration = duaration * 1000;
            counter.counterUp({
                delay: 10,
                time: duaration
            });
        });
    };

    factora.testimonialCarousel = function () {
        if (factoraShortCode.length === 0 || typeof factoraShortCode.testimonialCarousel === 'undefined') {
            return;
        }

        $.each(factoraShortCode.testimonialCarousel, function (id, imagesData) {
            var $sliders = $(document.getElementById(id));
            $sliders.not('.slick-initialized').slick({
                infinite: true,
                arrows: imagesData.nav,
                autoplay: imagesData.autoplay,
                autoplaySpeed: imagesData.speed,
                dots: imagesData.dot,
                cssEase: 'ease-out',
                prevArrow: imagesData.left,
                nextArrow: imagesData.right,
                slidesToShow: imagesData.perrow,
                responsive: [
                    {
                        breakpoint: 992,
                        settings: {
                            arrows: false,
                            dots: false,
                            slidesToShow: 2
                        }
                    },
                    {
                        breakpoint: 769,
                        settings: {
                            arrows: false,
                            dots: false,
                            slidesToShow: 1
                        }
                    },
                    {
                        breakpoint: 480,
                        settings: {
                            arrows: false,
                            dots: true,
                            slidesToShow: 1
                        }
                    }
                ]
            });

        });


    };

    factora.testimonialCarousel2 = function () {
        if (factoraShortCode.length === 0 || typeof factoraShortCode.testimonialCarousel2 === 'undefined') {
            return;
        }

        $.each(factoraShortCode.testimonialCarousel2, function (class_name, imagesData) {
            $('.slider-for').slick({
                slidesToShow: 1,
                slidesToScroll: 1,
                arrows: false,
                fade: true,
                asNavFor: '.slider-nav',

            });

            $('.slider-nav').slick({
                slidesToShow: imagesData.num,
                slidesToScroll: 1,
                asNavFor: '.slider-for',
                dots: false,
                focusOnSelect: true,
                swipe: false
            });

        });

    };

    factora.iconScoll = function () {
        if (factoraShortCode.length === 0 || typeof factoraShortCode.iconScoll === 'undefined') {
            return;
        }

        $.each(factoraShortCode.iconScoll, function (id, imagesData) {

            if( imagesData.count == '1' ) {
                return;
            }

            var wrapper = $(document.getElementById(id)),
                wrapperIn = wrapper.find('.wrapper-szroll');

            var controller = new ScrollMagic.Controller();

            // define movement of panels
            var wipeAnimation = new TimelineMax();

            $('.factora-icon-box--scroll .list-scroll:not(:first-child)').each(function(){
                wipeAnimation.fromTo(this, 1, {y: "100%"}, {y: "0%", ease: Linear.easeOutSine}); // in from top
            });

            // create scene to pin and link animation
            new ScrollMagic.Scene({
                triggerElement: ".wrapper-scroll",
                triggerHook: "0.22",
                duration: "200%"
                })
                .setClassToggle(".wrapper-scroll", "fix-top")
                .setPin(".wrapper-scroll")
                .setTween(wipeAnimation)
                .addTo(controller);
        });
    };
    /**
     * Document ready
     */
    $(function () {
        factora.init();
    });

})(jQuery);