<?php

/**
 * Define theme shortcodes
 *
 * @package Factora
 */
class Factora_Shortcodes {

	/**
	 * Store variables for js
	 *
	 * @var array
	 */
	public $l10n = array();

	/**
	 * Store variables for maps
	 *
	 * @var array
	 */
	public $maps = array();
	public $api_key = '';

	/**
	 * Check if WooCommerce plugin is actived or not
	 *
	 * @var bool
	 */
	private $wc_actived = false;

	/**
	 * Construction
	 *
	 * @return Factora_Shortcodes
	 */
	function __construct() {
		$this->wc_actived = function_exists( 'is_woocommerce' );

		$shortcodes = array(
			'factora_empty_space',
			'factora_section_title',
			'factora_images_carousel',
			'factora_social',
			'factora_portfolio_attribute',
			'factora_portfolio_carousel',
			'factora_portfolio_masonry',
			'factora_service_grid',
			'factora_service_icon',
			'factora_brochure',
			'factora_image_box_carousel',
			'factora_countdown',
			'factora_map',
			'factora_contact_form_7',
			'factora_button',
			'factora_latest_post',
			'factora_single_service',
			'factora_team_carousel',
			'factora_faq',
			'factora_portfolio_grid',
			'factora_partner',
			'factora_icon_box_scroll',
			'factora_icon_box',
			'factora_counter',
			'factora_testimonial_carousel',
		);

		foreach ( $shortcodes as $shortcode ) {
			add_shortcode( $shortcode, array( $this, $shortcode ) );
		}

		add_action( 'wp_footer', array( $this, 'footer' ) );
	}

	/**
	 * Get information
	 *
	 * @since  1.0.0
	 *
	 *
	 * @return string
	 */
	function factora_get_information( $id ) {
		$job       = get_post_meta( $id, 'job', true );
		$out_put[] = ! empty( $job ) ? sprintf( '<p class="job">%s</p>', $job ) : '';

		return sprintf( '<div class="info-member">%s</div>', implode( '', $out_put ) );
	}

	function factora_team_social( $id ) {

		$team_socials = get_post_meta( $id, 'social', true );

		$value = array();
		if ( $team_socials ) {
			$socials = (array) factora_get_socials();

			foreach ( $team_socials as $social ) {
				foreach ( $socials as $name => $label ) {
					$link_url = $social;
					if ( preg_match( '/' . $name . '/', $link_url ) ) {
						if ( $name == 'google' ) {
							$name = 'google-plus';
						}
						$value[] = sprintf( '<li><a href="%s" target="_blank"><i class="fa fa-%s"></i></a></li>', esc_url( $link_url ), esc_attr( $name ) );
						break;
					}
				}
			}
		}

		return sprintf( '<ul class="extra-menu-item menu-item-socials socials">%s</ul>', implode( '', $value ) );
	}

	/**
	 * Get ID number of a shortcode
	 *
	 * @param string $shortcode
	 *
	 * @return int
	 */
	protected function get_id_number( $shortcode ) {
		if ( isset( $this->ids[ $shortcode ] ) ) {
			$this->ids[ $shortcode ] ++;
		} else {
			$this->ids[ $shortcode ] = 1;
		}

		return $this->ids[ $shortcode ];
	}

	/**
	 * @param string $atts
	 *
	 * @return string
	 */
	protected function factora_font_size( $atts ) {
		$atts = preg_replace( '/\s+/', '', $atts );

		$pattern = '/^(\d*(?:\.\d+)?)\s*(px|\%|in|cm|mm|em|rem|ex|pt|pc|vw|vh|vmin|vmax)?$/';
		// allowed metrics: http://www.w3schools.com/cssref/css_units.asp
		$regexr   = preg_match( $pattern, $atts, $matches );
		$value    = isset( $matches[1] ) ? (float) $matches[1] : (float) $atts;
		$unit     = isset( $matches[2] ) ? $matches[2] : 'px';
		$fontSize = $value . $unit;

		return $fontSize;
	}

	public function footer() {
		// Load Google maps only when needed
		if ( isset( $this->l10n['map'] ) ) {
			echo '<script>if ( typeof google !== "object" || typeof google.maps !== "object" )
				document.write(\'<script src="//maps.google.com/maps/api/js?sensor=false&key=' . $this->api_key . '"><\/script>\')</script>';
		}

		wp_enqueue_script(
			'shortcodes', FACTORA_ADDONS_URL . 'assets/js/frontend.js', array(
			'jquery',
		), '20171018', true
		);

		wp_localize_script( 'shortcodes', 'factoraShortCode', $this->l10n );
	}

	/**
	 * Get empty space
	 *
	 * @since  1.0
	 *
	 * @return string
	 */
	function factora_empty_space( $atts, $content ) {
		$atts = shortcode_atts(
			array(
				'height'        => '',
				'height_mobile' => '',
				'height_tablet' => '',
				'bg_color'      => '',
				'el_class'      => '',
			), $atts
		);

		$css_class = array(
			'factora-empty-space',
			$atts['el_class'],
		);

		$style = '';

		if ( $atts['bg_color'] ) {
			$style = 'background-color:' . $atts['bg_color'] . ';';
		}

		$height = $atts['height'] ? (float) $atts['height'] : 0;

		if ( ! empty( $atts['height_tablet'] ) || $atts['height_tablet'] == '0' ) {
			$height_tablet = (float) $atts['height_tablet'];
		} else {
			$height_tablet = $height;
		}

		if ( ! empty( $atts['height_mobile'] ) || $atts['height_mobile'] == '0' ) {
			$height_mobile = (float) $atts['height_mobile'];
		} else {
			$height_mobile = $height_tablet;
		}

		$inline_css        = $height >= 0.0 ? ' style="height: ' . esc_attr( $height ) . 'px"' : '';
		$inline_css_tablet = $height_tablet >= 0.0 ? ' style="height: ' . esc_attr( $height_tablet ) . 'px"' : '';
		$inline_css_mobile = $height_mobile >= 0.0 ? ' style="height: ' . esc_attr( $height_mobile ) . 'px"' : '';

		return sprintf(
			'<div class="%s" style="%s">' .
			'<div class="factora_empty_space_lg visible-lg" %s></div>' .
			'<div class="factora_empty_space_md visible-sm visible-md" %s></div>' .
			'<div class="factora_empty_space_xs visible-xs" %s></div>' .
			'</div>',
			esc_attr( implode( ' ', $css_class ) ),
			$style,
			$inline_css,
			$inline_css_tablet,
			$inline_css_mobile
		);
	}

	/**
	 * Get limited words from given string.
	 * Strips all tags and shortcodes from string.
	 *
	 * @since 1.0.0
	 *
	 * @param integer $num_words The maximum number of words
	 * @param string  $more      More link.
	 *
	 * @return string Limited content.
	 */
	protected function factora_addons_content_limit( $content, $num_words, $more = "&hellip;" ) {
		// Strip tags and shortcodes so the content truncation count is done correctly
		$content = strip_tags( strip_shortcodes( $content ), apply_filters( 'factora_content_limit_allowed_tags', '<script>,<style>' ) );

		// Remove inline styles / scripts
		$content = trim( preg_replace( '#<(s(cript|tyle)).*?</\1>#si', '', $content ) );

		// Truncate $content to $max_char
		$content = wp_trim_words( $content, $num_words );

		if ( $more ) {
			return sprintf(
				'<div class="excerpt">%s <a href="%s" class="more-link" title="%s">%s</a></div>',
				$content,
				get_permalink(),
				sprintf( esc_html__( 'Continue reading &quot;%s&quot;', factora ), the_title_attribute( 'echo=0' ) ),
				esc_html( $more )
			);
		}

		return sprintf( '<div class="excerpt">%s</div>', $content );

	}

	/**
	 * Get vc link
	 *
	 * @param  array  $atts
	 * @param  string $content
	 *
	 * @return string
	 */
	protected function get_vc_link( $atts, $content ) {
		$attributes = array(
			'class' => 'factora-link',
		);

		$link = vc_build_link( $atts['link'] );

		if ( ! empty( $link['url'] ) ) {
			$attributes['href'] = $link['url'];
		}

		if ( ! $content ) {
			$content             = $link['title'];
			$attributes['title'] = $content;
		}

		if ( ! empty( $link['target'] ) ) {
			$attributes['target'] = $link['target'];
		}

		if ( ! empty( $link['rel'] ) ) {
			$attributes['rel'] = $link['rel'];
		}

		$attr = array();

		foreach ( $attributes as $name => $v ) {
			$attr[] = $name . '="' . esc_attr( $v ) . '"';
		}

		$button = sprintf(
			'<%1$s %2$s>%3$s</%1$s>',
			empty( $attributes['href'] ) ? 'span' : 'a',
			implode( ' ', $attr ),
			$content
		);

		return $button;
	}

	/**
	 * @param        $image
	 * @param string $size
	 *
	 * @return string
	 */

	protected function get_vc_image( $image, $size = 'thumbnail' ) {
		$image_src = '';
		if ( function_exists( 'wpb_getImageBySize' ) ) {
			$image = wpb_getImageBySize(
				array(
					'attach_id'  => $image,
					'thumb_size' => $size,
				)
			);

			if ( $image['thumbnail'] ) {
				$image_src = $image['thumbnail'];
			} elseif ( $image['p_img_large'] ) {
				$image_src = sprintf( '<img src="%s">', esc_url( $image['p_img_large'][0] ) );
			}

		}

		if ( empty( $image_src ) ) {
			$image_src = wp_get_attachment_image( $image, $size );
		}

		return $image_src;
	}


	function factora_images_carousel( $atts, $content ) {
		$atts  = shortcode_atts(
			array(
				'columns'        => '1',
				'images'         => '',
				'image_size'     => '',
				'nav'            => '',
				'autoplay'       => '',
				'autoplay_speed' => '',
				'el_class'       => '',
			), $atts
		);
		$class = array(
			'factora-images-carousel',
			$atts['el_class']
		);

		$image_ids  = explode( ',', $atts['images'] );
		$image_size = $atts['image_size'];
		$out_put    = array();
		foreach ( $image_ids as $image_id ) {
			$image     = $this->get_vc_image( $image_id, $image_size );
			$out_put[] = ! empty( $image_ids ) ? sprintf( '<li class="item">%s</li>', $image ) : '';
		}

		//Check nav
		if ( $atts['nav'] ) {
			$nav = true;
		} else {
			$nav = false;
		}
		if ( $atts['autoplay'] ) {
			$autoplay = true;
		} else {
			$autoplay = false;
		}
		$autoplay_speed = intval( $atts['autoplay_speed'] );
		$columns        = $atts['columns'];
		$nav_right      = '<div class="slide-arrow swiper-button-next"><i class="icon-chevron-right"></i></div>';
		$nav_left       = '<div class="slide-arrow swiper-button-prev"><i class="icon-chevron-left"></i></div>';

		$id                                  = uniqid( 'factora-images-carousel' );
		$this->l10n['imagesCarousel'][ $id ] = array(
			'columns'       => $columns,
			'nav'           => $nav,
			'autoplay'      => $autoplay,
			'autoplaySpeed' => $autoplay_speed,
			'right'         => $nav_right,
			'left'          => $nav_left,
		);

		return sprintf( '<div class="%s"><ul class="list-items" id="%s">%s</ul></div>', implode( ' ', $class ), $id, implode( '', $out_put ) );
	}

	function factora_portfolio_attribute( $atts, $content ) {
		$atts            = shortcode_atts(
			array(
				'attributes'       => '',
				'background_image' => '',
				'background_size'  => '',
				'el_class'         => '',
			), $atts
		);
		$css_class       = array( 'factora-portfolio-attributes', $atts['el_class'] );
		$image           = $atts['background_image'];
		$background_size = $atts['background_size'];
		$attributes      = vc_param_group_parse_atts( $atts['attributes'] );
		$outputs         = array();
		if ( ! empty( $attributes ) ) {
			foreach ( $attributes as $key => $attribute ) {
				$name  = ! empty( $attribute['name'] ) ? $attribute['name'] : '';
				$value = ! empty( $attribute['value'] ) ? $attribute['value'] : '';
				if ( ! empty( $name ) || ! empty( $value ) ) {
					$outputs[] = sprintf( '<li class="item"><span class="name">%s</span><span class="value">%s</span></li>', $name, $value );
				}
			}
		}

		$background = ! empty( $image ) ? sprintf( '<div class="background">%s</div>', $this->get_vc_image( $image, $background_size ) ) : '';

		return sprintf( '<div class="%s">%s<ul class="list-item">%s</ul></div>', implode( '', $css_class ), $background, implode( '', $outputs ) );
	}


	/**portfolio carousel
	 *
	 * @since  1.0
	 *
	 * @return string
	 */
	function factora_portfolio_carousel( $atts, $content ) {

		$atts = shortcode_atts(
			array(
				'style'           => '1',
				'posts_per_page'  => '12',
				'source'          => '1',
				'orderby'         => 'none',
				'order'           => 'DESC',
				'list_id'         => '',
				'excerpt_content' => '11',
				'columns'         => '4',
				'nav'             => '',
				'dots'            => '',
				'autoplay'        => '',
				'el_class'        => '',
			), $atts
		);

		$style          = $atts['style'];
		$el_class       = $atts['el_class'];
		$posts_per_page = $atts['posts_per_page'];
		$orderby        = $atts['orderby'];
		$columns        = $atts['columns'];

		$css_class = array( 'factora-portfolio-carousel', sprintf( 'style-%s', $style ), $el_class );

		if ( $orderby == 'none' ): $orderby = ''; endif;
		$order = $atts['order'];

		if ( $atts['source'] == '1' ) {
			$args = array(
				'post_type'      => 'portfolio',
				'posts_per_page' => $posts_per_page,
				'order'          => $order,
				'orderby'        => $orderby
			);
		} else {
			$list_id = explode( ',', $atts['list_id'] );
			$args    = array(
				'post_type'      => 'portfolio',
				'posts_per_page' => '-1',
				'order'          => $order,
				'orderby'       => 'post__in',
				'post__in'       => $list_id
			);
		}
		$the_query = new WP_Query( $args );
		$value     = $cats = array();

		if ( $atts['nav'] ) {
			$nav = true;
		} else {
			$nav = false;
		}
		if ( $atts['dots'] ) {
			$dots = true;
		} else {
			$dots = false;
		}
		if ( $atts['autoplay'] ) {
			$autoplay = true;
		} else {
			$autoplay = false;
		}
		if ( $style == '1' ) {
			$centerMode = true;
		} else {
			$centerMode = false;
		}
		$id                                     = uniqid( 'factora-portfolio-carousel-' );
		$this->l10n['portfolioCarousel'][ $id ] = array(
			'centerMode'   => $centerMode,
			'nav'          => $nav,
			'dots'         => $dots,
			'autoplay'     => $autoplay,
			'slidesToShow' => $columns,
			'prevArrow'    => '.factora-left-arrow',
			'nextArrow'    => '.factora-right-arrow',
		);


		$prevArrow = sprintf( '<div class="factora-left-arrow"><span class="arrow arrow_left"></span><span class="source">/</span><span class="text">%s</span></div>', esc_html__( 'Previous project' ) );
		$nextArrow = sprintf( '<div class="factora-right-arrow"><span class="text">%s</span><span class="source">/</span><span class="arrow arrow_right"></span></div>', esc_html__( 'Next project' ) );
		$count     = 1;
		if ( $the_query->have_posts() ) :
			while ( $the_query->have_posts() ) : $the_query->the_post();
				$permalink = get_permalink();
				$the_title = get_the_title();
				$id_post   = get_the_ID();
				$class     = sprintf( 'col-xs-12' );
				$size      = sprintf( 'factora-portfolio-carousel-%s', $style );
				$thumb     = get_the_post_thumbnail_url( $id_post, $size );
				$img       = "<img alt='$the_title' src='$thumb'/>";
				$active    = '';
				if ( $style == '1' ) {
					$active = '<div class="de-active"></div>';
				}

				$thumbnail = sprintf( '<div class="post-thumbnail">%s %s</div>', $img, $active );

				if ( $style == '1' ) {
					$read_more = sprintf( '<div class="read-more">%s</div>', esc_html__( 'View Detail', 'factora' ) );
				} else {
					$read_more = sprintf( '<div class="read-more">%s<span class="arrow_carrot-right"></span></div>', esc_html__( 'See Project', 'factora' ) );
				}

				$html_content = sprintf( '<div class="portfolio-content">
						<h3 class="entry-title">%s</h3>
						%s
						</div>',
					$the_title, $read_more );

				$value[] = sprintf( '<div class="%s element-item portfolio-wrapper portfolio-item" >
						<div class="content-item">
						<div class="entry-thumbnail">%s</div>
						%s
						<a href="%s" class="hover"></a>
						</div>
					</div>',
					$class, $thumbnail, $html_content, $permalink );
				$count ++;
			endwhile;
		endif;
		$footer_gr = '';
		if ( $count > 1 && $nav == true ) {
			$footer_gr = sprintf( '<div class="arrow-group"><div class="container"><div class="wrapper">%s</div></div></div>', $prevArrow . $nextArrow );
		}
		$value = implode( '', $value );

		return sprintf( '<div class="%s" ><div class="list-items" id="%s">%s</div>%s</div> ',
			implode( ' ', $css_class ), $id, $value, $footer_gr );
	}

	/**portfolio masonry
	 *
	 * @since  1.0
	 *
	 * @return string
	 */
	function factora_portfolio_masonry( $atts, $content ) {

		$atts = shortcode_atts(
			array(
				'posts_per_page' => '12',
				'orderby'        => 'none',
				'order'          => 'DESC',
				'el_class'       => '',
			), $atts
		);

		$el_class       = $atts['el_class'];
		$posts_per_page = $atts['posts_per_page'];
		$oderby         = $atts['orderby'];

		$css_class = array( 'factora-portfolio-masonry', $el_class );

		if ( $oderby == 'none' ): $oderby = ''; endif;
		$oder      = $atts['order'];
		$args      = array(
			'post_type'      => 'portfolio',
			'posts_per_page' => $posts_per_page,
			'order'          => $oder,
			'orderby'        => $oderby
		);
		$the_query = new WP_Query( $args );
		$value     = $cats = array();


		$i = 1;
		if ( $the_query->have_posts() ) :
			while ( $the_query->have_posts() ) : $the_query->the_post();
				$permalink = get_permalink();
				$the_title = get_the_title();
				$id_post   = get_the_ID();

				$thumb_size = $active = '';
				if ( $i == 1 ) {
					$thumb_size = 'factora-portfolio-masonry-thumb-1';

				} elseif ( $i == 2 ) {
					$thumb_size = 'factora-portfolio-masonry-thumb-2';

				} elseif ( $i == 3 ) {
					$thumb_size = 'factora-portfolio-masonry-thumb-3';

				} elseif ( $i == 4 ) {
					$thumb_size = 'factora-portfolio-masonry-thumb-3';

				}

				$thumb = get_the_post_thumbnail_url( $id_post, $thumb_size );
				$img   = "<img alt='$the_title' src='$thumb'/>";

				$thumbnail = sprintf( '<div class="post-thumbnail">%s %s</div>', $img, $active );
				$read_more = sprintf( '<div class="read-more">%s<span class="arrow_carrot-right"></span></div>', esc_html__( 'See Project', 'factora' ) );

				$html_content = sprintf( '<div class="portfolio-content">
						<h3 class="entry-title">%s</h3>
						%s
						</div>',
					$the_title, $read_more );

				$value[] = sprintf( '<div class="portfolio-item item-%s" >
						<div class="content-item">
						<div class="entry-thumbnail">%s</div>
						%s
						<a href="%s" class="hover"></a>
						</div>
					</div>',
					$i, $thumbnail, $html_content, $permalink );
				if ( $i == 4 ) {
					$i = 0;
				}
				$i ++;
			endwhile;
		endif;

		return sprintf( '<div class="%s" ><div class="row"> <div class="list-items">
				<div class="grid-sizer"></div>
  				<div class="grid-item"></div>
				%s</div></div></div> ',
			implode( ' ', $css_class ), implode( '', $value ) );
	}

	/**portfolio masonry
	 *
	 * @since  1.0
	 *
	 * @return string
	 */
	function factora_service_grid( $atts, $content ) {

		$atts = shortcode_atts(
			array(
				'style'          => '1',
				'title'          => '',
				'sub_title'      => '',
				'view_all'       => '',
				'text_view_all'  => '',
				'posts_per_page' => '12',
				'orderby'        => 'none',
				'order'          => 'DESC',
				'el_class'       => '',
			), $atts
		);

		$title          = $atts['title'];
		$style          = $atts['style'];
		$view_all       = $atts['view_all'];
		$el_class       = $atts['el_class'];
		$posts_per_page = $atts['posts_per_page'];
		$oderby         = $atts['orderby'];

		$css_class = array(
			'factora-service-grid',
			$style == '2' ? 'factora-archive-service' : '',
			sprintf( 'style-%s', $style ),
			$el_class
		);

		if ( $oderby == 'none' ): $oderby = ''; endif;
		$oder      = $atts['order'];
		$args      = array(
			'post_type'      => 'service',
			'posts_per_page' => $posts_per_page,
			'order'          => $oder,
			'orderby'        => $oderby
		);
		$the_query = new WP_Query( $args );
		$value     = $cats = array();

		$header        = array();
		$sub_title     = ! empty( $atts['sub_title'] ) ? sprintf( '<span class="sub-title">%s</span>', $atts['sub_title'] ) : '';
		$link          = get_post_type_archive_link( 'service' );
		$text_view_all = ! empty( $atts['text_view_all'] ) ? $atts['text_view_all'] : esc_html__( 'View All Project' );

		if ( ! empty( $title ) ) {
			$header[] = sprintf( '<div class="%s service-section-title">', $style == '1' ? 'col-lg-6' : 'container' );
			$header[] = '<div class="wrapper">';
			$header[] = '<div class="entry-title">';
			$header[] = sprintf( '<h3 class="title">%s</h3>%s', $title, $sub_title );
			$header[] = '</div>';
			$header[] = sprintf( '<div class="entry-content">%s</div>', $content );
			$header[] = ! empty( $view_all ) ? sprintf( '<a class="view-all" href="%s">%s</a>', $link, $text_view_all ) : '';
			$header[] = '</div>';
			$header[] = '</div>';
		}
		$ct_class = '';
		if ( $style != '1' ) {
			$ct_class = 'col-sm-6 col-md-4';
		}
		$i = 1;
		if ( $the_query->have_posts() ) :
			while ( $the_query->have_posts() ) : $the_query->the_post();
				$permalink   = get_permalink();
				$the_title   = get_the_title();
				$description = $style == '1' ? sprintf( '<div class="description">%s</div>', get_the_excerpt() ) : '';
				$id_post     = get_the_ID();

				$thumb_size = $active = '';
				if ( $style == '1' ) {
					$thumb_size = 'factora-service-grid-thumb-1';
				} elseif ( $style == '2' ) {
					$thumb_size = 'factora-blog-grid';
				}
				$thumb = get_the_post_thumbnail_url( $id_post, $thumb_size );
				$img   = sprintf( '<img alt="%s" src="%s"/>', $the_title, $thumb );

				$thumbnail   = sprintf( '<a href="%s" class="post-thumbnail">%s %s</a>', $permalink, $img, $active );
				$tx_readmore = $style == '1' ? sprintf( '%s<span class="arrow_carrot-right"></span>', esc_html__( 'Learn more', 'factora' ) ) : esc_html__( 'Read more', 'factora' );
				$read_more   = sprintf( '<a href="%s" class="read-more">%s</a>', $permalink, $tx_readmore );


				$html_content = sprintf( '<div class="service-content">
						<div class="content-wrapper">
							<h3 class="entry-title"><a href="%s">%s</a></h3>
							%s
							%s
						</div>
						%s
						</div>',
					$permalink, $the_title, $description, $style == '2' ? $read_more : '', $style == '1' ? $read_more : '' );
				if ( $style == '1' ) {

					if ( $i % 4 == 1 || $i % 4 == 2 ) {
						$value_content = sprintf( '<div class="entry-thumbnail">%s</div>%s', $thumbnail, $html_content );
					} else {
						$value_content = sprintf( '%s<div class="entry-thumbnail">%s</div>', $html_content, $thumbnail );
					}
				} else {
					$value_content = sprintf( '<div class="entry-thumbnail">%s</div>%s', $thumbnail, $html_content );
				}

				$value[] = sprintf( '<div class="service-item %s" >
						<div class="content-item">
						%s
						</div>
					</div>',
					$ct_class, $value_content );
				if ( $i == 4 ) {
					$i = 0;
				}
				$i ++;
			endwhile;
		endif;

		if ( $style == '1' ) {
			$entry_content = sprintf( '<div class="list-items">%s %s</div>', implode( '', $value ), implode( '', $header ) );
		} else {
			$entry_content = sprintf( '<div class="list-items row">%s</div>', implode( '', $value ) );
		}

		return sprintf( '<div class="%s" >%s</div> ',
			implode( ' ', $css_class ), $entry_content );
	}

	/**Service icon
	 *
	 * @since  1.0
	 *
	 * @return string
	 */
	function factora_service_icon( $atts, $content ) {

		$atts           = shortcode_atts(
			array(
				'style'           => '1',
				'posts_per_page'  => '12',
				'orderby'         => 'none',
				'order'           => 'DESC',
				'excerpt_content' => '11',
				'items'           => '4',
			), $atts
		);
		$style          = $atts['style'];
		$posts_per_page = $atts['posts_per_page'];
		$oderby         = $atts['orderby'];
		$items          = $atts['items'];
		$columns        = 12 / $items;

		if ( $oderby == 'none' ): $oderby = ''; endif;
		$oder      = $atts['order'];
		$args      = array(
			'post_type'      => 'service',
			'posts_per_page' => $posts_per_page,
			'order'          => $oder,
			'orderby'        => $oderby
		);
		$the_query = new WP_Query( $args );
		$value     = $cats = array();

		if ( $the_query->have_posts() ) :
			while ( $the_query->have_posts() ) : $the_query->the_post();
				$permalink = get_permalink();
				$the_title = get_the_title();
				$id        = get_the_ID();

				$class = sprintf( 'col-xs-12 col-sm-6 col-md-%s', $columns );

				$type_icon = get_post_meta( get_the_ID(), 'icon_type', true );
				$icon      = get_post_meta( get_the_ID(), 'icon', true );
				if ( $type_icon == 'svg' ) {
					$val_icon = sprintf( '<span class="factora-icon"><svg viewbox="0 0 512 512" ><use xlink:href="#%s"></use></svg></span>', $icon );
				} else {
					$val_icon = sprintf( '<span class="%s"></span>', $icon );
				}

				$entry_thumbnail = sprintf( '<a class="post-thumbnail" href="%s">%s</a>', $permalink, $val_icon );

				$excerpt_number = $atts['excerpt_content'];

				$desc = get_the_excerpt();
				if ( ! empty( $desc ) ) {
					$desc = $this->factora_addons_content_limit( $desc, $excerpt_number, '' );
				}

				$tx_readmore = sprintf( '%s<span class="arrow_carrot-right"></span>', esc_html__( 'Learn more', 'factora' ) );
				$read_more   = sprintf( '<a href="%s" class="read-more">%s</a>', $permalink, $tx_readmore );

				$value[] = sprintf( "<div id='%s' class='%s element-item service-icon-wrapper service-icons-item' >
						<div class='content-item'>
						<div class='entry-thumbnail'>%s</div>
						<div class='service-icons-content'>
						<h3 class='entry-title'><a class='title' href='%s'>%s</a></h3>
						<div class='descr'><div class='entry-content'>%s</div>%s</div>
						</div>
						</div>
					</div>",
					$id, $class, $entry_thumbnail, $permalink, $the_title, $desc, $read_more );
			endwhile;
		endif;

		$value = implode( '', $value );

		return sprintf( '<div class="factora-service-icons factora-service-icon-shortcode with_icon style-%s">
					<div class="service-icons-wrapper">%s</div>
					</div> ', $style, $value );
	}

	/**Service icon
	 *
	 * @since  1.0
	 *
	 * @return string
	 */
	function factora_brochure( $atts, $content ) {

		$atts      = shortcode_atts(
			array(
				'title'       => '',
				'list_button' => '',
				'el_class'    => '',
			), $atts
		);
		$title     = $atts['title'];
		$css_class = array( 'factora-brochure', $atts['el_class'] );
		$title     = ! empty( $title ) ? sprintf( '<h3 class="title">%s</h3>', $title ) : '';

		$buttons = vc_param_group_parse_atts( $atts['list_button'] );
		$outputs = array();
		if ( ! empty( $buttons ) ) {
			foreach ( $buttons as $key => $button ) {
				if ( ! empty( $button['name_button'] ) ) {
					$link      = ! empty( $button['link'] ) ? vc_build_link( $button['link'] )['url'] : '#';
					$outputs[] = sprintf( '<li class="item"><a href="%s">%s<i class="icon_download"></i></a></li>', $link, $button['name_button'] );
				}
			}
		}

		return sprintf( '<div class="%s">%s <ul class="list-item">%s</ul></div>', implode( ' ', $css_class ), $title, implode( '', $outputs ) );
	}


	/**Service carousel
	 *
	 * @since  1.0
	 *
	 * @return string
	 */
	function factora_image_box_carousel( $atts, $content ) {

		$atts = shortcode_atts(
			array(
				'list_image_box'  => '',
				'text_color'      => 'light',
				'excerpt_content' => '11',
				'columns'         => '4',
				'dots'            => '',
				'autoplay'        => '',
				'el_class'        => '',
			), $atts
		);

		$el_class = $atts['el_class'];
		$columns  = $atts['columns'];

		$css_class = array( 'factora-image-box-carousel', sprintf( 'text-color-%s', $atts['text_color'] ), $el_class );

		$value = $cats = array();

		if ( $atts['dots'] ) {
			$dots = true;
		} else {
			$dots = false;
		}
		if ( $atts['autoplay'] ) {
			$autoplay = true;
		} else {
			$autoplay = false;
		}

		$id                                    = uniqid( 'factora-image-box-carousel-' );
		$this->l10n['imageBoxCarousel'][ $id ] = array(
			'dots'         => $dots,
			'autoplay'     => $autoplay,
			'slidesToShow' => $columns,
		);

		$items = vc_param_group_parse_atts( $atts['list_image_box'] );
		$count = 1;
		if ( ! empty( $items ) ) {
			foreach ( $items as $key => $item ) {
				$permalink = ! empty( $item['link'] ) ? vc_build_link( $item['link'] )['url'] : '#';
				$the_title = ! empty( $item['title'] ) ? sprintf( '<h3 class="entry-title"><a href="%s">%s</a></h3>', $permalink, $item['title'] ) : '';

				$class  = sprintf( 'col-xs-12' );
				$size   = ! empty( $item['image_size'] ) ? $item['image_size'] : '';
				$img    = ! empty( $item['image_size'] ) ? $this->get_vc_image( $item['image'], $size ) : '';
				$active = '';

				$desc = ! empty( $item['desc'] ) ? sprintf( '<p class="desc">%s</p>', $item['desc'] ) : '';

				$thumbnail    = sprintf( '<div class="post-thumbnail">%s %s</div>', $img, $active );
				$read_more    = sprintf( '<a href="%s" class="read-more">%s</a>', $permalink, esc_html__( 'Read More', 'factora' ) );
				$html_content = sprintf( '<div class="image-box-content">
						%s
						%s
						%s
						</div>',
					$the_title,
					$desc,
					$read_more );

				$value[] = sprintf( '<div class="%s element-item image-box-wrapper image-box-item" >
						<div class="content-item">
						<div class="entry-thumbnail">%s</div>
						%s
						<a href="%s" class="hover"></a>
						</div>
					</div>',
					$class, $thumbnail, $html_content, $permalink );
				$count ++;
			}
		}


		$value = implode( '', $value );

		return sprintf( '<div class="%s" ><div class="list-items row" id="%s">%s</div></div> ',
			implode( ' ', $css_class ), $id, $value );
	}


	/**
	 * Count down shortcode
	 *
	 * @param array  $atts
	 * @param string $content
	 *
	 * @return string
	 */
	function factora_countdown( $atts, $content ) {
		$atts = shortcode_atts(
			array(
				'date'       => '',
				'text_color' => 'light',
				'el_class'   => '',
			), $atts
		);

		$css_class = array(
			'factora-countdown fatora-time-format',
			'text-' . $atts['text_color'],
			$atts['el_class'],
		);

		$second = 0;
		if ( $atts['date'] ) {
			$second_current = strtotime( date_i18n( 'Y/m/d H:i:s' ) );
			$date           = new DateTime( $atts['date'] );
			if ( $date ) {
				$second_discount = apply_filters( 'factora_product_coundown', strtotime( date_i18n( 'Y/m/d H:i:s', $date->getTimestamp() ) ) );
				if ( $second_discount > $second_current ) {
					$second = $second_discount - $second_current;
				}
			}
		}

		$html[] = sprintf( '<div class="factora-time-countdown ft-countdown" data-expire="%s"></div>', esc_attr( $second ) );

		return sprintf(
			'<div class="%s">%s</div>',
			esc_attr( implode( ' ', $css_class ) ),
			implode( '', $html )
		);
	}

	/**
	 * Map shortcode
	 *
	 * @param array  $atts
	 * @param string $content
	 *
	 * @return string
	 */
	function factora_map( $atts, $content ) {

		$atts = shortcode_atts(
			array(
				'marker'   => '',
				'token'    => '',
				'local'    => '',
				'height'   => '',
				'zoom'     => '',
				'color_1'  => '',
				'color_2'  => '',
				'el_class' => '',
			), $atts
		);

		// Add class
		$class_name = "factora-map__" . $this->get_id_number( __FUNCTION__ );

		$css_class = array(
			'factora-map',
			$class_name,
			$atts['el_class']
		);

		// CSS
		$style = '';
		if ( $atts['height'] ) {
			$style = 'style=height:' . $atts['height'] . 'px';
		}

		$image_src = wp_get_attachment_image_src( $atts['marker'], 'thumb' );
		$src       = esc_url( $image_src[0] );

		// JS
		$local   = empty( $atts['local'] ) ? 'New York, United States' : $atts['local'];
		$color_1 = $atts['color_1'] ? $atts['color_1'] : '#d0ecf2';
		$color_2 = $atts['color_2'] ? $atts['color_2'] : '#f0f0ec';
		$zoom    = $atts['zoom'] ? $atts['zoom'] : '11';
		$id      = uniqid( 'factora-map-' );

		$this->l10n['mapBox'][ $id ] = array(
			'marker'  => $src,
			'token'   => $atts['token'],
			'zom'     => intval( $zoom ),
			'color_1' => $color_1,
			'color_2' => $color_2,
			'local'   => $local,
		);

		return sprintf(
			'<div class="%s" id="%s" %s>' .
			'<div id="map">' .
			'</div>' .
			'</div>',
			esc_attr( implode( ' ', $css_class ) ),
			$id,
			esc_attr( $style )
		);
	}

	/**
	 * Social shortcode
	 *
	 * @param array  $atts
	 * @param string $content
	 *
	 * @return string
	 */
	function factora_social( $atts, $content ) {
		$atts = shortcode_atts(
			array(
				'style'    => '1',
				'title'    => '',
				'align'    => 'left',
				'setting'  => '',
				'el_class' => '',
			), $atts
		);

		// Add class
		$class_name = "factora-social__" . $this->get_id_number( __FUNCTION__ );
		$css_class  = array(
			'factora-social',
			'factora-social--' . $atts['align'],
			'style-' . $atts['style'],
			$class_name,
			$atts['el_class']
		);
		$outputs    = $css = array();
		// Param
		$infor = vc_param_group_parse_atts( $atts['setting'] );
		if ( ! empty( $infor ) ) {
			foreach ( $infor as $key => $value ) {
				// Link
				$url        = isset( $value['link'] ) && ! empty( $value['link'] ) ? vc_build_link( $value['link'] ) : '';
				$src        = $url != '' ? $url['url'] : '#';
				$value_icon = ! empty( $value['icon'] ) ? $value['icon'] : 'elegant';

				// Icon
				switch ( $value_icon ) {
					case 'svg':
						$value['name_icon'] = ! empty( $value['name_icon'] ) ? $value['name_icon'] : '';
						$icon               = $value['name_icon'] == '' ? '' : sprintf( "<svg viewBox='0 0 20 20'><use xlink:href='#%s'></use></svg>", $value['name_icon'] );
						break;
					case 'awesome':
						$icon = sprintf( "<i class='%s'></i>", $value['icon_fontawesome'] );
						break;
					case 'elegant':
						$icon = sprintf( "<i class='%s'></i>", $value['eleganticons'] );
						break;
					default:
						$icon = "";
				}

				$name_icon = $icon == '' ? '' : sprintf( '<div class="item"><a href="%s">%s</a></div>', $src, $icon );
				$outputs[] = $name_icon;
			}
		}
		$title = ! empty( $atts['title'] ) ? sprintf( '<h3 class="title">%s</h3>', $atts['title'] ) : '';

		return sprintf(
			'<div class="%s">' .
			'%s' .
			'<div class="list-item">%s</div>' .
			'</div>',
			implode( ' ', $css_class ),
			$title,
			implode( ' ', $outputs )
		);
	}

	/**
	 * Section Title shortcode
	 *
	 * @param array  $atts
	 * @param string $content
	 *
	 * @return string
	 */
	function factora_section_title( $atts, $content ) {
		$atts  = shortcode_atts(
			array(
				'title'        => '',
				'second_title' => '',
				'style'        => '1',
				'color'        => 'dark',
				'el_class'     => '',
			), $atts
		);
		$style = $atts['style'];
		$color = $atts['color'];
		$title = ! empty( $atts['title'] ) ? sprintf( '<h3 class="title">%s <span>%s</span></h3>', $atts['title'], $atts['second_title'] ) : '';

		return sprintf( '<div class="factora-section-title factora-style-%s color-%s %s">%s</div>',
			$style, $color, $atts['el_class'], $title );
	}

	/**
	 * Contact Form shortcode
	 *
	 * @param array  $atts
	 * @param string $content
	 *
	 * @return string
	 */
	function factora_contact_form_7( $atts, $content ) {
		$atts       = shortcode_atts(
			array(
				'style'     => '1',
				'btn_style' => 'default',
				'title'     => '',
				'form'      => '',
				'el_class'  => '',
			), $atts
		);
		$class_name = "factora-contact-form-7__" . $this->get_id_number( __FUNCTION__ );

		$css_class = array(
			'factora-contact-form-7',
			'factora--style-' . $atts['style'],
			'factora--button-style-' . $atts['btn_style'],
			$class_name,
			$atts['el_class']
		);

		$title = ! empty( $atts['title'] ) ? sprintf( '<h4 class="title">%s</h4>', $atts['title'] ) : '';

		return sprintf(
			'<div class="%s">%s %s</div>',
			esc_attr( implode( ' ', $css_class ) ),
			$title,
			do_shortcode( '[contact-form-7 id="' . esc_attr( $atts['form'] ) . '" title=" ' . get_the_title( $atts['form'] ) . ' "]' )
		);
	}

	/**
	 * Button shortcode
	 *
	 * @param array  $atts
	 * @param string $content
	 *
	 * @return string
	 */
	function factora_button( $atts, $content ) {
		$atts = shortcode_atts(
			array(
				'style'    => 'primary',
				'link'     => '',
				'icon'     => 'none',
				'icon_fontawesome'     => '',
				'linearicons'     => '',
				'eleganticons'     => '',
				'color'    => '',
				'align'    => 'left',
				'el_class' => '',
			), $atts
		);
		switch ( $atts['icon'] ) {

			case 'awesome':
				$icon = sprintf( "<i class='fct-icon %s'></i>", $atts['icon_fontawesome'] );
				break;
			case 'linear':
				$icon = sprintf( "<i class='fct-icon %s'></i>", $atts['linearicons'] );
				break;
			case 'elegant':
				$icon = sprintf( "<i class='fct-icon %s'></i>", $atts['eleganticons'] );
				break;
			default:
				$icon = "";
		}
		// Add class
		$class_name = "factora-button__" . $this->get_id_number( __FUNCTION__ );
		$css_class  = array(
			'factora-button',
			$class_name,
			'factora-button__align-' . $atts['align'],
			'factora-button__style-' . $atts['style'],
			$atts['el_class']
		);

		// Link
		$link  = ! empty( $atts['link'] ) ? vc_build_link( $atts['link'] ) : '';
		$src   = $link != '' ? $link['url'] : '#';
		$color = $atts['color'] ? sprintf( 'style="color:%s;"', $atts['color'] ) : '';

		// Btn
		$title = $link != '' ? $link['title'] : '';
		$btn   = ! empty( $title ) ? sprintf( '<a %s href="%s">%s %s</a>', $color, $src, $title, $icon ) : '';

		return sprintf(
			'<div class="%s">' .
			'%s' .
			'</div>',
			implode( ' ', $css_class ),
			$btn
		);
	}

	/**
	 * Latest Form shortcode
	 *
	 * @param array  $atts
	 * @param string $content
	 *
	 * @return string
	 */
	function factora_latest_post( $atts, $content ) {
		$atts = shortcode_atts(
			array(
				'style'    => 'grid',
				'limit'    => '3',
				'el_class' => '',
			), $atts
		);

		$css_class = array(
			'factora-latest-post',
			'factora-blog-page',
			'factora-latest-post__style-' . $atts['style'],
			$atts['el_class'],
		);

		$row_flex = 'row-flex';

		$blog_view = $atts['style'];
		$css       = 'blog-wrapper';
		$size      = 'factora-lastest-blog-' . $atts['style'];

		if ( $blog_view == 'grid' ) {
			$col = 12 / factora_get_option( 'blog_grid_columns' );
			$css .= ' blog-wrapper__grid col-flex-sm-6 col-flex-md-' . $col;
		} else {
			$css .= ' blog-wrapper__list';
			$row_flex = '';
		}

		if ( has_post_thumbnail() ) {
			$css .= ' has-post-thumbnail';
		}

		$output = array();

		$query_args = array(
			'posts_per_page'      => $atts['limit'],
			'post_type'           => 'post',
			'ignore_sticky_posts' => true,
		);

		$query = new WP_Query( $query_args );

		while ( $query->have_posts() ) : $query->the_post();
			ob_start();
			?>

			<article id="post-<?php the_ID(); ?>" class="<?php echo esc_attr( $css ) ?>">
				<?php factora_post_thumbnail( $size ); ?>

				<div class="factora-post__entry-header">
					<div class="side-content">
						<?php if ( $blog_view == 'grid' ):
							factora_title();
							echo '<div class="list-meta">';
							echo get_avatar( get_the_author_meta( 'ID' ), 40 );
						endif; ?>

						<?php factora_post_entry_meta(); ?>
						<?php if ( $blog_view == 'list' ): factora_title();
							factora_post_entry_content(); endif; ?>

						<?php if ( $blog_view == 'grid' ):
							echo '</div>';
						endif; ?>
					</div>
				</div>
			</article><!-- #post-<?php the_ID(); ?> -->

			<?php
			$output[] = ob_get_clean();

		endwhile;

		wp_reset_postdata();


		return sprintf(
			'<div class="%s %s">' .
			'%s' .
			'</div>',
			esc_attr( implode( ' ', $css_class ) ),
			esc_attr( $row_flex ),
			implode( '', $output )
		);
	}

	function factora_faq( $atts, $content ) {
		$atts = shortcode_atts(
			array(
				'style'     => '1',
				'box_style' => 'box_shadow',
				'active'    => '1',
				'font_size' => '',
				'setting'   => '',
				'el_class'  => '',
			), $atts
		);

		// add class
		$class_name = 'factora-faq__' . $this->get_id_number( __FUNCTION__ );
		$css_class  = array(
			'factora-faq',
			'factora-faq__style-' . $atts['style'],
			'factora-box-style-'. $atts['box_style'],
			$class_name,
			$atts['el_class']
		);

		//style
		$font_size = '';
		$css       = $this->factora_font_size( $atts['font_size'] );
		if ( ! empty( $atts['font_size'] ) ) {
			$font_size = 'style="font-size:' . $css . ' "';
		}

		// param content
		$infor   = vc_param_group_parse_atts( $atts['setting'] );
		$outputs = array();
		if ( ! empty( $infor ) ) {
			foreach ( $infor as $key => $value ) {

				$question = isset( $value['question'] ) && ( ! empty( $value['question'] ) ) ? sprintf( '<div class="factora-faq__question"><h4 %s>%s</h4> <span><i class="icon_minus-06"></i><i class="icon_plus"></i></span></div>', $font_size, $value['question'] ) : '';
				$answer   = isset( $value['answer'] ) && ( ! empty( $value['answer'] ) ) ? sprintf( '<div class="factora-faq__answer">%s</div>', $value['answer'] ) : '';

				$outputs[] = sprintf(
					'<div class="factora-faq__box">' .
					'%s' .
					'%s' .
					'</div>',
					$question,
					$answer
				);
			}
		}
		$count = isset( $infor ) ? count( $infor ) : '';
		if ( $atts['active'] > $count ) {
			$atts['active'] = '1';
		}

		return sprintf(
			'<div class="%s" data-active="%s">' .
			'%s' .
			'</div>',
			implode( ' ', $css_class ),
			esc_attr( $atts['active'] ),
			implode( '', $outputs )
		);
	}

	/**Team carousel
	 *
	 * @since  1.0
	 *
	 * @return string
	 */
	function factora_team_carousel( $atts, $content ) {

		$atts = shortcode_atts(
			array(
				'posts_per_page'  => '12',
				'orderby'         => 'none',
				'order'           => 'DESC',
				'excerpt_content' => '11',
				'columns'         => '4',
				'hidden_link'       => '4',
				'nav'             => '',
				'dots'            => '',
				'autoplay'        => '',
				'el_class'        => '',
			), $atts
		);

		$el_class       = $atts['el_class'];
		$posts_per_page = $atts['posts_per_page'];
		$oderby         = $atts['orderby'];
		$columns        = $atts['columns'];

		$css_class = array( 'factora-team-carousel', $el_class );

		if ( $oderby == 'none' ): $oderby = ''; endif;
		$oder      = $atts['order'];
		$args      = array(
			'post_type'      => 'team',
			'posts_per_page' => $posts_per_page,
			'order'          => $oder,
			'orderby'        => $oderby
		);
		$the_query = new WP_Query( $args );
		$value     = $cats = array();

		if ( $atts['nav'] ) {
			$nav = true;
		} else {
			$nav = false;
		}
		if ( $atts['dots'] ) {
			$dots = true;
		} else {
			$dots = false;
		}
		if ( $atts['autoplay'] ) {
			$autoplay = true;
		} else {
			$autoplay = false;
		}

		$id                                = uniqid( 'factora-team-carousel-' );
		$this->l10n['teamCarousel'][ $id ] = array(
			'nav'          => $nav,
			'dots'         => $dots,
			'autoplay'     => $autoplay,
			'slidesToShow' => $columns,
			'prevArrow'    => '<div class="slick-arrow arrow-left"><span class="icon-chevron-left"></span></div>',
			'nextArrow'    => '<div class="slick-arrow arrow-right"><span class="icon-chevron-right"></span></div>',
		);


		$count = 1;
		if ( $the_query->have_posts() ) :
			while ( $the_query->have_posts() ) : $the_query->the_post();
				$permalink = get_permalink();
				if ( $atts['hidden_link'] ) {
					$permalink = '';
				}
				$the_title = get_the_title();
				$id_post   = get_the_ID();
				$class     = sprintf( 'col-xs-12' );
				$size      = 'factora-team-image';
				$thumb     = get_the_post_thumbnail_url( $id_post, $size );
				$img       = "<img alt='$the_title' src='$thumb'/>";
				$active    = '';

				$thumbnail = $permalink != '' ? sprintf( '<a href="%s" class="post-thumbnail">%s %s</a>', $permalink, $img, $active ) :
					sprintf( '<div class="post-thumbnail">%s %s</div>', $img, $active ) ;
				$title = $permalink != '' ? sprintf('<h3 class="entry-title"><a href="%s">%s</a></h3>',$permalink, $the_title) :
					sprintf('<h3 class="entry-title">%s</h3>', $the_title);
				$job       = $this->factora_get_information( get_the_ID() );
				$social    = sprintf( '<div class="team-social">%s</div>', $this->factora_team_social( get_the_ID() ) );

				$html_content = sprintf( '<div class="team-content">% s%s %s</div>', $title, $job, $social );

				$value[]      = sprintf( '<div class="%s element-item team-wrapper team-item" >
						<div class="content-item">
						<div class="entry-thumbnail">%s</div>
						%s
						</div>
					</div>',
					$class, $thumbnail, $html_content );
				$count ++;
			endwhile;
		endif;

		$value = implode( '', $value );

		return sprintf( '<div class="%s" ><div class="list-items row" id="%s">%s</div></div> ',
			implode( ' ', $css_class ), $id, $value );
	}

	/**portfolio grid
	 *
	 * @since  1.0
	 *
	 * @return string
	 */
	function factora_portfolio_grid( $atts, $content ) {
		$atts = shortcode_atts(
			array(
				'title'          => '',
				'filter'         => '',
				'slug_cate'      => '',
				'orderby'        => 'none',
				'order'          => 'DESC',
				'items'          => '4',
				'posts_per_page' => '9',
			), $atts
		);

		$posts_per_page = $atts['posts_per_page'];
		$filter         = $atts['filter'];

		$items   = $atts['items'];
		$columns = 12 / $items;
		$width   = 100 / $items . '%';
		$oderby  = $atts['orderby'];
		if ( $oderby == 'none' ): $oderby = ''; endif;
		$oder          = $atts['order'];
		$args          = array(
			'post_type'      => 'portfolio',
			'posts_per_page' => $posts_per_page,
			'order'          => $oder,
			'orderby'        => $oderby
		);
		$the_query     = new WP_Query( $args );
		$list_category = $value = $cats = array();

		if ( $the_query->have_posts() ) :
			while ( $the_query->have_posts() ) : $the_query->the_post();
				$permalink = get_permalink();
				$the_title = get_the_title();
				$id        = get_the_ID();

				$slug  = array();
				$terms = get_the_terms( get_the_ID(), 'portfolio_category' );
				if ( $terms && ! is_wp_error( $terms ) ) :
					//$slug          = $terms[0]->slug;

					foreach ( $terms as $cat ) {
						$cat_id = $cat->term_id;

						$cats[ $cat_id ] = array( 'name' => $cat->name, 'slug' => $cat->slug, );
						$slug[]          = $cat->slug;

					}
				endif;

				$text_readmore   = esc_html__( 'See Project', 'factora' );
				$thumb_size      = "factora-portfolio-grid";
				$portfolio_class = sprintf( 'col-xs-12 col-sm-4 col-md-%s portfolio-grid', $columns );

				$class           = $portfolio_class;
				$thumb           = get_the_post_thumbnail_url( $id, $thumb_size );
				$img             = "<img alt='$the_title' src='$thumb'/>";
				$entry_thumbnail = sprintf( '<a href="%s" class="entry-thumbnail">%s</a>', $permalink, $img );
				$read_more       = sprintf( '<a href="%s" class="entry-read-more">%s <span class="arrow_carrot-right"></span></a>', $permalink, $text_readmore );

				$value[] = sprintf( "<div id='%s' class='%s element-item portfolio-wrapper portfolio-item %s' data-category='%s'>
						<div class='content-item'>
						<div class='entry-header'>%s</div>
						<div class='entry-content'>
							<div class='wrapper'>
								<h3 class='entry-title'><a href='%s'>%s</a></h3>
								%s
							</div>
						</div>
						</div>
					</div>",
					$id, $class, implode( ' ', $slug ), implode( '-', $slug ), $entry_thumbnail, $permalink, $the_title, $read_more );
			endwhile;
			wp_reset_postdata();
		endif;

		// List category
		$cats_slug = $atts['slug_cate'];
		if ( $cats_slug ) {
			$cats_slug = explode( ',', $cats_slug );

			foreach ( $cats_slug as $slug ) {
				$cat = get_term_by( 'slug', $slug, 'portfolio_category' );

				if ( $cat ) {
					$list_category[] = sprintf( '<span data-filter =".%s" class="button">%s</span>', esc_attr( $cat->slug ), esc_html( $cat->name ) );
				}
			}
		} else {
			foreach ( $cats as $category ) {
				$slug            = esc_attr( $category['slug'] );
				$cate_name       = esc_attr( $category['name'] );
				$list_category[] = "<span class='button' data-filter='.$slug'>$cate_name</span>";
			}
		}

		$title = '';
		if ( $atts['title'] ) {
			$title = sprintf( '<h3 class="title">%s</h3>', $atts['title'] );
		}
		if ( $filter ) :
			$str_viewall   = esc_html__( 'All Project', 'factora' );
			$list_category = implode( ' ', $list_category );
			$out_put       = sprintf( "<div class='container text-center categories-filter portfolio-cats-filters'>
									<div class='portfolio-grid-header'>
										%s
							            <div id='filters' class='button-group'><span class='button active' data-filter='*'>%s</span>
							            %s
										</div>
									</div>
								</div>", $title, $str_viewall, $list_category );
		else: $out_put = '';
		endif;

		$value = implode( '', $value );

		return sprintf( '<div class="factora-portfolio-grid">%s
					<div class="factora_portfolio_grid">%s</div>
					</div> ', $out_put, $value );
	}

	function factora_partner( $atts, $content ) {
		$atts = shortcode_atts(
			array(
				'style'          => 'grid',
				'columns'        => '1',
				'images'         => '',
				'image_size'     => '',
				'nav'            => '',
				'autoplay'       => '',
				'autoplay_speed' => '',
				'el_class'       => '',
			), $atts
		);

		$class = array(
			$atts['style'] == 'grid' ? 'factora-partner-grid' : 'factora-partner-carousel',
			$atts['el_class']
		);

		$image_size = $atts['image_size'];
		$out_put    = array();
		$images     = vc_param_group_parse_atts( $atts['images'] );
		if ( ! empty( $images ) ) {
			foreach ( $images as $key => $value ) {
				$image     = ! empty( $value['image'] ) ? $this->get_vc_image( $value['image'], $image_size ) : '';
				$link      = ! empty( $value['link'] ) ? vc_build_link( $value['link'] ) : '';
				$href      = ! empty( $link['url'] ) ? sprintf( ' href="%s"', $link['url'] ) : '';
				$tag       = ! empty( $link['url'] ) ? 'a' : 'div';
				$out_put[] = ! empty( $image ) ? sprintf( '<li class="item"><%s %s>%s</%s></li>', $tag, $href, $image, $tag ) : '';
			}
		}

		$id = $show_id = '';
		if ( $atts['style'] == 'carousel' ) {
			//Check nav
			if ( $atts['nav'] ) {
				$nav = true;
			} else {
				$nav = false;
			}
			if ( $atts['autoplay'] ) {
				$autoplay = true;
			} else {
				$autoplay = false;
			}
			$autoplay_speed = intval( $atts['autoplay_speed'] );
			$columns        = $atts['columns'];
			$nav_right      = '<div class="slide-arrow swiper-button-next"><i class="icon-chevron-right"></i></div>';
			$nav_left       = '<div class="slide-arrow swiper-button-prev"><i class="icon-chevron-left"></i></div>';
			$id             = uniqid( 'factora-partner-carousel' );

			$this->l10n['partnerCarousel'][ $id ] = array(
				'columns'       => $columns,
				'nav'           => $nav,
				'autoplay'      => $autoplay,
				'autoplaySpeed' => $autoplay_speed,
				'right'         => $nav_right,
				'left'          => $nav_left,
			);
		}

		if ( ! empty( $id ) ) {
			$show_id = 'id=' . $id . '';
		}

		return sprintf( '<div class="%s"><ul class="list-items" %s>%s</ul></div>', implode( ' ', $class ), $show_id, implode( '', $out_put ) );
	}

	function factora_icon_box_scroll( $atts, $content ) {

		$atts = shortcode_atts(
			array(
				'title'          => '',
				'desc'           => '',
				'text'           => '',
				'af_text'        => '',
				'image'          => '',
				'setting'        => '',
				'nav'            => '',
				'autoplay'       => '',
				'autoplay_speed' => '',
				'el_class'       => '',
			), $atts
		);

		// Add class
		$css_class = array(
			'factora-icon-box-carousel',
			'factora-icon-box--scroll',
			$atts['el_class']
		);

		$id                             = uniqid( 'factora-icon-box-carousel' );
		$this->l10n['iconScoll'][ $id ] = array();

		$outputs = array();

		// Param
		$infor = vc_param_group_parse_atts( $atts['setting'] );
		if ( ! empty( $infor ) ) {
			$this->l10n['iconScoll'][ $id ] ['count'] = count( $infor );
			foreach ( $infor as $key => $value ) {
				// Link
				$url = isset( $value['link'] ) && ! empty( $value['link'] ) ? vc_build_link( $value['link'] ) : '';
				$src = $url != '' ? $url['url'] : '#';

				// Icon
				switch ( $value['icon'] ) {
					case 'svg':
						$value['name_icon'] = ! empty( $value['name_icon'] ) ? $value['name_icon'] : '';
						$icon               = $value['name_icon'] == '' ? '' : sprintf( "<span class='factora-icon'><svg viewBox='0 0 20 20'><use xlink:href='#%s'></use></svg></span>", $value['name_icon'] );
						break;
					case 'awesome':
						$icon = sprintf( "<i class='%s'></i>", $value['icon_fontawesome'] );
						break;
					case 'linear':
						$icon = sprintf( "<i class='%s'></i>", $value['linearicons'] );
						break;
					case 'elegant':
						$icon = sprintf( "<i class='%s'></i>", $value['eleganticons'] );
						break;
					default:
						$icon = "";
				}

				$name_icon = $icon == '' ? '' : sprintf( '<div class="factora-icon-box-icon"><a href="%s">%s</a> </div>', $src, $icon );

				// Text
				$title      = isset( $value['title'] ) && ( ! empty( $value['title'] ) ) ? sprintf( '<a href="%s"><h3 class="title">%s</h3></a>', $src, $value['title'] ) : '';
				$desc       = isset( $value['desc'] ) && ( ! empty( $value['desc'] ) ) ? sprintf( '<div class="desc">%s</div>', $value['desc'] ) : '';
				$field_text = $title == '' && $desc == '' ? '' : sprintf( '<div class="factora-icon-box--text">%s %s</div>', $title, $desc );

				$outputs[] = sprintf( '<div class="factora-icon-box__list list-scroll">' );
				$outputs[] = $name_icon;
				$outputs[] = $field_text;
				$outputs[] = sprintf( '</div>' );
			}
		}
		$af_text = $atts['af_text'] ? sprintf( '<span>%s</span>', $atts['af_text'] ) : '';
		$text    = $atts['text'] == '' && $atts['af_text'] == '' ? '' : sprintf( '<div class="note-text">%s %s</div>', $atts['text'], $af_text );
		$title   = $atts['title'] || $atts['af_title'] ? sprintf( '<h3 class="title">%s</h3>', $atts['title'] ) : '';
		$desc    = $atts['desc'] ? sprintf( '<div class="desc">%s</div>', $atts['desc'] ) : '';
		$image   = ! empty( $atts['image'] ) ? $this->get_vc_image( $atts['image'], 'full' ) : '';

		$wrapper_text       = $text == '' && $title == '' && $desc == '' && $image == '' ? '' : sprintf( '<div class="col-flex-xs-12 col-flex-md-5 col-flex-lg-6"><div class="wrapper-text ">%s %s %s %s</div></div>', $title, $desc, $text, $image );
		$wrapper_scroll     = sprintf( '<div class="hidden-xs hidden-sm col-flex-md-7 col-flex-lg-6"><div class="circle-scroll">%s</div></div>', implode( ' ', $outputs ) );
		$wrapper_mobile     = sprintf( '<div class="hidden-md hidden-lg wrapper-mobile-text">%s %s</div>', $wrapper_text, implode( ' ', $outputs ) );

		return sprintf(
			'<div class="%s " id="%s">' .
			'<div class="wrapper-scroll row-flex">' .
			'%s' .
			'%s' .
			'</div>' .
			'%s' .
			'</div>',
			implode( ' ', $css_class ),
			$id,
			$wrapper_text,
			$wrapper_scroll,
			$wrapper_mobile
		);
	}

	function factora_icon_box( $atts, $content ) {

		$atts = shortcode_atts(
			array(
				'style'            => '1',
				'icon_type'        => 'svg',
				'name_icon'        => '',
				'icon_fontawesome' => '',
				'linearicons'      => '',
				'eleganticons'     => '',
				'title'            => '',
				'sub_title'        => '',
				'link'             => '',
				'el_class'         => '',
			), $atts
		);

		// Add class
		$css_class = array(
			'factora-icon-box',
			sprintf( 'style-%s', $atts['style'] ),
			$atts['el_class']
		);

		$url = ! empty( $atts['link'] ) ? vc_build_link( $atts['link'] ) : '';
		$src = $url != '' ? $url['url'] : '#';

		// Icon
		switch ( $atts['icon_type'] ) {
			case 'svg':
				$icon = ! empty( $atts['name_icon'] ) ? sprintf( "<span class='factora-icon'><svg viewBox='0 0 20 20'><use xlink:href='#%s'></use></svg></span>", $atts['name_icon'] ) : '';
				break;
			case 'awesome':
				$icon = sprintf( "<i class='%s'></i>", $atts['icon_fontawesome'] );
				break;
			case 'linear':
				$icon = sprintf( "<i class='%s'></i>", $atts['linearicons'] );
				break;
			case 'elegant':
				$icon = sprintf( "<i class='%s'></i>", $atts['eleganticons'] );
				break;
			default:
				$icon = "";
		}

		$name_icon = sprintf( '<div class="factora-icon-box--icon"><a href="%s">%s</a> </div>', $src, $icon );

		// Text
		$title      = ! empty( $atts['title'] ) ? sprintf( '<a href="%s"><h3 class="title">%s</h3></a>', $src, $atts['title'] ) : '';
		$desc       = ! empty( $content ) ? sprintf( '<div class="desc">%s</div>', $content ) : '';
		$field_text = sprintf( '<div class="factora-icon-box--text">%s %s</div>', $title, $desc );

		$outputs[] = sprintf( '<div class="factora-icon-box-wraper">' );
		$outputs[] = $name_icon;
		$outputs[] = $field_text;
		$outputs[] = sprintf( '</div>' );


		return sprintf(
			'<div class="%s">' .
			'%s' .
			'</div>',
			implode( ' ', $css_class ),
			implode( ' ', $outputs )
		);
	}

	function factora_counter( $atts, $content ) {
		$atts = shortcode_atts(
			array(
				'title'      => '',
				'number'     => '',
				'text_after' => '',
				'duration'   => '',
				'el_class'   => '',
			), $atts
		);

		// Class
		$css_class = array(
			'factora-counter',
			$atts['el_class']
		);

		// Duaration
		$duration = $atts['duration'] ? $atts['duration'] : '';

		$id = uniqid( 'factora-counter-' );

		if ( $duration != '' ):
			$this->l10n['factoraCounter'][ $id ] = array(
				'dua' => $duration,
			);
		endif;

		$field_title = isset( $atts['title'] ) && ( ! empty( $atts['title'] ) ) ? sprintf( '<p class="field-title">%s</p>', $atts['title'] ) : '';

		// Number
		$num      = ! empty( $atts['number'] ) ? sprintf( '<span class="number">%s</span>', $atts['number'] ) : '';
		$tx_after = ! empty( $atts['text_after'] ) ? sprintf( '<span class="tx_after">%s</span>', $atts['text_after'] ) : '';

		$field_text = $num == '' && $tx_after == '' ? '' : sprintf( '<div class="field-counter">%s %s</div>', $num, $tx_after );

		$outputs[] = sprintf( '<div class="factora-counter__list">' );
		$outputs[] = $field_text;
		$outputs[] = $field_title;
		$outputs[] = sprintf( '</div>' );


		return sprintf(
			'<div class="%s" id="%s">' .
			'%s' .
			'</div>',
			implode( ' ', $css_class ),
			$id,
			implode( ' ', $outputs )

		);
	}

	function factora_testimonial_carousel( $atts, $content ) {
		$atts       = shortcode_atts(
			array(
				'style'          => '1',
				'theme'          => 'light',
				'title'          => '',
				'sub_title'      => '',
				'limit'          => '3',
				'except'         => '10',
				'columns'        => '1',
				'nav'            => '',
				'dots'           => '',
				'order'          => 'DESC',
				'orderby'        => 'none',
				'autoplay'       => '',
				'autoplay_speed' => '',
				'el_class'       => '',
			), $atts
		);
		$style      = $atts['style'];
		$class_name = "factora-testimonial-carousel__" . $this->get_id_number( __FUNCTION__ );
		$css_class  = array(
			'factora-testimonial-carousel ',
			$class_name,
			$style == 1 ? $atts['theme'] : '',
			'factora-testimonial-carousel--style-' . $style,
			'factora-testimonial-' . $atts['theme'],
			$atts['el_class']
		);

		// Title
		$sub_title = ! empty( $atts['sub_title'] ) ? sprintf( '<span class="sub-title">%s </span>', $atts['sub_title'] ) : '';
		$title     = ! empty( $atts['title'] ) ? sprintf( '<h3 class="factora__section-title">%s %s</h3>', $atts['title'], $sub_title ) : '';

		$nav      = $atts['nav'] ? true : false;
		$dot      = $atts['dots'] ? true : false;
		$autoplay = $atts['autoplay'] ? true : false;

		$nav_right_icon = $style == 1 ? 'icon-chevron-right' : 'arrow_right';
		$nav_left_icon  = $style == 1 ? 'icon-chevron-left' : 'arrow_left';
		$nav_right      = sprintf( '<div class="testimonial--arrow right-arrow"><i class="%s"></i></div>', $nav_right_icon );
		$nav_left       = sprintf( '<div class="testimonial--arrow left-arrow"><i class="%s"></i></div>', $nav_left_icon );

		$arrows = sprintf( '<div class="arrows-group">%s</div>', $nav_left . $nav_right );

		$id = uniqid( 'factora-testimonial-carousel-' );

		$perrow = $atts['columns'];
		$speed  = intval( $atts['autoplay_speed'] );


		$oderby = $atts['orderby'];
		if ( $oderby == 'none' ): $oderby = ''; endif;
		$oder = $atts['order'];

		$args = array(
			'post_type'      => 'testimonial',
			'posts_per_page' => $atts['limit'],
			'order'          => $oder,
			'orderby'        => $oderby
		);

		$the_query = new WP_Query( $args );
		$outputs   = $value = $outputs_ava = array();
		$count     = 0;
		if ( $the_query->have_posts() ) :
			while ( $the_query->have_posts() ) : $the_query->the_post();
				$count ++;
				$permalink = get_permalink();
				$name      = sprintf( '<a href="%s"><span class="meta name">%s</span></a>', $permalink, get_the_title() );
				$id_testi  = get_the_ID();
				$except    = $this->factora_addons_content_limit( get_the_excerpt(), $atts['except'], '' );
				$desc      = sprintf( '<div class="field-desc">%s</div>', $except );
				$job_name  = sprintf( '<span class="meta job"> / %s</span>', get_post_meta( $id_testi, 'job_name', true ) );
				$rating    = intval( get_post_meta( $id_testi, 'job_rating', true ) );

				$star    = array();
				$counter = 0;
				while ( $counter < $rating ) {
					$star[] = '<span class="icon_star"></span>';
					$counter ++;
				}

				$thumb_size = 'factora-testimonial-thumb';

				$thumb = get_the_post_thumbnail_url( $id_testi, $thumb_size );
				$img   = sprintf( "<a href='%s'> <img alt='%s' src='%s'/></a>", $permalink, $name, $thumb );
				$image = ! empty( $thumb ) ? sprintf( '<div class="field-author--img">%s</div>', $img ) : '';

				if ( $style == '3' ) {
					$outputs_ava[] = ! empty( $thumb ) ? sprintf( '<div class="field-author--img"><img alt="%s" src="%s"/></div>', get_the_title(), $thumb ) : '';
				}
				$rating_html  = sprintf( '<div class="rating">%s</div>', implode( '', $star ) );
				$quote        = $style == '3' ? 'quote' : 'double-quotes';
				$icon         = sprintf( "<div class='field-icon fontawesome'><i class='factora-icon'><svg viewBox='0 0 20 20'><use xlink:href='#%s'></use></svg></i></div>", $quote );
				$outputs[]    = sprintf( '<div class="factora-testimonial-carousel__box">' );
				$field_author = $name == '' && $job_name == '' ? '' : sprintf( '<div class="field-author">%s<div class="field-author--text">%s %s</div></div>', $style == '1' ? $image : '', $name, $job_name );
				$outputs[]    = $style != '2' ? $icon : '';
				$outputs[]    = $style == '1' ? $field_author . $desc : '';
				$outputs[]    = $style == '2' ? $desc . $field_author : '';
				$outputs[]    = $style == '3' ? $desc . $rating_html . $field_author : '';
				$outputs[]    = $style == '2' ? $rating_html : '';
				$outputs[]    = sprintf( '</div>' );
			endwhile;
		endif;

		if ( $style != '3' ) {
			$this->l10n['testimonialCarousel'][ $id ] = array(
				'perrow'   => $perrow,
				'nav'      => $nav,
				'dot'      => $dot,
				'autoplay' => $autoplay,
				'speed'    => $speed,
				'right'    => '.right-arrow',
				'left'     => '.left-arrow',
			);
		} else {
			$this->l10n['testimonialCarousel2'][ $class_name ] = array(
				'num' => $count,
			);
		}

		$nav_ava = $outputs_ava != '' ? sprintf( '<div class="factora-testimonial-carousel__nav-img slider-nav">%s</div>', implode( '', $outputs_ava ) ) : '';
		if ( ! empty( $atts['title'] ) ) {
			$testi_header = sprintf( '<div class="testi-header">%s %s</div>', $title, ( $nav == true ) && $style != '2' ? $arrows : '' );
		} else {
			$testi_header = '';
		}

		return sprintf(
			'<div class="%s">' .
			'%s' .
			'<div id="%s" class="%s row">' .
			'%s' .
			'</div>' .
			'%s' .
			'%s' .
			'</div>',
			implode( ' ', $css_class ),
			$testi_header,
			$id,
			$style == '3' ? 'slider-for' : '',
			implode( '', $outputs ),
			$style == '2' ? $arrows : '',
			$style == '3' ? $nav_ava : ''

		);
	}
}
