<?php
/**
 * Custom functions for Visual Composer
 *
 * @package    Factora
 * @subpackage Visual Composer
 */

if ( ! function_exists( 'is_plugin_active' ) ) {
	require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
}

/**
 * Class Factora
 *
 * @since 1.0.0
 */
class Factora_VC {

	/**
	 * Temporary cached terms variable
	 *
	 * @var array
	 */
	public $terms = array();

	/**
	 * Construction
	 */
	function __construct() {
		// Stop if VC is not installed
		if ( ! is_plugin_active( 'js_composer/js_composer.php' ) ) {
			return false;
		}

		add_action( 'init', array( $this, 'map_shortcodes' ), 20 );
		add_filter( 'vc_iconpicker-type-linearicons', array( $this, 'vc_iconpicker_type_linearicons' ) );
		add_filter( 'vc_iconpicker-type-eleganticons', array( $this, 'vc_iconpicker_type_eleganticons' ) );
		add_action( 'vc_base_register_front_css', array( $this, 'vc_iconpicker_base_register_css' ) );
		add_action( 'vc_base_register_admin_css', array( $this, 'vc_iconpicker_base_register_css' ) );
		add_action( 'vc_enqueue_font_icon_element', array( $this, 'vc_icon_element_fonts_enqueue' ) );


		add_filter( 'vc_autocomplete_factora_portfolio_carousel_list_id_callback', array(
			$this,
			'portfolioIdsAutocompleteSuggester',
		), 10, 1 );
		add_filter( 'vc_autocomplete_factora_portfolio_carousel_list_id_render', array(
			$this,
			'portfolioIdsAutocompleteRender',
		), 10, 1 );

	}

	/**
	 * Suggester for autocomplete by slug
	 *
	 *
	 * @return array - id's from portfolio with title/slug.
	 */
	public function portfolioIdsAutocompleteSuggester( $query ) {
		$args = array(
			'post_type'              => 'portfolio',
			'no_found_rows'          => true,
			'update_post_term_cache' => false,
			'update_post_meta_cache' => false,
			'ignore_sticky_posts'    => true,
			's'                      => $query
		);

		$query   = new WP_Query( $args );
		$results = array();
		while ( $query->have_posts() ) : $query->the_post();
			$data          = array();
			$data['value'] = get_the_ID();
			$data['label'] = esc_html__( 'Id', 'factora' ) . ': ' . get_the_ID() . ' - ' . esc_html__( 'Title', 'factora' ) . ': ' . get_the_title();
			$results[]     = $data;

		endwhile;
		wp_reset_postdata();

		return $results;
	}

	/**
	 * Find portfolio by id
	 * @since 4.4
	 *
	 * @param $query
	 *
	 * @return bool|array
	 */
	public function portfolioIdsAutocompleteRender(
		$query
	) {
		$query = trim( $query['value'] ); // get value from requested

		if ( empty( $query ) ) {
			return false;
		}

		$args = array(
			'post_type'              => 'portfolio',
			'no_found_rows'          => true,
			'update_post_term_cache' => false,
			'update_post_meta_cache' => false,
			'ignore_sticky_posts'    => true,
			'p'                      => intval( $query )
		);

		$query = new WP_Query( $args );
		$data  = array();
		while ( $query->have_posts() ) : $query->the_post();
			$data['value'] = get_the_ID();
			$data['label'] = esc_html__( 'Id', 'factora' ) . ': ' . get_the_ID() . ' - ' . esc_html__( 'Title', 'factora' ) . ': ' . get_the_title();
		endwhile;
		wp_reset_postdata();

		return $data;

	}


	/**
	 * Enqueue icon element font
	 *
	 * @param $font
	 */
	function vc_icon_element_fonts_enqueue( $font ) {
		switch ( $font ) {
			case 'linearicons':
				wp_enqueue_style( 'linearicons' );
				break;

			case 'eleganticons':
				wp_enqueue_style( 'eleganticons' );
				break;
		}
	}

	function vc_iconpicker_base_register_css() {
		wp_enqueue_style( 'linearicons', FACTORA_ADDONS_URL . '/assets/css/linearicons.min.css', array(), '1.0.0' );
		wp_enqueue_style( 'eleganticons', FACTORA_ADDONS_URL . '/assets/css/eleganticons.min.css', array(), '1.0.0' );
	}

	function vc_iconpicker_type_linearicons( $icons ) {
		$linearicons = array(
			array( 'icon-home' => 'home' ),
			array( 'icon-home2' => 'home2' ),
			array( 'icon-home3' => 'home3' ),
			array( 'icon-home4' => 'home4' ),
			array( 'icon-home5' => 'home5' ),
			array( 'icon-home6' => 'home6' ),
			array( 'icon-bathtub' => 'bathtub' ),
			array( 'icon-toothbrush' => 'toothbrush' ),
			array( 'icon-bed' => 'bed' ),
			array( 'icon-couch' => 'couch' ),
			array( 'icon-chair' => 'chair' ),
			array( 'icon-city' => 'city' ),
			array( 'icon-apartment' => 'apartment' ),
			array( 'icon-pencil' => 'pencil' ),
			array( 'icon-pencil2' => 'pencil2' ),
			array( 'icon-pen' => 'pen' ),
			array( 'icon-pencil3' => 'pencil3' ),
			array( 'icon-eraser' => 'eraser' ),
			array( 'icon-pencil4' => 'pencil4' ),
			array( 'icon-pencil5' => 'pencil5' ),
			array( 'icon-feather' => 'feather' ),
			array( 'icon-feather2' => 'feather2' ),
			array( 'icon-feather3' => 'feather3' ),
			array( 'icon-pen2' => 'pen2' ),
			array( 'icon-pen-add' => 'pen-add' ),
			array( 'icon-pen-remove' => 'pen-remove' ),
			array( 'icon-vector' => 'vector' ),
			array( 'icon-pen3' => 'pen3' ),
			array( 'icon-blog' => 'blog' ),
			array( 'icon-brush' => 'brush' ),
			array( 'icon-brush2' => 'brush2' ),
			array( 'icon-spray' => 'spray' ),
			array( 'icon-paint-roller' => 'paint-roller' ),
			array( 'icon-stamp' => 'stamp' ),
			array( 'icon-tape' => 'tape' ),
			array( 'icon-desk-tape' => 'desk-tape' ),
			array( 'icon-texture' => 'texture' ),
			array( 'icon-eye-dropper' => 'eye-dropper' ),
			array( 'icon-palette' => 'palette' ),
			array( 'icon-color-sampler' => 'color-sampler' ),
			array( 'icon-bucket' => 'bucket' ),
			array( 'icon-gradient' => 'gradient' ),
			array( 'icon-gradient2' => 'gradient2' ),
			array( 'icon-magic-wand' => 'magic-wand' ),
			array( 'icon-magnet' => 'magnet' ),
			array( 'icon-pencil-ruler' => 'pencil-ruler' ),
			array( 'icon-pencil-ruler2' => 'pencil-ruler2' ),
			array( 'icon-compass' => 'compass' ),
			array( 'icon-aim' => 'aim' ),
			array( 'icon-gun' => 'gun' ),
			array( 'icon-bottle' => 'bottle' ),
			array( 'icon-drop' => 'drop' ),
			array( 'icon-drop-crossed' => 'drop-crossed' ),
			array( 'icon-drop2' => 'drop2' ),
			array( 'icon-snow' => 'snow' ),
			array( 'icon-snow2' => 'snow2' ),
			array( 'icon-fire' => 'fire' ),
			array( 'icon-lighter' => 'lighter' ),
			array( 'icon-knife' => 'knife' ),
			array( 'icon-dagger' => 'dagger' ),
			array( 'icon-tissue' => 'tissue' ),
			array( 'icon-toilet-paper' => 'toilet-paper' ),
			array( 'icon-poop' => 'poop' ),
			array( 'icon-umbrella' => 'umbrella' ),
			array( 'icon-umbrella2' => 'umbrella2' ),
			array( 'icon-rain' => 'rain' ),
			array( 'icon-tornado' => 'tornado' ),
			array( 'icon-wind' => 'wind' ),
			array( 'icon-fan' => 'fan' ),
			array( 'icon-contrast' => 'contrast' ),
			array( 'icon-sun-small' => 'sun-small' ),
			array( 'icon-sun' => 'sun' ),
			array( 'icon-sun2' => 'sun2' ),
			array( 'icon-moon' => 'moon' ),
			array( 'icon-cloud' => 'cloud' ),
			array( 'icon-cloud-upload' => 'cloud-upload' ),
			array( 'icon-cloud-download' => 'cloud-download' ),
			array( 'icon-cloud-rain' => 'cloud-rain' ),
			array( 'icon-cloud-hailstones' => 'cloud-hailstones' ),
			array( 'icon-cloud-snow' => 'cloud-snow' ),
			array( 'icon-cloud-windy' => 'cloud-windy' ),
			array( 'icon-sun-wind' => 'sun-wind' ),
			array( 'icon-cloud-fog' => 'cloud-fog' ),
			array( 'icon-cloud-sun' => 'cloud-sun' ),
			array( 'icon-cloud-lightning' => 'cloud-lightning' ),
			array( 'icon-cloud-sync' => 'cloud-sync' ),
			array( 'icon-cloud-lock' => 'cloud-lock' ),
			array( 'icon-cloud-gear' => 'cloud-gear' ),
			array( 'icon-cloud-alert' => 'cloud-alert' ),
			array( 'icon-cloud-check' => 'cloud-check' ),
			array( 'icon-cloud-cross' => 'cloud-cross' ),
			array( 'icon-cloud-crossed' => 'cloud-crossed' ),
			array( 'icon-cloud-database' => 'cloud-database' ),
			array( 'icon-database' => 'database' ),
			array( 'icon-database-add' => 'database-add' ),
			array( 'icon-database-remove' => 'database-remove' ),
			array( 'icon-database-lock' => 'database-lock' ),
			array( 'icon-database-refresh' => 'database-refresh' ),
			array( 'icon-database-check' => 'database-check' ),
			array( 'icon-database-history' => 'database-history' ),
			array( 'icon-database-upload' => 'database-upload' ),
			array( 'icon-database-download' => 'database-download' ),
			array( 'icon-server' => 'server' ),
			array( 'icon-shield' => 'shield' ),
			array( 'icon-shield-check' => 'shield-check' ),
			array( 'icon-shield-alert' => 'shield-alert' ),
			array( 'icon-shield-cross' => 'shield-cross' ),
			array( 'icon-lock' => 'lock' ),
			array( 'icon-rotation-lock' => 'rotation-lock' ),
			array( 'icon-unlock' => 'unlock' ),
			array( 'icon-key' => 'key' ),
			array( 'icon-key-hole' => 'key-hole' ),
			array( 'icon-toggle-off' => 'toggle-off' ),
			array( 'icon-toggle-on' => 'toggle-on' ),
			array( 'icon-cog' => 'cog' ),
			array( 'icon-cog2' => 'cog2' ),
			array( 'icon-wrench' => 'wrench' ),
			array( 'icon-screwdriver' => 'screwdriver' ),
			array( 'icon-hammer-wrench' => 'hammer-wrench' ),
			array( 'icon-hammer' => 'hammer' ),
			array( 'icon-saw' => 'saw' ),
			array( 'icon-axe' => 'axe' ),
			array( 'icon-axe2' => 'axe2' ),
			array( 'icon-shovel' => 'shovel' ),
			array( 'icon-pickaxe' => 'pickaxe' ),
			array( 'icon-factory' => 'factory' ),
			array( 'icon-factory2' => 'factory2' ),
			array( 'icon-recycle' => 'recycle' ),
			array( 'icon-trash' => 'trash' ),
			array( 'icon-trash2' => 'trash2' ),
			array( 'icon-trash3' => 'trash3' ),
			array( 'icon-broom' => 'broom' ),
			array( 'icon-game' => 'game' ),
			array( 'icon-gamepad' => 'gamepad' ),
			array( 'icon-joystick' => 'joystick' ),
			array( 'icon-dice' => 'dice' ),
			array( 'icon-spades' => 'spades' ),
			array( 'icon-diamonds' => 'diamonds' ),
			array( 'icon-clubs' => 'clubs' ),
			array( 'icon-hearts' => 'hearts' ),
			array( 'icon-heart' => 'heart' ),
			array( 'icon-star' => 'star' ),
			array( 'icon-star-half' => 'star-half' ),
			array( 'icon-star-empty' => 'star-empty' ),
			array( 'icon-flag' => 'flag' ),
			array( 'icon-flag2' => 'flag2' ),
			array( 'icon-flag3' => 'flag3' ),
			array( 'icon-mailbox-full' => 'mailbox-full' ),
			array( 'icon-mailbox-empty' => 'mailbox-empty' ),
			array( 'icon-at-sign' => 'at-sign' ),
			array( 'icon-envelope' => 'envelope' ),
			array( 'icon-envelope-open' => 'envelope-open' ),
			array( 'icon-paperclip' => 'paperclip' ),
			array( 'icon-paper-plane' => 'paper-plane' ),
			array( 'icon-reply' => 'reply' ),
			array( 'icon-reply-all' => 'reply-all' ),
			array( 'icon-inbox' => 'inbox' ),
			array( 'icon-inbox2' => 'inbox2' ),
			array( 'icon-outbox' => 'outbox' ),
			array( 'icon-box' => 'box' ),
			array( 'icon-archive' => 'archive' ),
			array( 'icon-archive2' => 'archive2' ),
			array( 'icon-drawers' => 'drawers' ),
			array( 'icon-drawers2' => 'drawers2' ),
			array( 'icon-drawers3' => 'drawers3' ),
			array( 'icon-eye' => 'eye' ),
			array( 'icon-eye-crossed' => 'eye-crossed' ),
			array( 'icon-eye-plus' => 'eye-plus' ),
			array( 'icon-eye-minus' => 'eye-minus' ),
			array( 'icon-binoculars' => 'binoculars' ),
			array( 'icon-binoculars2' => 'binoculars2' ),
			array( 'icon-hdd' => 'hdd' ),
			array( 'icon-hdd-down' => 'hdd-down' ),
			array( 'icon-hdd-up' => 'hdd-up' ),
			array( 'icon-floppy-disk' => 'floppy-disk' ),
			array( 'icon-disc' => 'disc' ),
			array( 'icon-tape2' => 'tape2' ),
			array( 'icon-printer' => 'printer' ),
			array( 'icon-shredder' => 'shredder' ),
			array( 'icon-file-empty' => 'file-empty' ),
			array( 'icon-file-add' => 'file-add' ),
			array( 'icon-file-check' => 'file-check' ),
			array( 'icon-file-lock' => 'file-lock' ),
			array( 'icon-files' => 'files' ),
			array( 'icon-copy' => 'copy' ),
			array( 'icon-compare' => 'compare' ),
			array( 'icon-folder' => 'folder' ),
			array( 'icon-folder-search' => 'folder-search' ),
			array( 'icon-folder-plus' => 'folder-plus' ),
			array( 'icon-folder-minus' => 'folder-minus' ),
			array( 'icon-folder-download' => 'folder-download' ),
			array( 'icon-folder-upload' => 'folder-upload' ),
			array( 'icon-folder-star' => 'folder-star' ),
			array( 'icon-folder-heart' => 'folder-heart' ),
			array( 'icon-folder-user' => 'folder-user' ),
			array( 'icon-folder-shared' => 'folder-shared' ),
			array( 'icon-folder-music' => 'folder-music' ),
			array( 'icon-folder-picture' => 'folder-picture' ),
			array( 'icon-folder-film' => 'folder-film' ),
			array( 'icon-scissors' => 'scissors' ),
			array( 'icon-paste' => 'paste' ),
			array( 'icon-clipboard-empty' => 'clipboard-empty' ),
			array( 'icon-clipboard-pencil' => 'clipboard-pencil' ),
			array( 'icon-clipboard-text' => 'clipboard-text' ),
			array( 'icon-clipboard-check' => 'clipboard-check' ),
			array( 'icon-clipboard-down' => 'clipboard-down' ),
			array( 'icon-clipboard-left' => 'clipboard-left' ),
			array( 'icon-clipboard-alert' => 'clipboard-alert' ),
			array( 'icon-clipboard-user' => 'clipboard-user' ),
			array( 'icon-register' => 'register' ),
			array( 'icon-enter' => 'enter' ),
			array( 'icon-exit' => 'exit' ),
			array( 'icon-papers' => 'papers' ),
			array( 'icon-news' => 'news' ),
			array( 'icon-reading' => 'reading' ),
			array( 'icon-typewriter' => 'typewriter' ),
			array( 'icon-document' => 'document' ),
			array( 'icon-document2' => 'document2' ),
			array( 'icon-graduation-hat' => 'graduation-hat' ),
			array( 'icon-license' => 'license' ),
			array( 'icon-license2' => 'license2' ),
			array( 'icon-medal-empty' => 'medal-empty' ),
			array( 'icon-medal-first' => 'medal-first' ),
			array( 'icon-medal-second' => 'medal-second' ),
			array( 'icon-medal-third' => 'medal-third' ),
			array( 'icon-podium' => 'podium' ),
			array( 'icon-trophy' => 'trophy' ),
			array( 'icon-trophy2' => 'trophy2' ),
			array( 'icon-music-note' => 'music-note' ),
			array( 'icon-music-note2' => 'music-note2' ),
			array( 'icon-music-note3' => 'music-note3' ),
			array( 'icon-playlist' => 'playlist' ),
			array( 'icon-playlist-add' => 'playlist-add' ),
			array( 'icon-guitar' => 'guitar' ),
			array( 'icon-trumpet' => 'trumpet' ),
			array( 'icon-album' => 'album' ),
			array( 'icon-shuffle' => 'shuffle' ),
			array( 'icon-repeat-one' => 'repeat-one' ),
			array( 'icon-repeat' => 'repeat' ),
			array( 'icon-headphones' => 'headphones' ),
			array( 'icon-headset' => 'headset' ),
			array( 'icon-loudspeaker' => 'loudspeaker' ),
			array( 'icon-equalizer' => 'equalizer' ),
			array( 'icon-theater' => 'theater' ),
			array( 'icon-3d-glasses' => '3d-glasses' ),
			array( 'icon-ticket' => 'ticket' ),
			array( 'icon-presentation' => 'presentation' ),
			array( 'icon-play' => 'play' ),
			array( 'icon-film-play' => 'film-play' ),
			array( 'icon-clapboard-play' => 'clapboard-play' ),
			array( 'icon-media' => 'media' ),
			array( 'icon-film' => 'film' ),
			array( 'icon-film2' => 'film2' ),
			array( 'icon-surveillance' => 'surveillance' ),
			array( 'icon-surveillance2' => 'surveillance2' ),
			array( 'icon-camera' => 'camera' ),
			array( 'icon-camera-crossed' => 'camera-crossed' ),
			array( 'icon-camera-play' => 'camera-play' ),
			array( 'icon-time-lapse' => 'time-lapse' ),
			array( 'icon-record' => 'record' ),
			array( 'icon-camera2' => 'camera2' ),
			array( 'icon-camera-flip' => 'camera-flip' ),
			array( 'icon-panorama' => 'panorama' ),
			array( 'icon-time-lapse2' => 'time-lapse2' ),
			array( 'icon-shutter' => 'shutter' ),
			array( 'icon-shutter2' => 'shutter2' ),
			array( 'icon-face-detection' => 'face-detection' ),
			array( 'icon-flare' => 'flare' ),
			array( 'icon-convex' => 'convex' ),
			array( 'icon-concave' => 'concave' ),
			array( 'icon-picture' => 'picture' ),
			array( 'icon-picture2' => 'picture2' ),
			array( 'icon-picture3' => 'picture3' ),
			array( 'icon-pictures' => 'pictures' ),
			array( 'icon-book' => 'book' ),
			array( 'icon-audio-book' => 'audio-book' ),
			array( 'icon-book2' => 'book2' ),
			array( 'icon-bookmark' => 'bookmark' ),
			array( 'icon-bookmark2' => 'bookmark2' ),
			array( 'icon-label' => 'label' ),
			array( 'icon-library' => 'library' ),
			array( 'icon-library2' => 'library2' ),
			array( 'icon-contacts' => 'contacts' ),
			array( 'icon-profile' => 'profile' ),
			array( 'icon-portrait' => 'portrait' ),
			array( 'icon-portrait2' => 'portrait2' ),
			array( 'icon-user' => 'user' ),
			array( 'icon-user-plus' => 'user-plus' ),
			array( 'icon-user-minus' => 'user-minus' ),
			array( 'icon-user-lock' => 'user-lock' ),
			array( 'icon-users' => 'users' ),
			array( 'icon-users2' => 'users2' ),
			array( 'icon-users-plus' => 'users-plus' ),
			array( 'icon-users-minus' => 'users-minus' ),
			array( 'icon-group-work' => 'group-work' ),
			array( 'icon-woman' => 'woman' ),
			array( 'icon-man' => 'man' ),
			array( 'icon-baby' => 'baby' ),
			array( 'icon-baby2' => 'baby2' ),
			array( 'icon-baby3' => 'baby3' ),
			array( 'icon-baby-bottle' => 'baby-bottle' ),
			array( 'icon-walk' => 'walk' ),
			array( 'icon-hand-waving' => 'hand-waving' ),
			array( 'icon-jump' => 'jump' ),
			array( 'icon-run' => 'run' ),
			array( 'icon-woman2' => 'woman2' ),
			array( 'icon-man2' => 'man2' ),
			array( 'icon-man-woman' => 'man-woman' ),
			array( 'icon-height' => 'height' ),
			array( 'icon-weight' => 'weight' ),
			array( 'icon-scale' => 'scale' ),
			array( 'icon-button' => 'button' ),
			array( 'icon-bow-tie' => 'bow-tie' ),
			array( 'icon-tie' => 'tie' ),
			array( 'icon-socks' => 'socks' ),
			array( 'icon-shoe' => 'shoe' ),
			array( 'icon-shoes' => 'shoes' ),
			array( 'icon-hat' => 'hat' ),
			array( 'icon-pants' => 'pants' ),
			array( 'icon-shorts' => 'shorts' ),
			array( 'icon-flip-flops' => 'flip-flops' ),
			array( 'icon-shirt' => 'shirt' ),
			array( 'icon-hanger' => 'hanger' ),
			array( 'icon-laundry' => 'laundry' ),
			array( 'icon-store' => 'store' ),
			array( 'icon-haircut' => 'haircut' ),
			array( 'icon-store-24' => 'store-24' ),
			array( 'icon-barcode' => 'barcode' ),
			array( 'icon-barcode2' => 'barcode2' ),
			array( 'icon-barcode3' => 'barcode3' ),
			array( 'icon-cashier' => 'cashier' ),
			array( 'icon-bag' => 'bag' ),
			array( 'icon-bag2' => 'bag2' ),
			array( 'icon-cart' => 'cart' ),
			array( 'icon-cart-empty' => 'cart-empty' ),
			array( 'icon-cart-full' => 'cart-full' ),
			array( 'icon-cart-plus' => 'cart-plus' ),
			array( 'icon-cart-plus2' => 'cart-plus2' ),
			array( 'icon-cart-add' => 'cart-add' ),
			array( 'icon-cart-remove' => 'cart-remove' ),
			array( 'icon-cart-exchange' => 'cart-exchange' ),
			array( 'icon-tag' => 'tag' ),
			array( 'icon-tags' => 'tags' ),
			array( 'icon-receipt' => 'receipt' ),
			array( 'icon-wallet' => 'wallet' ),
			array( 'icon-credit-card' => 'credit-card' ),
			array( 'icon-cash-dollar' => 'cash-dollar' ),
			array( 'icon-cash-euro' => 'cash-euro' ),
			array( 'icon-cash-pound' => 'cash-pound' ),
			array( 'icon-cash-yen' => 'cash-yen' ),
			array( 'icon-bag-dollar' => 'bag-dollar' ),
			array( 'icon-bag-euro' => 'bag-euro' ),
			array( 'icon-bag-pound' => 'bag-pound' ),
			array( 'icon-bag-yen' => 'bag-yen' ),
			array( 'icon-coin-dollar' => 'coin-dollar' ),
			array( 'icon-coin-euro' => 'coin-euro' ),
			array( 'icon-coin-pound' => 'coin-pound' ),
			array( 'icon-coin-yen' => 'coin-yen' ),
			array( 'icon-calculator' => 'calculator' ),
			array( 'icon-calculator2' => 'calculator2' ),
			array( 'icon-abacus' => 'abacus' ),
			array( 'icon-vault' => 'vault' ),
			array( 'icon-telephone' => 'telephone' ),
			array( 'icon-phone-lock' => 'phone-lock' ),
			array( 'icon-phone-wave' => 'phone-wave' ),
			array( 'icon-phone-pause' => 'phone-pause' ),
			array( 'icon-phone-outgoing' => 'phone-outgoing' ),
			array( 'icon-phone-incoming' => 'phone-incoming' ),
			array( 'icon-phone-in-out' => 'phone-in-out' ),
			array( 'icon-phone-error' => 'phone-error' ),
			array( 'icon-phone-sip' => 'phone-sip' ),
			array( 'icon-phone-plus' => 'phone-plus' ),
			array( 'icon-phone-minus' => 'phone-minus' ),
			array( 'icon-voicemail' => 'voicemail' ),
			array( 'icon-dial' => 'dial' ),
			array( 'icon-telephone2' => 'telephone2' ),
			array( 'icon-pushpin' => 'pushpin' ),
			array( 'icon-pushpin2' => 'pushpin2' ),
			array( 'icon-map-marker' => 'map-marker' ),
			array( 'icon-map-marker-user' => 'map-marker-user' ),
			array( 'icon-map-marker-down' => 'map-marker-down' ),
			array( 'icon-map-marker-check' => 'map-marker-check' ),
			array( 'icon-map-marker-crossed' => 'map-marker-crossed' ),
			array( 'icon-radar' => 'radar' ),
			array( 'icon-compass2' => 'compass2' ),
			array( 'icon-map' => 'map' ),
			array( 'icon-map2' => 'map2' ),
			array( 'icon-location' => 'location' ),
			array( 'icon-road-sign' => 'road-sign' ),
			array( 'icon-calendar-empty' => 'calendar-empty' ),
			array( 'icon-calendar-check' => 'calendar-check' ),
			array( 'icon-calendar-cross' => 'calendar-cross' ),
			array( 'icon-calendar-31' => 'calendar-31' ),
			array( 'icon-calendar-full' => 'calendar-full' ),
			array( 'icon-calendar-insert' => 'calendar-insert' ),
			array( 'icon-calendar-text' => 'calendar-text' ),
			array( 'icon-calendar-user' => 'calendar-user' ),
			array( 'icon-mouse' => 'mouse' ),
			array( 'icon-mouse-left' => 'mouse-left' ),
			array( 'icon-mouse-right' => 'mouse-right' ),
			array( 'icon-mouse-both' => 'mouse-both' ),
			array( 'icon-keyboard' => 'keyboard' ),
			array( 'icon-keyboard-up' => 'keyboard-up' ),
			array( 'icon-keyboard-down' => 'keyboard-down' ),
			array( 'icon-delete' => 'delete' ),
			array( 'icon-spell-check' => 'spell-check' ),
			array( 'icon-escape' => 'escape' ),
			array( 'icon-enter2' => 'enter2' ),
			array( 'icon-screen' => 'screen' ),
			array( 'icon-aspect-ratio' => 'aspect-ratio' ),
			array( 'icon-signal' => 'signal' ),
			array( 'icon-signal-lock' => 'signal-lock' ),
			array( 'icon-signal-80' => 'signal-80' ),
			array( 'icon-signal-60' => 'signal-60' ),
			array( 'icon-signal-40' => 'signal-40' ),
			array( 'icon-signal-20' => 'signal-20' ),
			array( 'icon-signal-0' => 'signal-0' ),
			array( 'icon-signal-blocked' => 'signal-blocked' ),
			array( 'icon-sim' => 'sim' ),
			array( 'icon-flash-memory' => 'flash-memory' ),
			array( 'icon-usb-drive' => 'usb-drive' ),
			array( 'icon-phone' => 'phone' ),
			array( 'icon-smartphone' => 'smartphone' ),
			array( 'icon-smartphone-notification' => 'smartphone-notification' ),
			array( 'icon-smartphone-vibration' => 'smartphone-vibration' ),
			array( 'icon-smartphone-embed' => 'smartphone-embed' ),
			array( 'icon-smartphone-waves' => 'smartphone-waves' ),
			array( 'icon-tablet' => 'tablet' ),
			array( 'icon-tablet2' => 'tablet2' ),
			array( 'icon-laptop' => 'laptop' ),
			array( 'icon-laptop-phone' => 'laptop-phone' ),
			array( 'icon-desktop' => 'desktop' ),
			array( 'icon-launch' => 'launch' ),
			array( 'icon-new-tab' => 'new-tab' ),
			array( 'icon-window' => 'window' ),
			array( 'icon-cable' => 'cable' ),
			array( 'icon-cable2' => 'cable2' ),
			array( 'icon-tv' => 'tv' ),
			array( 'icon-radio' => 'radio' ),
			array( 'icon-remote-control' => 'remote-control' ),
			array( 'icon-power-switch' => 'power-switch' ),
			array( 'icon-power' => 'power' ),
			array( 'icon-power-crossed' => 'power-crossed' ),
			array( 'icon-flash-auto' => 'flash-auto' ),
			array( 'icon-lamp' => 'lamp' ),
			array( 'icon-flashlight' => 'flashlight' ),
			array( 'icon-lampshade' => 'lampshade' ),
			array( 'icon-cord' => 'cord' ),
			array( 'icon-outlet' => 'outlet' ),
			array( 'icon-battery-power' => 'battery-power' ),
			array( 'icon-battery-empty' => 'battery-empty' ),
			array( 'icon-battery-alert' => 'battery-alert' ),
			array( 'icon-battery-error' => 'battery-error' ),
			array( 'icon-battery-low1' => 'battery-low1' ),
			array( 'icon-battery-low2' => 'battery-low2' ),
			array( 'icon-battery-low3' => 'battery-low3' ),
			array( 'icon-battery-mid1' => 'battery-mid1' ),
			array( 'icon-battery-mid2' => 'battery-mid2' ),
			array( 'icon-battery-mid3' => 'battery-mid3' ),
			array( 'icon-battery-full' => 'battery-full' ),
			array( 'icon-battery-charging' => 'battery-charging' ),
			array( 'icon-battery-charging2' => 'battery-charging2' ),
			array( 'icon-battery-charging3' => 'battery-charging3' ),
			array( 'icon-battery-charging4' => 'battery-charging4' ),
			array( 'icon-battery-charging5' => 'battery-charging5' ),
			array( 'icon-battery-charging6' => 'battery-charging6' ),
			array( 'icon-battery-charging7' => 'battery-charging7' ),
			array( 'icon-chip' => 'chip' ),
			array( 'icon-chip-x64' => 'chip-x64' ),
			array( 'icon-chip-x86' => 'chip-x86' ),
			array( 'icon-bubble' => 'bubble' ),
			array( 'icon-bubbles' => 'bubbles' ),
			array( 'icon-bubble-dots' => 'bubble-dots' ),
			array( 'icon-bubble-alert' => 'bubble-alert' ),
			array( 'icon-bubble-question' => 'bubble-question' ),
			array( 'icon-bubble-text' => 'bubble-text' ),
			array( 'icon-bubble-pencil' => 'bubble-pencil' ),
			array( 'icon-bubble-picture' => 'bubble-picture' ),
			array( 'icon-bubble-video' => 'bubble-video' ),
			array( 'icon-bubble-user' => 'bubble-user' ),
			array( 'icon-bubble-quote' => 'bubble-quote' ),
			array( 'icon-bubble-heart' => 'bubble-heart' ),
			array( 'icon-bubble-emoticon' => 'bubble-emoticon' ),
			array( 'icon-bubble-attachment' => 'bubble-attachment' ),
			array( 'icon-phone-bubble' => 'phone-bubble' ),
			array( 'icon-quote-open' => 'quote-open' ),
			array( 'icon-quote-close' => 'quote-close' ),
			array( 'icon-dna' => 'dna' ),
			array( 'icon-heart-pulse' => 'heart-pulse' ),
			array( 'icon-pulse' => 'pulse' ),
			array( 'icon-syringe' => 'syringe' ),
			array( 'icon-pills' => 'pills' ),
			array( 'icon-first-aid' => 'first-aid' ),
			array( 'icon-lifebuoy' => 'lifebuoy' ),
			array( 'icon-bandage' => 'bandage' ),
			array( 'icon-bandages' => 'bandages' ),
			array( 'icon-thermometer' => 'thermometer' ),
			array( 'icon-microscope' => 'microscope' ),
			array( 'icon-brain' => 'brain' ),
			array( 'icon-beaker' => 'beaker' ),
			array( 'icon-skull' => 'skull' ),
			array( 'icon-bone' => 'bone' ),
			array( 'icon-construction' => 'construction' ),
			array( 'icon-construction-cone' => 'construction-cone' ),
			array( 'icon-pie-chart' => 'pie-chart' ),
			array( 'icon-pie-chart2' => 'pie-chart2' ),
			array( 'icon-graph' => 'graph' ),
			array( 'icon-chart-growth' => 'chart-growth' ),
			array( 'icon-chart-bars' => 'chart-bars' ),
			array( 'icon-chart-settings' => 'chart-settings' ),
			array( 'icon-cake' => 'cake' ),
			array( 'icon-gift' => 'gift' ),
			array( 'icon-balloon' => 'balloon' ),
			array( 'icon-rank' => 'rank' ),
			array( 'icon-rank2' => 'rank2' ),
			array( 'icon-rank3' => 'rank3' ),
			array( 'icon-crown' => 'crown' ),
			array( 'icon-lotus' => 'lotus' ),
			array( 'icon-diamond' => 'diamond' ),
			array( 'icon-diamond2' => 'diamond2' ),
			array( 'icon-diamond3' => 'diamond3' ),
			array( 'icon-diamond4' => 'diamond4' ),
			array( 'icon-linearicons' => 'linearicons' ),
			array( 'icon-teacup' => 'teacup' ),
			array( 'icon-teapot' => 'teapot' ),
			array( 'icon-glass' => 'glass' ),
			array( 'icon-bottle2' => 'bottle2' ),
			array( 'icon-glass-cocktail' => 'glass-cocktail' ),
			array( 'icon-glass2' => 'glass2' ),
			array( 'icon-dinner' => 'dinner' ),
			array( 'icon-dinner2' => 'dinner2' ),
			array( 'icon-chef' => 'chef' ),
			array( 'icon-scale2' => 'scale2' ),
			array( 'icon-egg' => 'egg' ),
			array( 'icon-egg2' => 'egg2' ),
			array( 'icon-eggs' => 'eggs' ),
			array( 'icon-platter' => 'platter' ),
			array( 'icon-steak' => 'steak' ),
			array( 'icon-hamburger' => 'hamburger' ),
			array( 'icon-hotdog' => 'hotdog' ),
			array( 'icon-pizza' => 'pizza' ),
			array( 'icon-sausage' => 'sausage' ),
			array( 'icon-chicken' => 'chicken' ),
			array( 'icon-fish' => 'fish' ),
			array( 'icon-carrot' => 'carrot' ),
			array( 'icon-cheese' => 'cheese' ),
			array( 'icon-bread' => 'bread' ),
			array( 'icon-ice-cream' => 'ice-cream' ),
			array( 'icon-ice-cream2' => 'ice-cream2' ),
			array( 'icon-candy' => 'candy' ),
			array( 'icon-lollipop' => 'lollipop' ),
			array( 'icon-coffee-bean' => 'coffee-bean' ),
			array( 'icon-coffee-cup' => 'coffee-cup' ),
			array( 'icon-cherry' => 'cherry' ),
			array( 'icon-grapes' => 'grapes' ),
			array( 'icon-citrus' => 'citrus' ),
			array( 'icon-apple' => 'apple' ),
			array( 'icon-leaf' => 'leaf' ),
			array( 'icon-landscape' => 'landscape' ),
			array( 'icon-pine-tree' => 'pine-tree' ),
			array( 'icon-tree' => 'tree' ),
			array( 'icon-cactus' => 'cactus' ),
			array( 'icon-paw' => 'paw' ),
			array( 'icon-footprint' => 'footprint' ),
			array( 'icon-speed-slow' => 'speed-slow' ),
			array( 'icon-speed-medium' => 'speed-medium' ),
			array( 'icon-speed-fast' => 'speed-fast' ),
			array( 'icon-rocket' => 'rocket' ),
			array( 'icon-hammer2' => 'hammer2' ),
			array( 'icon-balance' => 'balance' ),
			array( 'icon-briefcase' => 'briefcase' ),
			array( 'icon-luggage-weight' => 'luggage-weight' ),
			array( 'icon-dolly' => 'dolly' ),
			array( 'icon-plane' => 'plane' ),
			array( 'icon-plane-crossed' => 'plane-crossed' ),
			array( 'icon-helicopter' => 'helicopter' ),
			array( 'icon-traffic-lights' => 'traffic-lights' ),
			array( 'icon-siren' => 'siren' ),
			array( 'icon-road' => 'road' ),
			array( 'icon-engine' => 'engine' ),
			array( 'icon-oil-pressure' => 'oil-pressure' ),
			array( 'icon-coolant-temperature' => 'coolant-temperature' ),
			array( 'icon-car-battery' => 'car-battery' ),
			array( 'icon-gas' => 'gas' ),
			array( 'icon-gallon' => 'gallon' ),
			array( 'icon-transmission' => 'transmission' ),
			array( 'icon-car' => 'car' ),
			array( 'icon-car-wash' => 'car-wash' ),
			array( 'icon-car-wash2' => 'car-wash2' ),
			array( 'icon-bus' => 'bus' ),
			array( 'icon-bus2' => 'bus2' ),
			array( 'icon-car2' => 'car2' ),
			array( 'icon-parking' => 'parking' ),
			array( 'icon-car-lock' => 'car-lock' ),
			array( 'icon-taxi' => 'taxi' ),
			array( 'icon-car-siren' => 'car-siren' ),
			array( 'icon-car-wash3' => 'car-wash3' ),
			array( 'icon-car-wash4' => 'car-wash4' ),
			array( 'icon-ambulance' => 'ambulance' ),
			array( 'icon-truck' => 'truck' ),
			array( 'icon-trailer' => 'trailer' ),
			array( 'icon-scale-truck' => 'scale-truck' ),
			array( 'icon-train' => 'train' ),
			array( 'icon-ship' => 'ship' ),
			array( 'icon-ship2' => 'ship2' ),
			array( 'icon-anchor' => 'anchor' ),
			array( 'icon-boat' => 'boat' ),
			array( 'icon-bicycle' => 'bicycle' ),
			array( 'icon-bicycle2' => 'bicycle2' ),
			array( 'icon-dumbbell' => 'dumbbell' ),
			array( 'icon-bench-press' => 'bench-press' ),
			array( 'icon-swim' => 'swim' ),
			array( 'icon-football' => 'football' ),
			array( 'icon-baseball-bat' => 'baseball-bat' ),
			array( 'icon-baseball' => 'baseball' ),
			array( 'icon-tennis' => 'tennis' ),
			array( 'icon-tennis2' => 'tennis2' ),
			array( 'icon-ping-pong' => 'ping-pong' ),
			array( 'icon-hockey' => 'hockey' ),
			array( 'icon-8ball' => '8ball' ),
			array( 'icon-bowling' => 'bowling' ),
			array( 'icon-bowling-pins' => 'bowling-pins' ),
			array( 'icon-golf' => 'golf' ),
			array( 'icon-golf2' => 'golf2' ),
			array( 'icon-archery' => 'archery' ),
			array( 'icon-slingshot' => 'slingshot' ),
			array( 'icon-soccer' => 'soccer' ),
			array( 'icon-basketball' => 'basketball' ),
			array( 'icon-cube' => 'cube' ),
			array( 'icon-3d-rotate' => '3d-rotate' ),
			array( 'icon-puzzle' => 'puzzle' ),
			array( 'icon-glasses' => 'glasses' ),
			array( 'icon-glasses2' => 'glasses2' ),
			array( 'icon-accessibility' => 'accessibility' ),
			array( 'icon-wheelchair' => 'wheelchair' ),
			array( 'icon-wall' => 'wall' ),
			array( 'icon-fence' => 'fence' ),
			array( 'icon-wall2' => 'wall2' ),
			array( 'icon-icons' => 'icons' ),
			array( 'icon-resize-handle' => 'resize-handle' ),
			array( 'icon-icons2' => 'icons2' ),
			array( 'icon-select' => 'select' ),
			array( 'icon-select2' => 'select2' ),
			array( 'icon-site-map' => 'site-map' ),
			array( 'icon-earth' => 'earth' ),
			array( 'icon-earth-lock' => 'earth-lock' ),
			array( 'icon-network' => 'network' ),
			array( 'icon-network-lock' => 'network-lock' ),
			array( 'icon-planet' => 'planet' ),
			array( 'icon-happy' => 'happy' ),
			array( 'icon-smile' => 'smile' ),
			array( 'icon-grin' => 'grin' ),
			array( 'icon-tongue' => 'tongue' ),
			array( 'icon-sad' => 'sad' ),
			array( 'icon-wink' => 'wink' ),
			array( 'icon-dream' => 'dream' ),
			array( 'icon-shocked' => 'shocked' ),
			array( 'icon-shocked2' => 'shocked2' ),
			array( 'icon-tongue2' => 'tongue2' ),
			array( 'icon-neutral' => 'neutral' ),
			array( 'icon-happy-grin' => 'happy-grin' ),
			array( 'icon-cool' => 'cool' ),
			array( 'icon-mad' => 'mad' ),
			array( 'icon-grin-evil' => 'grin-evil' ),
			array( 'icon-evil' => 'evil' ),
			array( 'icon-wow' => 'wow' ),
			array( 'icon-annoyed' => 'annoyed' ),
			array( 'icon-wondering' => 'wondering' ),
			array( 'icon-confused' => 'confused' ),
			array( 'icon-zipped' => 'zipped' ),
			array( 'icon-grumpy' => 'grumpy' ),
			array( 'icon-mustache' => 'mustache' ),
			array( 'icon-tombstone-hipster' => 'tombstone-hipster' ),
			array( 'icon-tombstone' => 'tombstone' ),
			array( 'icon-ghost' => 'ghost' ),
			array( 'icon-ghost-hipster' => 'ghost-hipster' ),
			array( 'icon-halloween' => 'halloween' ),
			array( 'icon-christmas' => 'christmas' ),
			array( 'icon-easter-egg' => 'easter-egg' ),
			array( 'icon-mustache2' => 'mustache2' ),
			array( 'icon-mustache-glasses' => 'mustache-glasses' ),
			array( 'icon-pipe' => 'pipe' ),
			array( 'icon-alarm' => 'alarm' ),
			array( 'icon-alarm-add' => 'alarm-add' ),
			array( 'icon-alarm-snooze' => 'alarm-snooze' ),
			array( 'icon-alarm-ringing' => 'alarm-ringing' ),
			array( 'icon-bullhorn' => 'bullhorn' ),
			array( 'icon-hearing' => 'hearing' ),
			array( 'icon-volume-high' => 'volume-high' ),
			array( 'icon-volume-medium' => 'volume-medium' ),
			array( 'icon-volume-low' => 'volume-low' ),
			array( 'icon-volume' => 'volume' ),
			array( 'icon-mute' => 'mute' ),
			array( 'icon-lan' => 'lan' ),
			array( 'icon-lan2' => 'lan2' ),
			array( 'icon-wifi' => 'wifi' ),
			array( 'icon-wifi-lock' => 'wifi-lock' ),
			array( 'icon-wifi-blocked' => 'wifi-blocked' ),
			array( 'icon-wifi-mid' => 'wifi-mid' ),
			array( 'icon-wifi-low' => 'wifi-low' ),
			array( 'icon-wifi-low2' => 'wifi-low2' ),
			array( 'icon-wifi-alert' => 'wifi-alert' ),
			array( 'icon-wifi-alert-mid' => 'wifi-alert-mid' ),
			array( 'icon-wifi-alert-low' => 'wifi-alert-low' ),
			array( 'icon-wifi-alert-low2' => 'wifi-alert-low2' ),
			array( 'icon-stream' => 'stream' ),
			array( 'icon-stream-check' => 'stream-check' ),
			array( 'icon-stream-error' => 'stream-error' ),
			array( 'icon-stream-alert' => 'stream-alert' ),
			array( 'icon-communication' => 'communication' ),
			array( 'icon-communication-crossed' => 'communication-crossed' ),
			array( 'icon-broadcast' => 'broadcast' ),
			array( 'icon-antenna' => 'antenna' ),
			array( 'icon-satellite' => 'satellite' ),
			array( 'icon-satellite2' => 'satellite2' ),
			array( 'icon-mic' => 'mic' ),
			array( 'icon-mic-mute' => 'mic-mute' ),
			array( 'icon-mic2' => 'mic2' ),
			array( 'icon-spotlights' => 'spotlights' ),
			array( 'icon-hourglass' => 'hourglass' ),
			array( 'icon-loading' => 'loading' ),
			array( 'icon-loading2' => 'loading2' ),
			array( 'icon-loading3' => 'loading3' ),
			array( 'icon-refresh' => 'refresh' ),
			array( 'icon-refresh2' => 'refresh2' ),
			array( 'icon-undo' => 'undo' ),
			array( 'icon-redo' => 'redo' ),
			array( 'icon-jump2' => 'jump2' ),
			array( 'icon-undo2' => 'undo2' ),
			array( 'icon-redo2' => 'redo2' ),
			array( 'icon-sync' => 'sync' ),
			array( 'icon-repeat-one2' => 'repeat-one2' ),
			array( 'icon-sync-crossed' => 'sync-crossed' ),
			array( 'icon-sync2' => 'sync2' ),
			array( 'icon-repeat-one3' => 'repeat-one3' ),
			array( 'icon-sync-crossed2' => 'sync-crossed2' ),
			array( 'icon-return' => 'return' ),
			array( 'icon-return2' => 'return2' ),
			array( 'icon-refund' => 'refund' ),
			array( 'icon-history' => 'history' ),
			array( 'icon-history2' => 'history2' ),
			array( 'icon-self-timer' => 'self-timer' ),
			array( 'icon-clock' => 'clock' ),
			array( 'icon-clock2' => 'clock2' ),
			array( 'icon-clock3' => 'clock3' ),
			array( 'icon-watch' => 'watch' ),
			array( 'icon-alarm2' => 'alarm2' ),
			array( 'icon-alarm-add2' => 'alarm-add2' ),
			array( 'icon-alarm-remove' => 'alarm-remove' ),
			array( 'icon-alarm-check' => 'alarm-check' ),
			array( 'icon-alarm-error' => 'alarm-error' ),
			array( 'icon-timer' => 'timer' ),
			array( 'icon-timer-crossed' => 'timer-crossed' ),
			array( 'icon-timer2' => 'timer2' ),
			array( 'icon-timer-crossed2' => 'timer-crossed2' ),
			array( 'icon-download' => 'download' ),
			array( 'icon-upload' => 'upload' ),
			array( 'icon-download2' => 'download2' ),
			array( 'icon-upload2' => 'upload2' ),
			array( 'icon-enter-up' => 'enter-up' ),
			array( 'icon-enter-down' => 'enter-down' ),
			array( 'icon-enter-left' => 'enter-left' ),
			array( 'icon-enter-right' => 'enter-right' ),
			array( 'icon-exit-up' => 'exit-up' ),
			array( 'icon-exit-down' => 'exit-down' ),
			array( 'icon-exit-left' => 'exit-left' ),
			array( 'icon-exit-right' => 'exit-right' ),
			array( 'icon-enter-up2' => 'enter-up2' ),
			array( 'icon-enter-down2' => 'enter-down2' ),
			array( 'icon-enter-vertical' => 'enter-vertical' ),
			array( 'icon-enter-left2' => 'enter-left2' ),
			array( 'icon-enter-right2' => 'enter-right2' ),
			array( 'icon-enter-horizontal' => 'enter-horizontal' ),
			array( 'icon-exit-up2' => 'exit-up2' ),
			array( 'icon-exit-down2' => 'exit-down2' ),
			array( 'icon-exit-left2' => 'exit-left2' ),
			array( 'icon-exit-right2' => 'exit-right2' ),
			array( 'icon-cli' => 'cli' ),
			array( 'icon-bug' => 'bug' ),
			array( 'icon-code' => 'code' ),
			array( 'icon-file-code' => 'file-code' ),
			array( 'icon-file-image' => 'file-image' ),
			array( 'icon-file-zip' => 'file-zip' ),
			array( 'icon-file-audio' => 'file-audio' ),
			array( 'icon-file-video' => 'file-video' ),
			array( 'icon-file-preview' => 'file-preview' ),
			array( 'icon-file-charts' => 'file-charts' ),
			array( 'icon-file-stats' => 'file-stats' ),
			array( 'icon-file-spreadsheet' => 'file-spreadsheet' ),
			array( 'icon-link' => 'link' ),
			array( 'icon-unlink' => 'unlink' ),
			array( 'icon-link2' => 'link2' ),
			array( 'icon-unlink2' => 'unlink2' ),
			array( 'icon-thumbs-up' => 'thumbs-up' ),
			array( 'icon-thumbs-down' => 'thumbs-down' ),
			array( 'icon-thumbs-up2' => 'thumbs-up2' ),
			array( 'icon-thumbs-down2' => 'thumbs-down2' ),
			array( 'icon-thumbs-up3' => 'thumbs-up3' ),
			array( 'icon-thumbs-down3' => 'thumbs-down3' ),
			array( 'icon-share' => 'share' ),
			array( 'icon-share2' => 'share2' ),
			array( 'icon-share3' => 'share3' ),
			array( 'icon-magnifier' => 'magnifier' ),
			array( 'icon-file-search' => 'file-search' ),
			array( 'icon-find-replace' => 'find-replace' ),
			array( 'icon-zoom-in' => 'zoom-in' ),
			array( 'icon-zoom-out' => 'zoom-out' ),
			array( 'icon-loupe' => 'loupe' ),
			array( 'icon-loupe-zoom-in' => 'loupe-zoom-in' ),
			array( 'icon-loupe-zoom-out' => 'loupe-zoom-out' ),
			array( 'icon-cross' => 'cross' ),
			array( 'icon-menu' => 'menu' ),
			array( 'icon-list' => 'list' ),
			array( 'icon-list2' => 'list2' ),
			array( 'icon-list3' => 'list3' ),
			array( 'icon-menu2' => 'menu2' ),
			array( 'icon-list4' => 'list4' ),
			array( 'icon-menu3' => 'menu3' ),
			array( 'icon-exclamation' => 'exclamation' ),
			array( 'icon-question' => 'question' ),
			array( 'icon-check' => 'check' ),
			array( 'icon-cross2' => 'cross2' ),
			array( 'icon-plus' => 'plus' ),
			array( 'icon-minus' => 'minus' ),
			array( 'icon-percent' => 'percent' ),
			array( 'icon-chevron-up' => 'chevron-up' ),
			array( 'icon-chevron-down' => 'chevron-down' ),
			array( 'icon-chevron-left' => 'chevron-left' ),
			array( 'icon-chevron-right' => 'chevron-right' ),
			array( 'icon-chevrons-expand-vertical' => 'chevrons-expand-vertical' ),
			array( 'icon-chevrons-expand-horizontal' => 'chevrons-expand-horizontal' ),
			array( 'icon-chevrons-contract-vertical' => 'chevrons-contract-vertical' ),
			array( 'icon-chevrons-contract-horizontal' => 'chevrons-contract-horizontal' ),
			array( 'icon-arrow-up' => 'arrow-up' ),
			array( 'icon-arrow-down' => 'arrow-down' ),
			array( 'icon-arrow-left' => 'arrow-left' ),
			array( 'icon-arrow-right' => 'arrow-right' ),
			array( 'icon-arrow-up-right' => 'arrow-up-right' ),
			array( 'icon-arrows-merge' => 'arrows-merge' ),
			array( 'icon-arrows-split' => 'arrows-split' ),
			array( 'icon-arrow-divert' => 'arrow-divert' ),
			array( 'icon-arrow-return' => 'arrow-return' ),
			array( 'icon-expand' => 'expand' ),
			array( 'icon-contract' => 'contract' ),
			array( 'icon-expand2' => 'expand2' ),
			array( 'icon-contract2' => 'contract2' ),
			array( 'icon-move' => 'move' ),
			array( 'icon-tab' => 'tab' ),
			array( 'icon-arrow-wave' => 'arrow-wave' ),
			array( 'icon-expand3' => 'expand3' ),
			array( 'icon-expand4' => 'expand4' ),
			array( 'icon-contract3' => 'contract3' ),
			array( 'icon-notification' => 'notification' ),
			array( 'icon-warning' => 'warning' ),
			array( 'icon-notification-circle' => 'notification-circle' ),
			array( 'icon-question-circle' => 'question-circle' ),
			array( 'icon-menu-circle' => 'menu-circle' ),
			array( 'icon-checkmark-circle' => 'checkmark-circle' ),
			array( 'icon-cross-circle' => 'cross-circle' ),
			array( 'icon-plus-circle' => 'plus-circle' ),
			array( 'icon-circle-minus' => 'circle-minus' ),
			array( 'icon-percent-circle' => 'percent-circle' ),
			array( 'icon-arrow-up-circle' => 'arrow-up-circle' ),
			array( 'icon-arrow-down-circle' => 'arrow-down-circle' ),
			array( 'icon-arrow-left-circle' => 'arrow-left-circle' ),
			array( 'icon-arrow-right-circle' => 'arrow-right-circle' ),
			array( 'icon-chevron-up-circle' => 'chevron-up-circle' ),
			array( 'icon-chevron-down-circle' => 'chevron-down-circle' ),
			array( 'icon-chevron-left-circle' => 'chevron-left-circle' ),
			array( 'icon-chevron-right-circle' => 'chevron-right-circle' ),
			array( 'icon-backward-circle' => 'backward-circle' ),
			array( 'icon-first-circle' => 'first-circle' ),
			array( 'icon-previous-circle' => 'previous-circle' ),
			array( 'icon-stop-circle' => 'stop-circle' ),
			array( 'icon-play-circle' => 'play-circle' ),
			array( 'icon-pause-circle' => 'pause-circle' ),
			array( 'icon-next-circle' => 'next-circle' ),
			array( 'icon-last-circle' => 'last-circle' ),
			array( 'icon-forward-circle' => 'forward-circle' ),
			array( 'icon-eject-circle' => 'eject-circle' ),
			array( 'icon-crop' => 'crop' ),
			array( 'icon-frame-expand' => 'frame-expand' ),
			array( 'icon-frame-contract' => 'frame-contract' ),
			array( 'icon-focus' => 'focus' ),
			array( 'icon-transform' => 'transform' ),
			array( 'icon-grid' => 'grid' ),
			array( 'icon-grid-crossed' => 'grid-crossed' ),
			array( 'icon-layers' => 'layers' ),
			array( 'icon-layers-crossed' => 'layers-crossed' ),
			array( 'icon-toggle' => 'toggle' ),
			array( 'icon-rulers' => 'rulers' ),
			array( 'icon-ruler' => 'ruler' ),
			array( 'icon-funnel' => 'funnel' ),
			array( 'icon-flip-horizontal' => 'flip-horizontal' ),
			array( 'icon-flip-vertical' => 'flip-vertical' ),
			array( 'icon-flip-horizontal2' => 'flip-horizontal2' ),
			array( 'icon-flip-vertical2' => 'flip-vertical2' ),
			array( 'icon-angle' => 'angle' ),
			array( 'icon-angle2' => 'angle2' ),
			array( 'icon-subtract' => 'subtract' ),
			array( 'icon-combine' => 'combine' ),
			array( 'icon-intersect' => 'intersect' ),
			array( 'icon-exclude' => 'exclude' ),
			array( 'icon-align-center-vertical' => 'align-center-vertical' ),
			array( 'icon-align-right' => 'align-right' ),
			array( 'icon-align-bottom' => 'align-bottom' ),
			array( 'icon-align-left' => 'align-left' ),
			array( 'icon-align-center-horizontal' => 'align-center-horizontal' ),
			array( 'icon-align-top' => 'align-top' ),
			array( 'icon-square' => 'square' ),
			array( 'icon-plus-square' => 'plus-square' ),
			array( 'icon-minus-square' => 'minus-square' ),
			array( 'icon-percent-square' => 'percent-square' ),
			array( 'icon-arrow-up-square' => 'arrow-up-square' ),
			array( 'icon-arrow-down-square' => 'arrow-down-square' ),
			array( 'icon-arrow-left-square' => 'arrow-left-square' ),
			array( 'icon-arrow-right-square' => 'arrow-right-square' ),
			array( 'icon-chevron-up-square' => 'chevron-up-square' ),
			array( 'icon-chevron-down-square' => 'chevron-down-square' ),
			array( 'icon-chevron-left-square' => 'chevron-left-square' ),
			array( 'icon-chevron-right-square' => 'chevron-right-square' ),
			array( 'icon-check-square' => 'check-square' ),
			array( 'icon-cross-square' => 'cross-square' ),
			array( 'icon-menu-square' => 'menu-square' ),
			array( 'icon-prohibited' => 'prohibited' ),
			array( 'icon-circle' => 'circle' ),
			array( 'icon-radio-button' => 'radio-button' ),
			array( 'icon-ligature' => 'ligature' ),
			array( 'icon-text-format' => 'text-format' ),
			array( 'icon-text-format-remove' => 'text-format-remove' ),
			array( 'icon-text-size' => 'text-size' ),
			array( 'icon-bold' => 'bold' ),
			array( 'icon-italic' => 'italic' ),
			array( 'icon-underline' => 'underline' ),
			array( 'icon-strikethrough' => 'strikethrough' ),
			array( 'icon-highlight' => 'highlight' ),
			array( 'icon-text-align-left' => 'text-align-left' ),
			array( 'icon-text-align-center' => 'text-align-center' ),
			array( 'icon-text-align-right' => 'text-align-right' ),
			array( 'icon-text-align-justify' => 'text-align-justify' ),
			array( 'icon-line-spacing' => 'line-spacing' ),
			array( 'icon-indent-increase' => 'indent-increase' ),
			array( 'icon-indent-decrease' => 'indent-decrease' ),
			array( 'icon-text-wrap' => 'text-wrap' ),
			array( 'icon-pilcrow' => 'pilcrow' ),
			array( 'icon-direction-ltr' => 'direction-ltr' ),
			array( 'icon-direction-rtl' => 'direction-rtl' ),
			array( 'icon-page-break' => 'page-break' ),
			array( 'icon-page-break2' => 'page-break2' ),
			array( 'icon-sort-alpha-asc' => 'sort-alpha-asc' ),
			array( 'icon-sort-alpha-desc' => 'sort-alpha-desc' ),
			array( 'icon-sort-numeric-asc' => 'sort-numeric-asc' ),
			array( 'icon-sort-numeric-desc' => 'sort-numeric-desc' ),
			array( 'icon-sort-amount-asc' => 'sort-amount-asc' ),
			array( 'icon-sort-amount-desc' => 'sort-amount-desc' ),
			array( 'icon-sort-time-asc' => 'sort-time-asc' ),
			array( 'icon-sort-time-desc' => 'sort-time-desc' ),
			array( 'icon-sigma' => 'sigma' ),
			array( 'icon-pencil-line' => 'pencil-line' ),
			array( 'icon-hand' => 'hand' ),
			array( 'icon-pointer-up' => 'pointer-up' ),
			array( 'icon-pointer-right' => 'pointer-right' ),
			array( 'icon-pointer-down' => 'pointer-down' ),
			array( 'icon-pointer-left' => 'pointer-left' ),
			array( 'icon-finger-tap' => 'finger-tap' ),
			array( 'icon-fingers-tap' => 'fingers-tap' ),
			array( 'icon-reminder' => 'reminder' ),
			array( 'icon-fingers-crossed' => 'fingers-crossed' ),
			array( 'icon-fingers-victory' => 'fingers-victory' ),
			array( 'icon-gesture-zoom' => 'gesture-zoom' ),
			array( 'icon-gesture-pinch' => 'gesture-pinch' ),
			array( 'icon-fingers-scroll-horizontal' => 'fingers-scroll-horizontal' ),
			array( 'icon-fingers-scroll-vertical' => 'fingers-scroll-vertical' ),
			array( 'icon-fingers-scroll-left' => 'fingers-scroll-left' ),
			array( 'icon-fingers-scroll-right' => 'fingers-scroll-right' ),
			array( 'icon-hand2' => 'hand2' ),
			array( 'icon-pointer-up2' => 'pointer-up2' ),
			array( 'icon-pointer-right2' => 'pointer-right2' ),
			array( 'icon-pointer-down2' => 'pointer-down2' ),
			array( 'icon-pointer-left2' => 'pointer-left2' ),
			array( 'icon-finger-tap2' => 'finger-tap2' ),
			array( 'icon-fingers-tap2' => 'fingers-tap2' ),
			array( 'icon-reminder2' => 'reminder2' ),
			array( 'icon-gesture-zoom2' => 'gesture-zoom2' ),
			array( 'icon-gesture-pinch2' => 'gesture-pinch2' ),
			array( 'icon-fingers-scroll-horizontal2' => 'fingers-scroll-horizontal2' ),
			array( 'icon-fingers-scroll-vertical2' => 'fingers-scroll-vertical2' ),
			array( 'icon-fingers-scroll-left2' => 'fingers-scroll-left2' ),
			array( 'icon-fingers-scroll-right2' => 'fingers-scroll-right2' ),
			array( 'icon-fingers-scroll-vertical3' => 'fingers-scroll-vertical3' ),
			array( 'icon-border-style' => 'border-style' ),
			array( 'icon-border-all' => 'border-all' ),
			array( 'icon-border-outer' => 'border-outer' ),
			array( 'icon-border-inner' => 'border-inner' ),
			array( 'icon-border-top' => 'border-top' ),
			array( 'icon-border-horizontal' => 'border-horizontal' ),
			array( 'icon-border-bottom' => 'border-bottom' ),
			array( 'icon-border-left' => 'border-left' ),
			array( 'icon-border-vertical' => 'border-vertical' ),
			array( 'icon-border-right' => 'border-right' ),
			array( 'icon-border-none' => 'border-none' ),
			array( 'icon-ellipsis' => 'ellipsis' ),
			array( 'icon-uni21' => 'uni21' ),
			array( 'icon-uni22' => 'uni22' ),
			array( 'icon-uni23' => 'uni23' ),
			array( 'icon-uni24' => 'uni24' ),
			array( 'icon-uni25' => 'uni25' ),
			array( 'icon-uni26' => 'uni26' ),
			array( 'icon-uni27' => 'uni27' ),
			array( 'icon-uni28' => 'uni28' ),
			array( 'icon-uni29' => 'uni29' ),
			array( 'icon-uni2a' => 'uni2a' ),
			array( 'icon-uni2b' => 'uni2b' ),
			array( 'icon-uni2c' => 'uni2c' ),
			array( 'icon-uni2d' => 'uni2d' ),
			array( 'icon-uni2e' => 'uni2e' ),
			array( 'icon-uni2f' => 'uni2f' ),
			array( 'icon-uni30' => 'uni30' ),
			array( 'icon-uni31' => 'uni31' ),
			array( 'icon-uni32' => 'uni32' ),
			array( 'icon-uni33' => 'uni33' ),
			array( 'icon-uni34' => 'uni34' ),
			array( 'icon-uni35' => 'uni35' ),
			array( 'icon-uni36' => 'uni36' ),
			array( 'icon-uni37' => 'uni37' ),
			array( 'icon-uni38' => 'uni38' ),
			array( 'icon-uni39' => 'uni39' ),
			array( 'icon-uni3a' => 'uni3a' ),
			array( 'icon-uni3b' => 'uni3b' ),
			array( 'icon-uni3c' => 'uni3c' ),
			array( 'icon-uni3d' => 'uni3d' ),
			array( 'icon-uni3e' => 'uni3e' ),
			array( 'icon-uni3f' => 'uni3f' ),
			array( 'icon-uni40' => 'uni40' ),
			array( 'icon-uni41' => 'uni41' ),
			array( 'icon-uni42' => 'uni42' ),
			array( 'icon-uni43' => 'uni43' ),
			array( 'icon-uni44' => 'uni44' ),
			array( 'icon-uni45' => 'uni45' ),
			array( 'icon-uni46' => 'uni46' ),
			array( 'icon-uni47' => 'uni47' ),
			array( 'icon-uni48' => 'uni48' ),
			array( 'icon-uni49' => 'uni49' ),
			array( 'icon-uni4a' => 'uni4a' ),
			array( 'icon-uni4b' => 'uni4b' ),
			array( 'icon-uni4c' => 'uni4c' ),
			array( 'icon-uni4d' => 'uni4d' ),
			array( 'icon-uni4e' => 'uni4e' ),
			array( 'icon-uni4f' => 'uni4f' ),
			array( 'icon-uni50' => 'uni50' ),
			array( 'icon-uni51' => 'uni51' ),
			array( 'icon-uni52' => 'uni52' ),
			array( 'icon-uni53' => 'uni53' ),
			array( 'icon-uni54' => 'uni54' ),
			array( 'icon-uni55' => 'uni55' ),
			array( 'icon-uni56' => 'uni56' ),
			array( 'icon-uni57' => 'uni57' ),
			array( 'icon-uni58' => 'uni58' ),
			array( 'icon-uni59' => 'uni59' ),
			array( 'icon-uni5a' => 'uni5a' ),
			array( 'icon-uni5b' => 'uni5b' ),
			array( 'icon-uni5c' => 'uni5c' ),
			array( 'icon-uni5d' => 'uni5d' ),
			array( 'icon-uni5e' => 'uni5e' ),
			array( 'icon-uni5f' => 'uni5f' ),
			array( 'icon-uni60' => 'uni60' ),
			array( 'icon-uni61' => 'uni61' ),
			array( 'icon-uni62' => 'uni62' ),
			array( 'icon-uni63' => 'uni63' ),
			array( 'icon-uni64' => 'uni64' ),
			array( 'icon-uni65' => 'uni65' ),
			array( 'icon-uni66' => 'uni66' ),
			array( 'icon-uni67' => 'uni67' ),
			array( 'icon-uni68' => 'uni68' ),
			array( 'icon-uni69' => 'uni69' ),
			array( 'icon-uni6a' => 'uni6a' ),
			array( 'icon-uni6b' => 'uni6b' ),
			array( 'icon-uni6c' => 'uni6c' ),
			array( 'icon-uni6d' => 'uni6d' ),
			array( 'icon-uni6e' => 'uni6e' ),
			array( 'icon-uni6f' => 'uni6f' ),
			array( 'icon-uni70' => 'uni70' ),
			array( 'icon-uni71' => 'uni71' ),
			array( 'icon-uni72' => 'uni72' ),
			array( 'icon-uni73' => 'uni73' ),
			array( 'icon-uni74' => 'uni74' ),
			array( 'icon-uni75' => 'uni75' ),
			array( 'icon-uni76' => 'uni76' ),
			array( 'icon-uni77' => 'uni77' ),
			array( 'icon-uni78' => 'uni78' ),
			array( 'icon-uni79' => 'uni79' ),
			array( 'icon-uni7a' => 'uni7a' ),
			array( 'icon-uni7b' => 'uni7b' ),
			array( 'icon-uni7c' => 'uni7c' ),
			array( 'icon-uni7d' => 'uni7d' ),
			array( 'icon-uni7e' => 'uni7e' ),
			array( 'icon-copyright' => 'copyright' ),
		);

		return array_merge( $icons, array( $linearicons ) );
	}

	function vc_iconpicker_type_eleganticons( $icons ) {
		$e_icons      = array(
			'arrow-up-down',
			'arrow_back',
			'arrow_carrot-2down',
			'arrow_carrot-2down_alt2',
			'arrow_carrot-2dwnn_alt',
			'arrow_carrot-2left',
			'arrow_carrot-2left_alt',
			'arrow_carrot-2left_alt2',
			'arrow_carrot-2right',
			'arrow_carrot-2right_alt',
			'arrow_carrot-2right_alt2',
			'arrow_carrot-2up',
			'arrow_carrot-2up_alt',
			'arrow_carrot-2up_alt2',
			'arrow_carrot-down',
			'arrow_carrot-down_alt',
			'arrow_carrot-down_alt2',
			'arrow_carrot-left',
			'arrow_carrot-left_alt',
			'arrow_carrot-left_alt2',
			'arrow_carrot-right',
			'arrow_carrot-right_alt',
			'arrow_carrot-right_alt2',
			'arrow_carrot-up',
			'arrow_carrot-up_alt2',
			'arrow_carrot_up_alt',
			'arrow_condense',
			'arrow_condense_alt',
			'arrow_down',
			'arrow_down_alt',
			'arrow_expand',
			'arrow_expand_alt',
			'arrow_expand_alt2',
			'arrow_expand_alt3',
			'arrow_left',
			'arrow_left-down',
			'arrow_left-down_alt',
			'arrow_left-right',
			'arrow_left-right_alt',
			'arrow_left-up',
			'arrow_left-up_alt',
			'arrow_left_alt',
			'arrow_move',
			'arrow_right',
			'arrow_right-down',
			'arrow_right-down_alt',
			'arrow_right-up',
			'arrow_right-up_alt',
			'arrow_right_alt',
			'arrow_triangle-down',
			'arrow_triangle-down_alt',
			'arrow_triangle-down_alt2',
			'arrow_triangle-left',
			'arrow_triangle-left_alt',
			'arrow_triangle-left_alt2',
			'arrow_triangle-right',
			'arrow_triangle-right_alt',
			'arrow_triangle-right_alt2',
			'arrow_triangle-up',
			'arrow_triangle-up_alt',
			'arrow_triangle-up_alt2',
			'arrow_up',
			'arrow_up-down_alt',
			'arrow_up_alt',
			'icon_adjust-horiz',
			'icon_adjust-vert',
			'icon_archive',
			'icon_archive_alt',
			'icon_bag',
			'icon_bag_alt',
			'icon_balance',
			'icon_blocked',
			'icon_book',
			'icon_book_alt',
			'icon_box-checked',
			'icon_box-empty',
			'icon_box-selected',
			'icon_briefcase',
			'icon_briefcase_alt',
			'icon_building',
			'icon_building_alt',
			'icon_calculator_alt',
			'icon_calendar',
			'icon_calulator',
			'icon_camera',
			'icon_camera_alt',
			'icon_cart',
			'icon_cart_alt',
			'icon_chat',
			'icon_chat_alt',
			'icon_check',
			'icon_check_alt',
			'icon_check_alt2',
			'icon_circle-empty',
			'icon_circle-slelected',
			'icon_clipboard',
			'icon_clock',
			'icon_clock_alt',
			'icon_close',
			'icon_close_alt',
			'icon_close_alt2',
			'icon_cloud',
			'icon_cloud-download',
			'icon_cloud-download_alt',
			'icon_cloud-upload',
			'icon_cloud-upload_alt',
			'icon_cloud_alt',
			'icon_cog',
			'icon_cogs',
			'icon_comment',
			'icon_comment_alt',
			'icon_compass',
			'icon_compass_alt',
			'icon_cone',
			'icon_cone_alt',
			'icon_contacts',
			'icon_contacts_alt',
			'icon_creditcard',
			'icon_currency',
			'icon_currency_alt',
			'icon_cursor',
			'icon_cursor_alt',
			'icon_datareport',
			'icon_datareport_alt',
			'icon_desktop',
			'icon_dislike',
			'icon_dislike_alt',
			'icon_document',
			'icon_document_alt',
			'icon_documents',
			'icon_documents_alt',
			'icon_download',
			'icon_drawer',
			'icon_drawer_alt',
			'icon_drive',
			'icon_drive_alt',
			'icon_easel',
			'icon_easel_alt',
			'icon_error-circle',
			'icon_error-circle_alt',
			'icon_error-oct',
			'icon_error-oct_alt',
			'icon_error-triangle',
			'icon_error-triangle_alt',
			'icon_film',
			'icon_floppy',
			'icon_floppy_alt',
			'icon_flowchart',
			'icon_flowchart_alt',
			'icon_folder',
			'icon_folder-add',
			'icon_folder-add_alt',
			'icon_folder-alt',
			'icon_folder-open',
			'icon_folder-open_alt',
			'icon_folder_download',
			'icon_folder_upload',
			'icon_genius',
			'icon_gift',
			'icon_gift_alt',
			'icon_globe',
			'icon_globe-2',
			'icon_globe_alt',
			'icon_grid-2x2',
			'icon_grid-3x3',
			'icon_group',
			'icon_headphones',
			'icon_heart',
			'icon_heart_alt',
			'icon_hourglass',
			'icon_house',
			'icon_house_alt',
			'icon_id',
			'icon_id-2',
			'icon_id-2_alt',
			'icon_id_alt',
			'icon_image',
			'icon_images',
			'icon_info',
			'icon_info_alt',
			'icon_key',
			'icon_key_alt',
			'icon_laptop',
			'icon_lifesaver',
			'icon_lightbulb',
			'icon_lightbulb_alt',
			'icon_like',
			'icon_like_alt',
			'icon_link',
			'icon_link_alt',
			'icon_loading',
			'icon_lock',
			'icon_lock-open',
			'icon_lock-open_alt',
			'icon_lock_alt',
			'icon_mail',
			'icon_mail_alt',
			'icon_map',
			'icon_map_alt',
			'icon_menu',
			'icon_menu-circle_alt',
			'icon_menu-circle_alt2',
			'icon_menu-square_alt',
			'icon_menu-square_alt2',
			'icon_mic',
			'icon_mic_alt',
			'icon_minus-06',
			'icon_minus-box',
			'icon_minus_alt',
			'icon_minus_alt2',
			'icon_mobile',
			'icon_mug',
			'icon_mug_alt',
			'icon_music',
			'icon_ol',
			'icon_paperclip',
			'icon_pause',
			'icon_pause_alt',
			'icon_pause_alt2',
			'icon_pencil',
			'icon_pencil-edit',
			'icon_pencil-edit_alt',
			'icon_pencil_alt',
			'icon_pens',
			'icon_pens_alt',
			'icon_percent',
			'icon_percent_alt',
			'icon_phone',
			'icon_piechart',
			'icon_pin',
			'icon_pin_alt',
			'icon_plus',
			'icon_plus-box',
			'icon_plus_alt',
			'icon_plus_alt2',
			'icon_printer',
			'icon_printer-alt',
			'icon_profile',
			'icon_pushpin',
			'icon_pushpin_alt',
			'icon_puzzle',
			'icon_puzzle_alt',
			'icon_question',
			'icon_question_alt',
			'icon_question_alt2',
			'icon_quotations',
			'icon_quotations_alt',
			'icon_quotations_alt2',
			'icon_refresh',
			'icon_ribbon',
			'icon_ribbon_alt',
			'icon_rook',
			'icon_search',
			'icon_search-2',
			'icon_search_alt',
			'icon_shield',
			'icon_shield_alt',
			'icon_star',
			'icon_star-half',
			'icon_star-half_alt',
			'icon_star_alt',
			'icon_stop',
			'icon_stop_alt',
			'icon_stop_alt2',
			'icon_table',
			'icon_tablet',
			'icon_tag',
			'icon_tag_alt',
			'icon_tags',
			'icon_tags_alt',
			'icon_target',
			'icon_tool',
			'icon_toolbox',
			'icon_toolbox_alt',
			'icon_tools',
			'icon_trash',
			'icon_trash_alt',
			'icon_ul',
			'icon_upload',
			'icon_vol-mute',
			'icon_vol-mute_alt',
			'icon_volume-high',
			'icon_volume-high_alt',
			'icon_volume-low',
			'icon_volume-low_alt',
			'icon_wallet',
			'icon_wallet_alt',
			'icon_zoom-in',
			'icon_zoom-in_alt',
			'icon_zoom-out',
			'icon_zoom-out_alt',
			'social_blogger',
			'social_blogger_circle',
			'social_blogger_square',
			'social_delicious',
			'social_delicious_circle',
			'social_delicious_square',
			'social_deviantart',
			'social_deviantart_circle',
			'social_deviantart_square',
			'social_dribbble',
			'social_dribbble_circle',
			'social_dribbble_square',
			'social_facebook',
			'social_facebook_circle',
			'social_facebook_square',
			'social_flickr',
			'social_flickr_circle',
			'social_flickr_square',
			'social_googledrive',
			'social_googledrive_alt2',
			'social_googledrive_square',
			'social_googleplus',
			'social_googleplus_circle',
			'social_googleplus_square',
			'social_instagram',
			'social_instagram_circle',
			'social_instagram_square',
			'social_linkedin',
			'social_linkedin_circle',
			'social_linkedin_square',
			'social_myspace',
			'social_myspace_circle',
			'social_myspace_square',
			'social_picassa',
			'social_picassa_circle',
			'social_picassa_square',
			'social_pinterest',
			'social_pinterest_circle',
			'social_pinterest_square',
			'social_rss',
			'social_rss_circle',
			'social_rss_square',
			'social_share',
			'social_share_circle',
			'social_share_square',
			'social_skype',
			'social_skype_circle',
			'social_skype_square',
			'social_spotify',
			'social_spotify_circle',
			'social_spotify_square',
			'social_stumbleupon_circle',
			'social_stumbleupon_square',
			'social_tumbleupon',
			'social_tumblr',
			'social_tumblr_circle',
			'social_tumblr_square',
			'social_twitter',
			'social_twitter_circle',
			'social_twitter_square',
			'social_vimeo',
			'social_vimeo_circle',
			'social_vimeo_square',
			'social_wordpress',
			'social_wordpress_circle',
			'social_wordpress_square',
			'social_youtube',
			'social_youtube_circle',
			'social_youtube_square ',
		);
		$eleganticons = array();

		foreach ( $e_icons as $e_icon ) {
			$eleganticons[][ $e_icon ] = $e_icon;
		}

		return array_merge( $icons, array( $eleganticons ) );
	}

	/**
	 * Add new params or add new shortcode to VC
	 *
	 * @since 1.0
	 *
	 * @return void
	 */
	function map_shortcodes() {

		$attributes = array(
			array(
				'type'        => 'colorpicker',
				'heading'     => esc_html__( 'Overlay', 'factora' ),
				'param_name'  => 'overlay',
				'group'       => esc_html__( 'Design Options', 'factora' ),
				'value'       => '',
				'description' => esc_html__( 'Select an overlay color for this row', 'factora' ),
			),
		);
		vc_add_params( 'vc_row', $attributes );

		// Empty Space
		vc_map(
			array(
				'name'     => esc_html__( 'Factora Empty Space', 'factora' ),
				'base'     => 'factora_empty_space',
				'class'    => '',
				'category' => esc_html__( 'Factora', 'factora' ),
				'params'   => array(
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Height(px)', 'factora' ),
						'param_name'  => 'height',
						'admin_label' => true,
						'description' => esc_html__( 'Enter empty space height on Desktop.', 'factora' )
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Height on Tablet(px)', 'factora' ),
						'param_name'  => 'height_tablet',
						'admin_label' => true,
						'description' => esc_html__( 'Enter empty space height on Mobile. Leave empty to use the height of the desktop', 'factora' )
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Height on Mobile(px)', 'factora' ),
						'param_name'  => 'height_mobile',
						'admin_label' => true,
						'description' => esc_html__( 'Enter empty space height on Mobile. Leave empty to use the height of the tablet', 'factora' )
					),
					array(
						'type'       => 'colorpicker',
						'heading'    => esc_html__( 'Background Color', 'factora' ),
						'param_name' => 'bg_color',
						'value'      => '',
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'factora' ),
						'param_name'  => 'el_class',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'factora' ),
					),
				),
			)
		);

		// Section Title
		vc_map(
			array(
				'name'     => esc_html__( 'Factora Section title', 'factora' ),
				'base'     => 'factora_section_title',
				'class'    => '',
				'category' => esc_html__( 'Factora', 'factora' ),
				'params'   => array(
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Style', 'factora' ),
						'param_name' => 'style',
						'value'      => array(
							esc_html__( 'Style 1', 'factora' ) => '1',
							esc_html__( 'Style 2', 'factora' ) => '2',
							esc_html__( 'Style 3', 'factora' ) => '3',
						),
					),
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Color', 'factora' ),
						'param_name' => 'color',
						'value'      => array(
							esc_html__( 'Dark', 'factora' )  => 'dark',
							esc_html__( 'Light', 'factora' ) => 'light',
						),
					),
					array(
						'heading'     => esc_html__( 'Title', 'factora' ),
						'type'        => 'textfield',
						'param_name'  => 'title',
						'value'       => '',
						'admin_label' => true,
					),
					array(
						'heading'     => esc_html__( 'After Title', 'factora' ),
						'type'        => 'textfield',
						'param_name'  => 'second_title',
						'value'       => '',
						'admin_label' => true,
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'factora' ),
						'param_name'  => 'el_class',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'factora' ),
					),
				),
			)
		);

		// Countdown
		vc_map(
			array(
				'name'     => esc_html__( 'Factora Countdown', 'factora' ),
				'base'     => 'factora_countdown',
				'class'    => '',
				'category' => esc_html__( 'Factora', 'factora' ),
				'params'   => array(
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Date', 'factora' ),
						'param_name'  => 'date',
						'value'       => '',
						'description' => esc_html__( 'Enter the date by format: YYYY-MM-DD', 'factora' ),
					),
					array(
						'heading'    => esc_html__( 'Text Color', 'factora' ),
						'param_name' => 'text_color',
						'type'       => 'dropdown',
						'value'      => array(
							esc_html__( 'Light', 'factora' ) => 'light',
							esc_html__( 'Dark', 'factora' )  => 'dark',
						),
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'factora' ),
						'param_name'  => 'el_class',
						'value'       => '',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file . ', 'factora' ),
					),
				),
			)
		);

		//  Map Box
		vc_map(
			array(
				'name'     => esc_html__( 'Factora Map', 'factora' ),
				'base'     => 'factora_map',
				'class'    => '',
				'category' => esc_html__( 'Factora', 'factora' ),
				'params'   => array(

					array(
						'type'        => 'attach_image',
						'heading'     => esc_html__( 'Marker', 'factora' ),
						'param_name'  => 'marker',
						'value'       => '',
						'description' => esc_html__( 'Choose an image from media library', 'factora' ),
					),

					array(
						'heading'     => esc_html__( 'Token', 'factora' ),
						'type'        => 'textfield',
						'param_name'  => 'token',
						'value'       => '',
						'description' => sprintf( __( 'Please go to <a href="%s" target="_blank">Maps Box APIs</a> to get a key', 'factora' ), esc_url( 'https://www.mapbox.com' ) ),
					),

					array(
						'heading'          => esc_html__( 'Local', 'factora' ),
						'type'             => 'textfield',
						'param_name'       => 'local',
						'value'            => '',
						'edit_field_class' => 'vc_col-xs-6',
						'description'      => esc_attr__( 'Example: New York, United States...', 'factora' ),
					),

					array(
						'heading'     => esc_html__( 'Height Map', 'factora' ),
						'type'        => 'textfield',
						'param_name'  => 'height',
						'value'       => '',
						'group'       => esc_html__( 'Style', 'factora' ),
						'description' => esc_attr__( 'Example: 500, 600,... (px)', 'factora' ),
					),

					array(
						'heading'          => esc_html__( 'Color Water', 'factora' ),
						'type'             => 'colorpicker',
						'param_name'       => 'color_1',
						'value'            => '',
						'edit_field_class' => 'vc_col-xs-6',
						'group'            => esc_html__( 'Style', 'factora' ),
					),

					array(
						'heading'          => esc_html__( 'Color Building', 'factora' ),
						'type'             => 'colorpicker',
						'param_name'       => 'color_2',
						'value'            => '',
						'edit_field_class' => 'vc_col-xs-6',
						'group'            => esc_html__( 'Style', 'factora' ),
					),

					array(
						'heading'          => esc_html__( 'Zoom Map', 'factora' ),
						'type'             => 'textfield',
						'param_name'       => 'zoom',
						'value'            => '',
						'edit_field_class' => 'vc_col-xs-6',
						'description'      => esc_attr__( 'Example: 9,10,11...', 'factora' ),
					),

					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'factora' ),
						'param_name'  => 'el_class',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'factora' ),
					),
				),
			)
		);

		// Contact Form 7
		$mail_forms    = get_posts( 'post_type=wpcf7_contact_form&posts_per_page=-1' );
		$mail_form_ids = array(
			esc_html__( 'Select Form', 'factora' ) => '',
		);
		foreach ( $mail_forms as $form ) {
			$mail_form_ids[ $form->post_title ] = $form->ID;
		}
		vc_map(
			array(
				'name'     => esc_html__( 'Factora Contact Form 7', 'factora' ),
				'base'     => 'factora_contact_form_7',
				'class'    => '',
				'category' => esc_html__( 'Factora', 'factora' ),
				'params'   => array(
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Style Version', 'factora' ),
						'param_name' => 'style',
						'value'      => array(
							esc_html__( 'Style 1', 'factora' )  => '1',
							esc_html__( 'Style 2 ', 'factora' ) => '2',
						),
					),

					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Button Style', 'factora' ),
						'param_name' => 'btn_style',
						'value'      => array(
							esc_html__( 'Default', 'factora' ) => 'default',
							esc_html__( 'Full ', 'factora' )   => 'full',
						),
					),

					array(
						'heading'     => esc_html__( 'Title', 'factora' ),
						'type'        => 'textfield',
						'param_name'  => 'title',
						'value'       => '',
						'admin_label' => true,
					),

					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Contact Form 7', 'factora' ),
						'param_name' => 'form',
						'value'      => $mail_form_ids,
					),

					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'factora' ),
						'param_name'  => 'el_class',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'factora' ),
					),
				),
			)
		);

		// Button
		vc_map(
			array(
				'name'     => esc_html__( 'Factora Button', 'factora' ),
				'base'     => 'factora_button',
				'class'    => '',
				'category' => esc_html__( 'Factora', 'factora' ),
				'params'   => array(
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Style', 'factora' ),
						'param_name' => 'style',
						'value'      => array(
							esc_html__( 'Primary', 'factora' ) => 'primary',
							esc_html__( 'Dark', 'factora' )    => 'dark',
							esc_html__( 'Normal', 'factora' )  => 'normal',
						),
					),

					array(
						'type'        => 'vc_link',
						'heading'     => esc_html__( 'Link (URL)', 'factora' ),
						'param_name'  => 'link',
						'value'       => '',
						'description' => esc_html__( 'Enter information If you want show button', 'factora' ),
					),

					array(
						'type'       => 'colorpicker',
						'heading'    => esc_html__( 'Color Button', 'factora' ),
						'param_name' => 'color',
						'value'      => '',
						'dependency' => array(
							'element' => 'style',
							'value'   => 'normal',
						),
					),

					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Text Align', 'factora' ),
						'param_name' => 'align',
						'value'      => array(
							esc_html__( 'Left', 'factora' )   => 'left',
							esc_html__( 'Center', 'factora' ) => 'center',
							esc_html__( 'Right', 'factora' )  => 'right',
						),
					),

					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Icon', 'factora' ),
						'param_name' => 'icon',
						'value'      => array(
							esc_html__( 'None', 'factora' )             => 'none',
							esc_html__( 'Fontawesome Icon', 'factora' ) => 'awesome',
							esc_html__( 'Linear Icon', 'factora' )      => 'linear',
							esc_html__( 'Elegant Icon', 'factora' )     => 'elegant',
						),
					),

					array(
						'heading'     => esc_html__( 'Icon', 'factora' ),
						'description' => esc_html__( 'Pick an icon from library.', 'factora' ),
						'type'        => 'iconpicker',
						'param_name'  => 'icon_fontawesome',
						'value'       => 'fa fa-adjust',
						'settings'    => array(
							'emptyIcon'    => false,
							'iconsPerPage' => 4000,
						),
						'dependency'  => array(
							'element' => 'icon',
							'value'   => 'awesome',
						),
					),

					array(
						'heading'     => esc_html__( 'Linearicons', 'factora' ),
						'description' => esc_html__( 'Select icon from library.', 'factora' ),
						'type'        => 'iconpicker',
						'param_name'  => 'linearicons',
						'value'       => 'icon-home',
						'settings'    => array(
							'emptyIcon'    => false,
							'iconsPerPage' => 4000,
							'type'         => 'linearicons',
						),
						'dependency'  => array(
							'element' => 'icon',
							'value'   => 'linear',
						),
					),

					array(
						'heading'     => esc_html__( 'Eleganticons', 'factora' ),
						'description' => esc_html__( 'Select icon from library.', 'factora' ),
						'type'        => 'iconpicker',
						'param_name'  => 'eleganticons',
						'value'       => 'icon-home',
						'settings'    => array(
							'emptyIcon'    => false,
							'iconsPerPage' => 4000,
							'type'         => 'eleganticons',
						),
						'dependency'  => array(
							'element' => 'icon',
							'value'   => 'elegant',
						),
					),

					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'factora' ),
						'param_name'  => 'el_class',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'factora' ),
					),
				),
			)
		);

		// Latest Post
		vc_map(
			array(
				'name'     => esc_html__( 'Factora Latest Post', 'factora' ),
				'base'     => 'factora_latest_post',
				'class'    => '',
				'category' => esc_html__( 'Factora', 'factora' ),
				'params'   => array(
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Style', 'factora' ),
						'param_name' => 'style',
						'value'      => array(
							esc_html__( 'Grid', 'factora' ) => 'grid',
							esc_html__( 'List', 'factora' ) => 'list',
						),
					),

					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Number of Posts', 'factora' ),
						'param_name'  => 'limit',
						'value'       => '3',
						'description' => esc_html__( 'Set numbers of Posts you want to display. Set -1 -> show all post', 'factora' ),
					),

					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'factora' ),
						'param_name'  => 'el_class',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'factora' ),
					),
				),
			)
		);

		// Testimonial Carousel
		vc_map(
			array(
				'name'     => esc_html__( 'Factora Testimonial Carousel', 'factora' ),
				'base'     => 'factora_testimonial_carousel',
				'class'    => '',
				'category' => esc_html__( 'Factora', 'factora' ),
				'params'   => array(
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Style', 'factora' ),
						'param_name' => 'style',
						'value'      => array(
							esc_html__( 'Style 1', 'factora' ) => '1',
							esc_html__( 'Style 2', 'factora' ) => '2',
							esc_html__( 'Style 3', 'factora' ) => '3',
						),
					),

					array(
						'heading'          => esc_html__( 'Title', 'factora' ),
						'type'             => 'textfield',
						'value'            => '',
						'param_name'       => 'title',
						'edit_field_class' => 'vc_col-xs-6',

					),
					array(
						'heading'          => esc_html__( 'Sub Title', 'factora' ),
						'type'             => 'textfield',
						'value'            => '',
						'param_name'       => 'sub_title',
						'edit_field_class' => 'vc_col-xs-6',

					),

					array(
						'type'             => 'dropdown',
						'heading'          => esc_html__( 'Theme', 'factora' ),
						'param_name'       => 'theme',
						'value'            => array(
							esc_html__( 'Light', 'factora' ) => 'light',
							esc_html__( 'Dark', 'factora' )  => 'dark',
						),
						'dependency'       => array(
							'element' => 'style',
							'value'   => array( '1', '3' ),
						),
						'edit_field_class' => 'vc_col-xs-6',

					),

					array(
						'type'             => 'dropdown',
						'heading'          => esc_html__( 'Order', 'factora' ),
						'param_name'       => 'order',
						'value'            => array(
							esc_html__( 'DESC', 'factora' ) => 'DESC',
							esc_html__( 'ASC', 'factora' )  => 'ASC',
						),
						'edit_field_class' => 'vc_col-xs-6',

					),
					array(
						'type'             => 'dropdown',
						'heading'          => esc_html__( 'Order by', 'factora' ),
						'param_name'       => 'orderby',
						'value'            => array(
							esc_html__( 'None', 'factora' )   => 'none',
							esc_html__( 'Name', 'factora' )   => 'title',
							esc_html__( 'Random', 'factora' ) => 'ran',
							esc_html__( 'ID', 'factora' )     => 'id',
						),
						'edit_field_class' => 'vc_col-xs-6',

					),

					array(
						'type'             => 'textfield',
						'heading'          => esc_html__( 'Number of Posts', 'factora' ),
						'param_name'       => 'limit',
						'value'            => '3',
						'description'      => esc_html__( 'Set numbers of Posts you want to display. Set -1 -> show all post', 'factora' ),
						'edit_field_class' => 'vc_col-xs-6',

					),
					array(
						'type'             => 'textfield',
						'heading'          => esc_html__( 'Except content limit', 'factora' ),
						'param_name'       => 'except',
						'value'            => '10',
						'description'      => esc_html__( 'Set numbers of Posts you want to display. Set -1 -> show all post', 'factora' ),
						'edit_field_class' => 'vc_col-xs-6',

					),
					array(
						'type'             => 'dropdown',
						'heading'          => esc_html__( 'Columns', 'factora' ),
						'param_name'       => 'columns',
						'value'            => array(
							esc_html__( '1 Columns', 'factora' ) => '1',
							esc_html__( '2 Columns', 'factora' ) => '2',
							esc_html__( '3 Columns', 'factora' ) => '3',
						),
						'edit_field_class' => 'vc_col-xs-6',
					),

					array(
						'type'             => 'checkbox',
						'heading'          => esc_html__( 'Nav', 'factora' ),
						'param_name'       => 'nav',
						'value'            => array( esc_html__( 'Yes', 'factora' ) => '1' ),
						'description'      => esc_html__( 'If "YES" show arrow', 'factora' ),
						'edit_field_class' => 'vc_col-xs-4',
						'group'            => esc_html__( 'Setting carousel', 'factora' ),
					),
					array(
						'type'             => 'checkbox',
						'heading'          => esc_html__( 'Dots', 'factora' ),
						'param_name'       => 'dots',
						'value'            => array( esc_html__( 'Yes', 'factora' ) => '1' ),
						'description'      => esc_html__( 'If "YES" show dots', 'factora' ),
						'edit_field_class' => 'vc_col-xs-4',
						'group'            => esc_html__( 'Setting carousel', 'factora' ),
					),

					array(
						'type'             => 'checkbox',
						'heading'          => esc_html__( 'Autoplay', 'factora' ),
						'param_name'       => 'autoplay',
						'value'            => array( esc_html__( 'Yes', 'factora' ) => 'yes' ),
						'description'      => esc_html__( 'If "YES" Enable autoplay', 'factora' ),
						'edit_field_class' => 'vc_col-xs-4',
						'group'            => esc_html__( 'Setting carousel', 'factora' ),

					),

					array(
						'type'             => 'textfield',
						'heading'          => esc_html__( 'Autoplay speed', 'factora' ),
						'param_name'       => 'autoplay_speed',
						'value'            => '2000',
						'description'      => esc_html__( 'Set auto play speed (in ms).', 'factora' ),
						'dependency'       => array(
							'element' => 'autoplay',
							'value'   => array( 'yes' ),
						),
						'edit_field_class' => 'vc_col-xs-4',
						'group'            => esc_html__( 'Setting carousel', 'factora' ),
					),

					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'factora' ),
						'param_name'  => 'el_class',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'factora' ),
					),
				),
			)
		);

		// Icons Box Scroll
		vc_map(
			array(
				'name'     => esc_html__( 'Icons Box Scoll', 'factora' ),
				'base'     => 'factora_icon_box_scroll',
				'class'    => '',
				'category' => esc_html__( 'Factora', 'factora' ),
				'params'   => array(
					array(
						'heading'    => esc_html__( 'Title', 'factora' ),
						'type'       => 'textfield',
						'value'      => '',
						'param_name' => 'title',
					),

					array(
						'heading'    => esc_html__( 'Description', 'factora' ),
						'type'       => 'textarea',
						'value'      => '',
						'param_name' => 'desc',
					),

					array(
						'heading'          => esc_html__( 'Text', 'factora' ),
						'type'             => 'textfield',
						'value'            => '',
						'param_name'       => 'text',
						'edit_field_class' => 'vc_col-xs-6',
					),

					array(
						'heading'          => esc_html__( 'After text ', 'factora' ),
						'type'             => 'textfield',
						'value'            => '',
						'param_name'       => 'af_text',
						'edit_field_class' => 'vc_col-xs-6',
					),

					array(
						'type'        => 'attach_image',
						'heading'     => esc_html__( 'Image', 'factora' ),
						'param_name'  => 'image',
						'value'       => '',
						'description' => esc_html__( 'Choose an image from media library', 'factora' ),
					),

					array(
						'type'       => 'param_group',
						'heading'    => esc_html__( 'List Icon Box', 'factora' ),
						'value'      => '',
						'param_name' => 'setting',
						'params'     => array(
							array(
								'type'       => 'dropdown',
								'heading'    => esc_html__( 'Icon', 'factora' ),
								'param_name' => 'icon',
								'value'      => array(
									esc_html__( 'SVG Icon', 'factora' )         => 'svg',
									esc_html__( 'Fontawesome Icon', 'factora' ) => 'awesome',
									esc_html__( 'Linear Icon', 'factora' )      => 'linear',
									esc_html__( 'Elegant Icon', 'factora' )     => 'elegant',
								),
							),

							array(
								'type'       => 'textfield',
								'heading'    => esc_html__( 'SVG Icon name', 'factora' ),
								'param_name' => 'name_icon',
								'value'      => '',
								'dependency' => array(
									'element' => 'icon',
									'value'   => 'svg',
								),
							),

							array(
								'heading'     => esc_html__( 'Icon', 'factora' ),
								'description' => esc_html__( 'Pick an icon from library.', 'factora' ),
								'type'        => 'iconpicker',
								'param_name'  => 'icon_fontawesome',
								'value'       => 'fa fa-adjust',
								'settings'    => array(
									'emptyIcon'    => false,
									'iconsPerPage' => 4000,
								),
								'dependency'  => array(
									'element' => 'icon',
									'value'   => 'awesome',
								),
							),

							array(
								'heading'     => esc_html__( 'Linearicons', 'factora' ),
								'description' => esc_html__( 'Select icon from library.', 'factora' ),
								'type'        => 'iconpicker',
								'param_name'  => 'linearicons',
								'value'       => 'icon-home',
								'settings'    => array(
									'emptyIcon'    => false,
									'iconsPerPage' => 4000,
									'type'         => 'linearicons',
								),
								'dependency'  => array(
									'element' => 'icon',
									'value'   => 'linear',
								),
							),

							array(
								'heading'     => esc_html__( 'Eleganticons', 'factora' ),
								'description' => esc_html__( 'Select icon from library.', 'factora' ),
								'type'        => 'iconpicker',
								'param_name'  => 'eleganticons',
								'value'       => 'icon-home',
								'settings'    => array(
									'emptyIcon'    => false,
									'iconsPerPage' => 4000,
									'type'         => 'eleganticons',
								),
								'dependency'  => array(
									'element' => 'icon',
									'value'   => 'elegant',
								),
							),

							array(
								'type'        => 'textfield',
								'heading'     => esc_html__( 'Title', 'factora' ),
								'param_name'  => 'title',
								'value'       => '',
								'admin_label' => true,
							),

							array(
								'type'       => 'textarea',
								'heading'    => esc_html__( 'Description', 'factora' ),
								'param_name' => 'desc',
								'value'      => '',
							),

							array(
								'type'       => 'vc_link',
								'heading'    => esc_html__( 'Link (URL)', 'factora' ),
								'param_name' => 'link',
								'value'      => '',
							),
						),
					),

					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'factora' ),
						'param_name'  => 'el_class',
						'value'       => '',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file . ', 'factora' ),
					),
				),
			)
		);

		vc_map(
			array(
				'name'     => esc_html__( 'Images Carousel', 'factora' ),
				'base'     => 'factora_images_carousel',
				'class'    => '',
				'category' => esc_html__( 'Factora', 'factora' ),
				'params'   => array(

					array(
						'type'       => 'attach_images',
						'heading'    => esc_html__( 'Images', 'factora' ),
						'param_name' => 'images',
						'value'      => '',
					),
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Columns', 'factora' ),
						'param_name' => 'columns',
						'value'      => array(
							esc_html__( '1 Column', 'factora' )  => '1',
							esc_html__( '2 Columns', 'factora' ) => '2',
							esc_html__( '3 Columns', 'factora' ) => '3',
							esc_html__( '4 Columns', 'factora' ) => '4',
							esc_html__( '5 Columns', 'factora' ) => '5',
							esc_html__( '6 Columns', 'factora' ) => '6',
						),
					),
					array(
						'heading'     => esc_html__( 'Image size', 'factora' ),
						'description' => esc_html__( 'Enter image size. Example: "thumbnail", "medium", "large", "full" or other sizes defined by current theme. Alternatively enter image size in pixels: 200x100 (Width x Height). Leave empty to use "thumbnail" size.', 'factora' ),
						'type'        => 'textfield',
						'param_name'  => 'image_size',
						'value'       => '',
					),
					// Slide Option
					array(
						'type'             => 'checkbox',
						'heading'          => esc_html__( 'Show Nav', 'factora' ),
						'param_name'       => 'nav',
						'value'            => array( esc_html__( 'Yes', 'factora' ) => '1' ),
						'edit_field_class' => 'vc_col-xs-6',
						'group'            => esc_html__( 'Slide Option', 'factora' ),
					),
					array(
						'type'             => 'checkbox',
						'heading'          => esc_html__( 'Autoplay', 'factora' ),
						'param_name'       => 'autoplay',
						'value'            => array( esc_html__( 'Yes', 'factora' ) => '1' ),
						'edit_field_class' => 'vc_col-xs-6',
						'group'            => esc_html__( 'Slide Option', 'factora' ),
					),
					array(
						'type'             => 'textfield',
						'heading'          => esc_html__( 'Autoplay Speed', 'factora' ),
						'param_name'       => 'autoplay_speed',
						'value'            => 2000,
						'description'      => esc_html__( 'Autoplay Speed in milliseconds', 'factora' ),
						'edit_field_class' => 'vc_col-xs-6',
						'dependency'       => array(
							'element' => 'autoplay',
							'value'   => '1',
						),
						'group'            => esc_html__( 'Slide Option', 'factora' ),
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'factora' ),
						'param_name'  => 'el_class',
						'value'       => '',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file . ', 'factora' ),
					),
				),
			)
		);
		vc_map(
			array(
				'name'     => esc_html__( 'Factora Social', 'factora' ),
				'base'     => 'factora_social',
				'class'    => '',
				'category' => esc_html__( 'Factora', 'factora' ),
				'params'   => array(

					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Title', 'factora' ),
						'param_name'  => 'el_class',
						'value'       => '',
						'admin_label' => true,
					),

					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Style', 'factora' ),
						'param_name' => 'style',
						'value'      => array(
							esc_html__( 'Style 1', 'factora' ) => '1',
							esc_html__( 'Style 2', 'factora' ) => '2',
						),
					),
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Align', 'factora' ),
						'param_name' => 'align',
						'value'      => array(
							esc_html__( 'Left', 'factora' )   => 'left',
							esc_html__( 'Center', 'factora' ) => 'center',
							esc_html__( 'Right', 'factora' )  => 'right',
						),
					),

					array(
						'type'       => 'param_group',
						'heading'    => esc_html__( 'List Social', 'factora' ),
						'value'      => '',
						'param_name' => 'setting',
						'params'     => array(
							array(
								'type'        => 'vc_link',
								'heading'     => esc_html__( 'Link Social(URL)', 'factora' ),
								'param_name'  => 'link',
								'value'       => '',
								'description' => esc_html__( 'Enter information social', 'factora' ),
							),

							array(
								'type'       => 'dropdown',
								'heading'    => esc_html__( 'Icon inside image', 'factora' ),
								'param_name' => 'icon',
								'value'      => array(
									esc_html__( 'Elengant Icon', 'factora' )    => 'elegant',
									esc_html__( 'SVG Icon', 'factora' )         => 'svg',
									esc_html__( 'Fontawesome Icon', 'factora' ) => 'awesome',
									esc_html__( 'Linear Icon', 'factora' )      => 'linear',
								),
							),

							array(
								'type'             => 'textfield',
								'heading'          => esc_html__( 'SVG Icon name', 'factora' ),
								'param_name'       => 'name_icon',
								'value'            => '',
								'dependency'       => array(
									'element' => 'icon',
									'value'   => 'svg',
								),
								'edit_field_class' => 'vc_col-xs-6',
							),

							array(
								'heading'     => esc_html__( 'Icon', 'factora' ),
								'description' => esc_html__( 'Pick an icon from library.', 'factora' ),
								'type'        => 'iconpicker',
								'param_name'  => 'icon_fontawesome',
								'value'       => 'fa fa-adjust',
								'settings'    => array(
									'emptyIcon'    => false,
									'iconsPerPage' => 4000,
								),
								'dependency'  => array(
									'element' => 'icon',
									'value'   => 'awesome',
								),
							),

							array(
								'heading'     => esc_html__( 'Eleganticons', 'factora' ),
								'description' => esc_html__( 'Select icon from library.', 'factora' ),
								'type'        => 'iconpicker',
								'param_name'  => 'eleganticons',
								'value'       => 'arrow-up-down',
								'settings'    => array(
									'emptyIcon'    => false,
									'iconsPerPage' => 4000,
									'type'         => 'eleganticons',
								),
								'dependency'  => array(
									'element' => 'icon',
									'value'   => 'elegant',
								),
							),

							array(
								'heading'     => esc_html__( 'Linearicons', 'factora' ),
								'description' => esc_html__( 'Select icon from library.', 'factora' ),
								'type'        => 'iconpicker',
								'param_name'  => 'linearicons',
								'value'       => 'icon-home',
								'settings'    => array(
									'emptyIcon'    => false,
									'iconsPerPage' => 4000,
									'type'         => 'linearicons',
								),
								'dependency'  => array(
									'element' => 'icon',
									'value'   => 'linear',
								),
							),
						),
					),

					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'factora' ),
						'param_name'  => 'el_class',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'factora' ),
						'group'       => esc_html__( 'Add class', 'factora' ),
					),
				),
			)
		);

		//Portfolio Attribute
		vc_map(
			array(
				'name'     => esc_html__( 'Portfolio Attribute', 'factora' ),
				'base'     => 'factora_portfolio_attribute',
				'class'    => '',
				'category' => esc_html__( 'Factora', 'factora' ),
				'params'   => array(
					array(
						'type'       => 'param_group',
						'heading'    => esc_html__( 'List Icons', 'factora' ),
						'value'      => '',
						'param_name' => 'attributes',
						'params'     => array(
							array(
								'type'        => 'textfield',
								'heading'     => esc_html__( 'Name', 'factora' ),
								'param_name'  => 'name',
								'value'       => '',
								'admin_label' => true,
							),
							array(
								'type'       => 'textfield',
								'heading'    => esc_html__( 'Value', 'factora' ),
								'param_name' => 'value',
								'value'      => '',
							),
						),

					),
					array(
						'type'       => 'attach_image',
						'heading'    => esc_html__( 'Background Images', 'factora' ),
						'param_name' => 'background_image',
						'value'      => '',
					),
					array(
						'heading'     => esc_html__( 'Background size', 'factora' ),
						'description' => esc_html__( 'Enter image size. Example: "thumbnail", "medium", "large", "full" or other sizes defined by current theme. Alternatively enter image size in pixels: 200x100 (Width x Height). Leave empty to use "thumbnail" size.', 'factora' ),
						'type'        => 'textfield',
						'param_name'  => 'background_size',
						'value'       => '',
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'factora' ),
						'param_name'  => 'el_class',
						'value'       => '',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file . ', 'factora' ),
					),
				)
			)
		);

		//Portfolio Carousel
		vc_map(
			array(
				'name'     => esc_html__( 'Portfolio Carousel', 'factora' ),
				'base'     => 'factora_portfolio_carousel',
				'class'    => '',
				'category' => esc_html__( 'Factora', 'factora' ),
				'params'   => array(

					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Style', 'factora' ),
						'param_name' => 'style',
						'value'      => array(
							esc_html__( 'Style 1', 'factora' ) => '1',
							esc_html__( 'Style 2', 'factora' ) => '2',
						),
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'factora' ),
						'param_name'  => 'el_class',
						'value'       => '',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file . ', 'factora' ),
					),

					//Portfolio Setting
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Portfolios Source', 'factora' ),
						'param_name' => 'source',
						'value'      => array(
							esc_html__( 'Default', 'factora' ) => '1',
							esc_html__( 'Custom', 'factora' )  => '2',
						),
						'group'      => esc_html__( 'Portfolio Setting', 'factora' ),
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Number Items', 'factora' ),
						'param_name' => 'posts_per_page',
						'group'      => esc_html__( 'Portfolio Setting', 'factora' ),
					),

					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Number excerpt content', 'factora' ),
						'param_name'  => 'excerpt_content',
						'value'       => '10',
						'description' => esc_html__( 'Set 0 to hide content', 'factora' ),
						'group'       => esc_html__( 'Portfolio Setting', 'factora' ),
					),

					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Order', 'factora' ),
						'param_name' => 'order',
						'value'      => array(
							esc_html__( 'DESC', 'factora' ) => 'DESC',
							esc_html__( 'ASC', 'factora' )  => 'ASC',
						),
						'dependency' => array(
							'element' => 'source',
							'value'   => array( '1' ),
						),
						'group'      => esc_html__( 'Portfolio Setting', 'factora' ),
					),
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Order by', 'factora' ),
						'param_name' => 'orderby',
						'value'      => array(
							esc_html__( 'None', 'factora' )   => 'none',
							esc_html__( 'Name', 'factora' )   => 'title',
							esc_html__( 'Random', 'factora' ) => 'ran',
							esc_html__( 'ID', 'factora' )     => 'id',
						),
						'dependency' => array(
							'element' => 'source',
							'value'   => '1',
						),
						'group'      => esc_html__( 'Portfolio Setting', 'factora' ),
					),
					array(
						'type'        => 'autocomplete',
						'heading'     => esc_html__( 'Portfolios', 'factora' ),
						'param_name'  => 'list_id',
						'value'       => '',
						'settings'    => array(
							'multiple'      => true,
							'sortable'      => true,
							'unique_values' => true,
						),
						'description' => esc_html__( 'Insert list portfolio id. Example: 2,3,4,...', 'factora' ),
						'dependency'  => array(
							'element' => 'source',
							'value'   => '2',
						),
						'group'       => esc_html__( 'Portfolio Setting', 'factora' ),
					),
					//slide setting
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Columns', 'factora' ),
						'param_name' => 'columns',
						'value'      => array(
							esc_html__( '4 Columns', 'factora' ) => '4',
							esc_html__( '3 Columns', 'factora' ) => '3',
							esc_html__( '2 Columns', 'factora' ) => '2',
							esc_html__( '1 Column', 'factora' )  => '1',
						),
						'group'      => esc_html__( 'Slide Setting', 'factora' ),
					),
					array(
						'type'       => 'checkbox',
						'heading'    => esc_html__( 'Show Nav', 'factora' ),
						'param_name' => 'nav',
						'value'      => array( esc_html__( 'Yes', 'factora' ) => '1' ),
						'group'      => esc_html__( 'Slide Setting', 'factora' ),
					),
					array(
						'type'       => 'checkbox',
						'heading'    => esc_html__( 'Show Dots', 'factora' ),
						'param_name' => 'dots',
						'value'      => array( esc_html__( 'Yes', 'factora' ) => '1' ),
						'group'      => esc_html__( 'Slide Setting', 'factora' ),
					),
					array(
						'type'        => 'checkbox',
						'heading'     => esc_html__( 'Autoplay', 'factora' ),
						'param_name'  => 'autoplay',
						'value'       => array( esc_html__( 'Yes', 'factora' ) => 'yes' ),
						'description' => esc_html__( 'If "YES" Enable autoplay', 'factora' ),
						'dependency'  => array(
							'element' => 'type',
						),
						'group'       => esc_html__( 'Slide Setting', 'factora' ),
					),


				),
			)
		);

		//Portfolio Masonry
		vc_map(
			array(
				'name'     => esc_html__( 'Portfolio Masonry', 'factora' ),
				'base'     => 'factora_portfolio_masonry',
				'class'    => '',
				'category' => esc_html__( 'Factora', 'factora' ),
				'params'   => array(

					//Portfolio Setting
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Number Items', 'factora' ),
						'param_name'  => 'posts_per_page',
						'description' => esc_html__( 'Insert number item you want to show', 'factora' ),
					),

					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Columns', 'factora' ),
						'param_name' => 'columns',
						'value'      => array(
							esc_html__( '4 Columns', 'factora' ) => '4',
							esc_html__( '3 Columns', 'factora' ) => '3',
							esc_html__( '2 Columns', 'factora' ) => '2',
							esc_html__( '1 Column', 'factora' )  => '1',
						),
						'dependency' => array(
							'element' => 'layout',
							'value'   => 'grid',
						),

					),

					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Order', 'factora' ),
						'param_name' => 'order',
						'value'      => array(
							esc_html__( 'DESC', 'factora' ) => 'DESC',
							esc_html__( 'ASC', 'factora' )  => 'ASC',
						),

					),
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Order by', 'factora' ),
						'param_name' => 'orderby',
						'value'      => array(
							esc_html__( 'None', 'factora' )   => 'none',
							esc_html__( 'Name', 'factora' )   => 'title',
							esc_html__( 'Random', 'factora' ) => 'ran',
							esc_html__( 'ID', 'factora' )     => 'id',
						),

					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'factora' ),
						'param_name'  => 'el_class',
						'value'       => '',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file . ', 'factora' ),
					),
				),
			)
		);

		//Service grid
		vc_map(
			array(
				'name'     => esc_html__( 'Service Grid', 'factora' ),
				'base'     => 'factora_service_grid',
				'class'    => '',
				'category' => esc_html__( 'Factora', 'factora' ),
				'params'   => array(
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Style', 'factora' ),
						'param_name' => 'style',
						'value'      => array(
							esc_html__( 'Style 1', 'factora' ) => '1',
							esc_html__( 'Style 2', 'factora' ) => '2',
						),
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'factora' ),
						'param_name'  => 'el_class',
						'value'       => '',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file . ', 'factora' ),
					),
					//Title Setting
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Title', 'factora' ),
						'param_name'  => 'title',
						'admin_label' => true,
						'dependency'  => array(
							'element' => 'style',
							'value'   => '1',
						),
						'group'       => esc_html__( 'Title Setting', 'factora' ),
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Sub Title', 'factora' ),
						'param_name' => 'sub_title',
						'dependency' => array(
							'element' => 'style',
							'value'   => '1',
						),
						'group'      => esc_html__( 'Title Setting', 'factora' ),
					),

					array(
						'type'       => 'textarea_html',
						'heading'    => esc_html__( 'Description', 'factora' ),
						'param_name' => 'content',
						'value'      => '',
						'dependency' => array(
							'element' => 'style',
							'value'   => '1',
						),
						'group'      => esc_html__( 'Title Setting', 'factora' ),
					),
					array(
						'type'       => 'checkbox',
						'heading'    => esc_html__( 'Button View All', 'factora' ),
						'param_name' => 'view_all',
						'dependency' => array(
							'element' => 'style',
							'value'   => '1',
						),
						'value'      => array( esc_html__( 'Yes', 'factora' ) => '1' ),
						'group'      => esc_html__( 'Title Setting', 'factora' ),
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Text View All', 'factora' ),
						'param_name' => 'text_view_all',
						'value'      => '',
						'dependency' => array(
							'element' => 'view_all',
							'value'   => '1',
						),
						'group'      => esc_html__( 'Title Setting', 'factora' ),
					),
					//Service Setting

					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Number Items', 'factora' ),
						'param_name'  => 'posts_per_page',
						'group'       => esc_html__( 'Service Setting', 'factora' ),
						'description' => esc_html__( 'Insert number item you want to show', 'factora' ),
					),

					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Order', 'factora' ),
						'param_name' => 'order',
						'value'      => array(
							esc_html__( 'DESC', 'factora' ) => 'DESC',
							esc_html__( 'ASC', 'factora' )  => 'ASC',
						),
						'group'      => esc_html__( 'Service Setting', 'factora' ),
					),
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Order by', 'factora' ),
						'param_name' => 'orderby',
						'value'      => array(
							esc_html__( 'None', 'factora' )   => 'none',
							esc_html__( 'Name', 'factora' )   => 'title',
							esc_html__( 'Random', 'factora' ) => 'ran',
							esc_html__( 'ID', 'factora' )     => 'id',
						),
						'group'      => esc_html__( 'Service Setting', 'factora' ),
					),

				),
			)
		);

		//Service icon
		vc_map(
			array(
				'name'     => esc_html__( 'Service Icon', 'factora' ),
				'base'     => 'factora_service_icon',
				'class'    => '',
				'category' => esc_html__( 'Factora', 'factora' ),
				'params'   => array(
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Style', 'factora' ),
						'param_name' => 'style',
						'value'      => array(
							esc_html__( 'Style 1', 'factora' ) => '1',
							esc_html__( 'Style 2', 'factora' ) => '2',
						),
					),
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Columns', 'factora' ),
						'param_name' => 'items',
						'value'      => array(
							esc_html__( '4', 'factora' ) => '4',
							esc_html__( '3', 'factora' ) => '3',
							esc_html__( '2', 'factora' ) => '2',
						),

					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Post per page', 'factora' ),
						'param_name'  => 'posts_per_page',
						'value'       => '12',
						'description' => esc_html__( 'Set -1 to show all portfolio', 'factora' ),
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Number excerpt content', 'factora' ),
						'param_name'  => 'excerpt_content',
						'value'       => '10',
						'description' => esc_html__( 'Set 0 to hide content', 'factora' ),

					),
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Order', 'factora' ),
						'param_name' => 'order',
						'value'      => array(
							esc_html__( 'DESC', 'factora' ) => 'DESC',
							esc_html__( 'ASC', 'factora' )  => 'ASC',
						),
					),
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Order by', 'factora' ),
						'param_name' => 'orderby',
						'value'      => array(
							esc_html__( 'None', 'factora' )   => 'none',
							esc_html__( 'Name', 'factora' )   => 'title',
							esc_html__( 'Random', 'factora' ) => 'ran',
							esc_html__( 'ID', 'factora' )     => 'id',
						),
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'factora' ),
						'param_name'  => 'el_class',
						'value'       => '',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file . ', 'factora' ),
					),
				),
			)
		);

		//Brochure
		vc_map(
			array(
				'name'     => esc_html__( 'Factora Brochure', 'factora' ),
				'base'     => 'factora_brochure',
				'class'    => '',
				'category' => esc_html__( 'Factora', 'factora' ),
				'params'   => array(
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Title', 'factora' ),
						'param_name'  => 'title',
						'admin_label' => true,
					),
					array(
						'type'       => 'param_group',
						'heading'    => esc_html__( 'List Button', 'factora' ),
						'value'      => '',
						'param_name' => 'list_button',
						'params'     => array(
							array(
								'type'        => 'textfield',
								'heading'     => esc_html__( 'Name Button', 'factora' ),
								'param_name'  => 'name_button',
								'admin_label' => true,
							),
							array(
								'type'       => 'vc_link',
								'heading'    => esc_html__( 'Link Button', 'factora' ),
								'param_name' => 'link',
								'value'      => '',
							)
						),
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'factora' ),
						'param_name'  => 'el_class',
						'value'       => '',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file . ', 'factora' ),
					),
				),
			)
		);

		//Service Carousel
		vc_map(
			array(
				'name'     => esc_html__( 'Image Box Carousel', 'factora' ),
				'base'     => 'factora_image_box_carousel',
				'class'    => '',
				'category' => esc_html__( 'Factora', 'factora' ),
				'params'   => array(

					array(
						'type'       => 'param_group',
						'heading'    => esc_html__( 'List Image Box', 'factora' ),
						'value'      => '',
						'param_name' => 'list_image_box',
						'params'     => array(
							array(
								'heading'     => esc_html__( 'Title', 'factora' ),
								'type'        => 'textfield',
								'param_name'  => 'title',
								'admin_label' => true,
							),
							array(
								'heading'    => esc_html__( 'Description', 'factora' ),
								'type'       => 'textarea',
								'param_name' => 'desc',
							),
							array(
								'type'       => 'attach_image',
								'heading'    => esc_html__( 'Image', 'factora' ),
								'param_name' => 'image',
								'value'      => '',
							),
							array(
								'heading'    => esc_html__( 'Image size', 'factora' ),
								'type'       => 'textfield',
								'param_name' => 'image_size',
								'value'      => '',
							),
							array(
								'type'       => 'vc_link',
								'heading'    => esc_html__( 'Link Image box', 'factora' ),
								'param_name' => 'link',
								'value'      => '',
							)
						),
					),

					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Text color', 'factora' ),
						'param_name' => 'text_color',
						'value'      => array(
							esc_html__( 'Color Light', 'factora' ) => 'light',
							esc_html__( 'Color Dark', 'factora' )  => 'dark',
						),
					),

					//slide setting
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Columns', 'factora' ),
						'param_name' => 'columns',
						'value'      => array(
							esc_html__( '4 Columns', 'factora' ) => '4',
							esc_html__( '3 Columns', 'factora' ) => '3',
							esc_html__( '2 Columns', 'factora' ) => '2',
							esc_html__( '1 Column', 'factora' )  => '1',
						),
						'group'      => esc_html__( 'Slide Setting', 'factora' ),
					),
					array(
						'type'       => 'checkbox',
						'heading'    => esc_html__( 'Show Dots', 'factora' ),
						'param_name' => 'dots',
						'value'      => array( esc_html__( 'Yes', 'factora' ) => '1' ),
						'group'      => esc_html__( 'Slide Setting', 'factora' ),
					),
					array(
						'type'        => 'checkbox',
						'heading'     => esc_html__( 'Autoplay', 'factora' ),
						'param_name'  => 'autoplay',
						'value'       => array( esc_html__( 'Yes', 'factora' ) => 'yes' ),
						'description' => esc_html__( 'If "YES" Enable autoplay', 'factora' ),
						'dependency'  => array(
							'element' => 'type',
						),
						'group'       => esc_html__( 'Slide Setting', 'factora' ),
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'factora' ),
						'param_name'  => 'el_class',
						'value'       => '',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file . ', 'factora' ),
						'group'       => esc_html__( 'Extra Class', 'factora' ),
					),
				),
			)
		);

		// Faq
		vc_map(
			array(
				'name'     => esc_html__( 'Factora FAQ', 'factora' ),
				'base'     => 'factora_faq',
				'class'    => '',
				'category' => esc_html__( 'Factora', 'factora' ),
				'params'   => array(
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Style', 'factora' ),
						'param_name' => 'style',
						'value'      => array(
							esc_html__( 'Style 1', 'factora' ) => '1',
							esc_html__( 'Style 2', 'factora' ) => '2',
						),
					),
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Box Style', 'factora' ),
						'param_name' => 'box_style',
						'value'      => array(
							esc_html__( 'Box Shadow', 'factora' ) => 'box_shadow',
							esc_html__( 'Border', 'factora' ) => 'border',
						),
					),

					array(
						'type'             => 'textfield',
						'heading'          => esc_html__( 'Active section', 'factora' ),
						'description'      => esc_html__( 'Enter active section number (Note: to have all sections closed on initial load enter non-existing number).', 'factora' ),
						'param_name'       => 'active',
						'value'            => '1',
						'edit_field_class' => 'vc_col-xs-6',
					),

					array(
						'type'             => 'textfield',
						'heading'          => esc_html__( 'Font size (px) for title', 'factora' ),
						'param_name'       => 'font_size',
						'value'            => '',
						'description'      => esc_html__( 'Set numbers Ex: 20, 22, 24, 30... ', 'factora' ),
						'edit_field_class' => 'vc_col-xs-6',
					),

					array(
						'type'       => 'param_group',
						'heading'    => esc_html__( 'List Faq', 'factora' ),
						'value'      => '',
						'param_name' => 'setting',
						'params'     => array(
							array(
								'heading'     => esc_html__( 'Question', 'factora' ),
								'type'        => 'textfield',
								'param_name'  => 'question',
								'admin_label' => true,
							),
							array(
								'heading'    => esc_html__( 'Answer', 'factora' ),
								'type'       => 'textarea',
								'param_name' => 'answer',
							),
						),
					),

					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'factora' ),
						'param_name'  => 'el_class',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'factora' ),
						'group'       => esc_html__( 'Add class', 'factora' ),
					),
				),
			)
		);

		//Team Carousel
		vc_map(
			array(
				'name'     => esc_html__( 'Team Carousel', 'factora' ),
				'base'     => 'factora_team_carousel',
				'class'    => '',
				'category' => esc_html__( 'Factora', 'factora' ),
				'params'   => array(


					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Number Items', 'factora' ),
						'param_name' => 'posts_per_page',
						'group'      => esc_html__( 'Team Setting', 'factora' ),
					),

					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Number excerpt content', 'factora' ),
						'param_name'  => 'excerpt_content',
						'value'       => '10',
						'description' => esc_html__( 'Set 0 to hide content', 'factora' ),
						'group'       => esc_html__( 'Team Setting', 'factora' ),
					),

					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Order', 'factora' ),
						'param_name' => 'order',
						'value'      => array(
							esc_html__( 'DESC', 'factora' ) => 'DESC',
							esc_html__( 'ASC', 'factora' )  => 'ASC',
						),
						'group'      => esc_html__( 'Team Setting', 'factora' ),
					),

					array(
						'type'       => 'checkbox',
						'heading'    => esc_html__( 'Hidden Link', 'factora' ),
						'param_name' => 'hidden_link',
						'value'      => array( esc_html__( 'Yes', 'factora' ) => '1' ),
						'group'      => esc_html__( 'Team Setting', 'factora' ),
					),

					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Order by', 'factora' ),
						'param_name' => 'orderby',
						'value'      => array(
							esc_html__( 'None', 'factora' )   => 'none',
							esc_html__( 'Name', 'factora' )   => 'title',
							esc_html__( 'Random', 'factora' ) => 'ran',
							esc_html__( 'ID', 'factora' )     => 'id',
						),
						'group'      => esc_html__( 'Team Setting', 'factora' ),

						array(
							'type'        => 'textfield',
							'heading'     => esc_html__( 'Extra class name', 'factora' ),
							'param_name'  => 'el_class',
							'value'       => '',
							'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file . ', 'factora' ),
							'group'       => esc_html__( 'Team Setting', 'factora' ),
						),
					),
					//slide setting
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Columns', 'factora' ),
						'param_name' => 'columns',
						'value'      => array(
							esc_html__( '4 Columns', 'factora' ) => '4',
							esc_html__( '3 Columns', 'factora' ) => '3',
							esc_html__( '2 Columns', 'factora' ) => '2',
							esc_html__( '1 Column', 'factora' )  => '1',
						),
						'group'      => esc_html__( 'Slide Setting', 'factora' ),
					),
					array(
						'type'       => 'checkbox',
						'heading'    => esc_html__( 'Show Nav', 'factora' ),
						'param_name' => 'nav',
						'value'      => array( esc_html__( 'Yes', 'factora' ) => '1' ),
						'group'      => esc_html__( 'Slide Setting', 'factora' ),
					),
					array(
						'type'       => 'checkbox',
						'heading'    => esc_html__( 'Show Dots', 'factora' ),
						'param_name' => 'dots',
						'value'      => array( esc_html__( 'Yes', 'factora' ) => '1' ),
						'group'      => esc_html__( 'Slide Setting', 'factora' ),
					),
					array(
						'type'        => 'checkbox',
						'heading'     => esc_html__( 'Autoplay', 'factora' ),
						'param_name'  => 'autoplay',
						'value'       => array( esc_html__( 'Yes', 'factora' ) => 'yes' ),
						'description' => esc_html__( 'If "YES" Enable autoplay', 'factora' ),
						'dependency'  => array(
							'element' => 'type',
						),
						'group'       => esc_html__( 'Slide Setting', 'factora' ),
					),
				),
			)
		);

		//Portfolio grid
		vc_map(
			array(
				'name'     => esc_html__( 'Portfolio Grid', 'factora' ),
				'base'     => 'factora_portfolio_grid',
				'class'    => '',
				'category' => esc_html__( 'Factora', 'factora' ),
				'params'   => array(

					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Section Title', 'factora' ),
						'param_name'  => 'title',
						'admin_label' => true,
					),

					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Items per row', 'factora' ),
						'param_name' => 'items',
						'value'      => array(
							esc_html__( '2 items', 'factora' ) => '2',
							esc_html__( '3 items', 'factora' ) => '3',
							esc_html__( '4 items', 'factora' ) => '4',
						),
					),
					array(
						'type'       => 'checkbox',
						'heading'    => esc_html__( 'Portfolio categorized filter', 'factora' ),
						'param_name' => 'filter',
						'value'      => array( esc_html__( 'Yes', 'factora' ) => '1' ),
					),
					array(
						'type'        => 'textarea',
						'heading'     => esc_html__( 'Categories slug', 'factora' ),
						'param_name'  => 'slug_cate',
						'description' => esc_html__( 'Enter categories slug you want to display. Each slug is separated by comma character ",". If empty, it will display default', 'factora' ),
						'dependency'  => array(
							'element' => 'filter',
							'value'   => '1',
						),
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Post per page', 'factora' ),
						'param_name' => 'posts_per_page',
					),
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Order', 'factora' ),
						'param_name' => 'order',
						'value'      => array(
							esc_html__( 'DESC', 'factora' ) => 'DESC',
							esc_html__( 'ASC', 'factora' )  => 'ASC',
						),
					),
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Order by', 'factora' ),
						'param_name' => 'orderby',
						'value'      => array(
							esc_html__( 'None', 'factora' )   => 'none',
							esc_html__( 'Name', 'factora' )   => 'title',
							esc_html__( 'Random', 'factora' ) => 'ran',
							esc_html__( 'ID', 'factora' )     => 'id',
						),
					),
				),
			)
		);

		vc_map(
			array(
				'name'     => esc_html__( 'Factora Partner', 'factora' ),
				'base'     => 'factora_partner',
				'class'    => '',
				'category' => esc_html__( 'Factora', 'factora' ),
				'params'   => array(

					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Style', 'factora' ),
						'param_name' => 'style',
						'value'      => array(
							esc_html__( 'Grid', 'factora' )     => 'grid',
							esc_html__( 'Carousel', 'factora' ) => 'carousel',
						),
					),
					array(
						'type'       => 'param_group',
						'heading'    => esc_html__( 'List Images', 'factora' ),
						'value'      => '',
						'param_name' => 'images',
						'params'     => array(
							array(
								'type'       => 'attach_image',
								'heading'    => esc_html__( 'Image', 'factora' ),
								'param_name' => 'image',
								'value'      => '',
							),
							array(
								'type'        => 'vc_link',
								'heading'     => esc_html__( 'Link Social(URL)', 'factora' ),
								'param_name'  => 'link',
								'value'       => '',
								'description' => esc_html__( 'Enter information social', 'factora' ),
							),
						),
					),
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Columns', 'factora' ),
						'param_name' => 'columns',
						'value'      => array(
							esc_html__( '1 Column', 'factora' )  => '1',
							esc_html__( '2 Columns', 'factora' ) => '2',
							esc_html__( '3 Columns', 'factora' ) => '3',
							esc_html__( '4 Columns', 'factora' ) => '4',
							esc_html__( '5 Columns', 'factora' ) => '5',
							esc_html__( '6 Columns', 'factora' ) => '6',
						),
						'dependency' => array(
							'element' => 'style',
							'value'   => 'carousel',
						),
					),
					array(
						'heading'     => esc_html__( 'Image size', 'factora' ),
						'description' => esc_html__( 'Enter image size. Example: "thumbnail", "medium", "large", "full" or other sizes defined by current theme. Alternatively enter image size in pixels: 200x100 (Width x Height). Leave empty to use "thumbnail" size.', 'factora' ),
						'type'        => 'textfield',
						'param_name'  => 'image_size',
						'value'       => '',
					),
					// Slide Option
					array(
						'type'             => 'checkbox',
						'heading'          => esc_html__( 'Show Nav', 'factora' ),
						'param_name'       => 'nav',
						'value'            => array( esc_html__( 'Yes', 'factora' ) => '1' ),
						'edit_field_class' => 'vc_col-xs-4',
						'group'            => esc_html__( 'Slide Option', 'factora' ),
						'dependency'       => array(
							'element' => 'style',
							'value'   => 'carousel',
						),
					),
					array(
						'type'             => 'checkbox',
						'heading'          => esc_html__( 'Autoplay', 'factora' ),
						'param_name'       => 'autoplay',
						'value'            => array( esc_html__( 'Yes', 'factora' ) => '1' ),
						'edit_field_class' => 'vc_col-xs-4',
						'group'            => esc_html__( 'Slide Option', 'factora' ),
						'dependency'       => array(
							'element' => 'style',
							'value'   => 'carousel',
						),
					),
					array(
						'type'             => 'textfield',
						'heading'          => esc_html__( 'Autoplay Speed', 'factora' ),
						'param_name'       => 'autoplay_speed',
						'value'            => 2000,
						'description'      => esc_html__( 'Autoplay Speed in milliseconds', 'factora' ),
						'edit_field_class' => 'vc_col-xs-6',
						'dependency'       => array(
							'element' => 'autoplay',
							'value'   => '1',
						),
						'group'            => esc_html__( 'Slide Option', 'factora' ),
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'factora' ),
						'param_name'  => 'el_class',
						'value'       => '',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file . ', 'factora' ),
					),
				),
			)
		);

		vc_map(
			array(
				'name'     => esc_html__( 'Icons Box', 'factora' ),
				'base'     => 'factora_icon_box',
				'class'    => '',
				'category' => esc_html__( 'Factora', 'factora' ),
				'params'   => array(

					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Style', 'factora' ),
						'param_name' => 'style',
						'value'      => array(
							esc_html__( 'Style 1', 'factora' ) => '1',
							esc_html__( 'Style 2', 'factora' ) => '2',
						),
					),

					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Icon', 'factora' ),
						'param_name' => 'icon_type',
						'value'      => array(
							esc_html__( 'SVG Icon', 'factora' )         => 'svg',
							esc_html__( 'Fontawesome Icon', 'factora' ) => 'awesome',
							esc_html__( 'Linear Icon', 'factora' )      => 'linear',
							esc_html__( 'Elegant Icon', 'factora' )     => 'elegant',
						),
					),

					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'SVG Icon name', 'factora' ),
						'param_name' => 'name_icon',
						'value'      => '',
						'dependency' => array(
							'element' => 'icon_type',
							'value'   => 'svg',
						),
					),

					array(
						'heading'     => esc_html__( 'Icon', 'factora' ),
						'description' => esc_html__( 'Pick an icon from library.', 'factora' ),
						'type'        => 'iconpicker',
						'param_name'  => 'icon_fontawesome',
						'value'       => 'fa fa-adjust',
						'settings'    => array(
							'emptyIcon'    => false,
							'iconsPerPage' => 4000,
						),
						'dependency'  => array(
							'element' => 'icon_type',
							'value'   => 'awesome',
						),
					),

					array(
						'heading'     => esc_html__( 'Linearicons', 'factora' ),
						'description' => esc_html__( 'Select icon from library.', 'factora' ),
						'type'        => 'iconpicker',
						'param_name'  => 'linearicons',
						'value'       => 'icon-home',
						'settings'    => array(
							'emptyIcon'    => false,
							'iconsPerPage' => 4000,
							'type'         => 'linearicons',
						),
						'dependency'  => array(
							'element' => 'icon_type',
							'value'   => 'linear',
						),
					),

					array(
						'heading'     => esc_html__( 'Eleganticons', 'factora' ),
						'description' => esc_html__( 'Select icon from library.', 'factora' ),
						'type'        => 'iconpicker',
						'param_name'  => 'eleganticons',
						'value'       => 'icon-home',
						'settings'    => array(
							'emptyIcon'    => false,
							'iconsPerPage' => 4000,
							'type'         => 'eleganticons',
						),
						'dependency'  => array(
							'element' => 'icon_type',
							'value'   => 'elegant',
						),
					),

					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Title', 'factora' ),
						'param_name'  => 'title',
						'value'       => '',
						'admin_label' => true,
					),

					array(
						'type'       => 'textarea_html',
						'heading'    => esc_html__( 'Description', 'factora' ),
						'param_name' => 'content',
						'value'      => '',
					),

					array(
						'type'       => 'vc_link',
						'heading'    => esc_html__( 'Link (URL)', 'factora' ),
						'param_name' => 'link',
						'value'      => '',
					),


					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'factora' ),
						'param_name'  => 'el_class',
						'value'       => '',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file . ', 'factora' ),
					),
				),
			)
		);

		//Counter
		vc_map(
			array(
				'name'     => esc_html__( 'Factora Counter', 'factora' ),
				'base'     => 'factora_counter',
				'class'    => '',
				'category' => esc_html__( 'Factora', 'factora' ),
				'params'   => array(

					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Number', 'factora' ),
						'param_name'  => 'number',
						'description' => esc_html__( 'Enter number. Ex: 100, 200, 300)', 'factora' ),
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Time delay', 'factora' ),
						'param_name'  => 'duration',
						'description' => esc_html__( 'Enter time delay for number. Ex: 1, 2, 3...(s)', 'factora' ),
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Text After', 'factora' ),
						'param_name' => 'text_after',
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Title', 'factora' ),
						'param_name' => 'title',
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Extra Class', 'factora' ),
						'param_name' => 'el_class',
						'value'      => '',
					),
				)
			)
		);
	}
}