<?php

class Factora_Recent_Posts_Widget extends WP_Widget {
	/**
	 * Holds widget settings defaults, populated in constructor.
	 *
	 * @var array
	 */
	protected $defaults;

	/**
	 * Class constructor
	 * Set up the widget
	 *
	 * @return Factora_Recent_Posts_Widget
	 */
	function __construct() {
		$this->defaults = array(
			'title'      => '',
			'limit'      => 5,
			'date'      => 1,
			'thumb'      => 1,
			'thumb_size' => 'widget-thumb',
		);

		parent::__construct(
			'recent-posts-widget',
			esc_html__( 'Factora - Recent Post', 'factora' ),
			array(
				'classname'   => 'recent-posts-widget',
				'description' => esc_html__( 'Display most recent posts', 'factora' ),
			)
		);
	}

	/**
	 * Display widget
	 *
	 * @param array $args     Sidebar configuration
	 * @param array $instance Widget settings
	 *
	 * @return void
	 */
	function widget( $args, $instance ) {
		$instance = wp_parse_args( $instance, $this->defaults );
		extract( $args );

		$query_args = array(
			'posts_per_page'      => $instance['limit'],
			'no_found_rows'       => true,
			'post_status'         => 'publish',
			'ignore_sticky_posts' => true,
		);

		$query = new WP_Query( $query_args );

		if ( ! $query->have_posts() ) {
			return;
		}

		echo $before_widget;

		if ( $title = apply_filters( 'widget_title', $instance['title'], $instance, $this->id_base ) ) {
			echo $before_title . $title . $after_title;
		}

		$class = $instance['thumb'] ? '' : 'no-thumbnail';
		echo '<div class="widget-list-post">';

		while ( $query->have_posts() ) : $query->the_post();
			?>
            <div class="factora__recent-post post <?php if ( has_post_thumbnail() ) { echo 'thumbnail-widget'; } echo esc_attr( $class ); ?>">
				<?php
				if ( has_post_thumbnail() ) {
					printf(
						'<a class="widget-thumb" href="%s" title="%s">%s</a>',
						get_permalink(),
						get_the_title(),
						get_the_post_thumbnail( get_the_ID(), 'factora-testimonial-thumb' )
					);
				}
				?>
                <div class="recent-post-title">
                    <h4><a href="<?php the_permalink() ?>"><?php the_title() ?></a></h4>
					<?php
					if ( $instance['date'] ) {
						printf(
							'<time class="entry-date published updated" datetime="%1$s">%2$s</time>',
							esc_attr( get_the_date( 'c' ) ),
							esc_html( get_the_date() )
						);
					}
					?>
                </div>
            </div>
		<?php
		endwhile;
		wp_reset_postdata();

		echo '</div>';

		echo $after_widget;

	}

	/**
	 * Update widget
	 *
	 * @param array $new_instance New widget settings
	 * @param array $old_instance Old widget settings
	 *
	 * @return array
	 */
	function update( $new_instance, $old_instance ) {
		$new_instance['title']     = strip_tags( $new_instance['title'] );
		$new_instance['limit']     = intval( $new_instance['limit'] );
		$new_instance['thumb']     = ! empty( $new_instance['thumb'] );
		$new_instance['date']      = ! empty( $new_instance['date'] );

		return $new_instance;
	}

	/**
	 * Display widget settings
	 *
	 * @param array $instance Widget settings
	 *
	 * @return void
	 */
	function form( $instance ) {
		$instance = wp_parse_args( $instance, $this->defaults );
		?>

        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title', 'factora' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $instance['title'] ); ?>">
        </p>

        <p>
            <input id="<?php echo esc_attr( $this->get_field_id( 'limit' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'limit' ) ); ?>" type="text" size="2" value="<?php echo intval( $instance['limit'] ); ?>">
            <label for="<?php echo esc_attr( $this->get_field_id( 'limit' ) ); ?>"><?php esc_html_e( 'Number Of Posts', 'factora' ); ?></label>
        </p>


        <p>
            <input id="<?php echo esc_attr( $this->get_field_id( 'date' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'date' ) ); ?>" type="checkbox" value="1" <?php checked( $instance['date'] ); ?>>
            <label for="<?php echo esc_attr( $this->get_field_id( 'date' ) ); ?>"><?php esc_html_e( 'Show Date', 'factora' ); ?></label>
        </p>

        <p>
            <input id="<?php echo esc_attr( $this->get_field_id( 'thumb' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'thumb' ) ); ?>" type="checkbox" value="1" <?php checked( $instance['thumb'] ); ?>>
            <label for="<?php echo esc_attr( $this->get_field_id( 'thumb' ) ); ?>"><?php esc_html_e( 'Show Thumbnail', 'factora' ); ?></label>
        </p>

		<?php
	}

}