<?php
/**
 * Functions and definitions
 *
 * @link    https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Factora
 */

if ( ! function_exists( 'factora_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function factora_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /lang/ directory.
		 * If you're building a theme based on factora, use a find and replace
		 * to change  'factora' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'factora', get_template_directory() . '/lang' );

		// Theme supports
		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'title-tag' );
		add_theme_support( 'post-thumbnails' );
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );
		add_theme_support( 'customize-selective-refresh-widgets' );

		add_editor_style( 'css/editor-style.css' );

		// Load regular editor styles into the new block-based editor.
		add_theme_support( 'editor-styles' );

		// Image Size
		add_image_size( 'factora-post-single', 1170, 737, true );
		add_image_size( 'factora-blog-grid', 570, 431, true );
		add_image_size( 'factora-blog-list', 440, 410, true );
		add_image_size( 'factora-lastest-blog-grid', 740, 560, true );
		add_image_size( 'factora-lastest-blog-list', 680, 520, true );
		add_image_size( 'factora-portfolio-grid', 650, 535, true );
		add_image_size( 'factora-portfolio-listing', 770, 550, true );
		add_image_size( 'factora-portfolio-carousel-1', 1170, 650, true );
		add_image_size( 'factora-portfolio-carousel-2', 425, 575, true );
		add_image_size( 'factora-portfolio-masonry-thumb-1', 570, 610, true );
		add_image_size( 'factora-portfolio-masonry-thumb-2', 570, 290, true );
		add_image_size( 'factora-portfolio-masonry-thumb-3', 540, 580, true );
		add_image_size( 'factora-team-image', 370, 612, true );
		add_image_size( 'factora-service-grid-thumb-1', 580, 483, true );
		add_image_size( 'factora-testimonial-thumb', 80, 80, true );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary' => esc_html__( 'Primary Menu', 'factora' ),
		) );

		if(intval(factora_get_option( 'footer_copyright_menu' ))){
			register_nav_menus( array(
				'footer-copyright' => esc_html__( 'Footer Copyright Menu', 'factora' )
			) );
		}
	}
endif;
add_action( 'after_setup_theme', 'factora_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function factora_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'factora_content_width', 640 );
}

add_action( 'after_setup_theme', 'factora_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function factora_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Blog Sidebar', 'factora' ),
		'id'            => 'blog-sidebar',
		'description'   => esc_html__( 'Add widgets here in order to display them on blog pages.', 'factora' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Top Bar 1', 'factora' ),
		'id'            => 'topbar-1',
		'description'   => esc_html__( 'Add widgets here in order to display them on top bar left.', 'factora' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Top Bar 2', 'factora' ),
		'id'            => 'topbar-2',
		'description'   => esc_html__( 'Add widgets here in order to display them on top bar right.', 'factora' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Topbar mobile', 'factora' ),
		'id'            => 'topbar-mobile',
		'description'   => esc_html__( 'Add widgets here in order to display them on top bar mobile.', 'factora' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Header Sidebar', 'factora' ),
		'id'            => 'header-sidebar',
		'description'   => esc_html__( 'Add widgets here in order to display them on header sidebar.', 'factora' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Single Service Sidebar', 'factora' ),
		'id'            => 'single-service-sidebar',
		'description'   => esc_html__( 'Add widgets here in order to display them on single service sidebar.', 'factora' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );


	if ( class_exists( 'WooCommerce' ) ) {

		register_sidebar( array(
			'name'          => esc_html__( 'Catalog Sidebar', 'factora' ),
			'id'            => 'catalog-sidebar',
			'description'   => esc_html__( 'Add widgets here in order to display them on catalog sidebar.', 'factora' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		) );

	}


	if ( intval( factora_get_option( 'footer_widget' ) ) ) {
		for ( $i = 1; $i < 5; $i ++ ) {
			register_sidebar( array(
				'name'          => sprintf( esc_html__( 'Footer Sidebar %s', 'factora' ), $i ),
				'id'            => 'footer-' . $i,
				'description'   => esc_html__( 'Add widgets here in order to display on footer', 'factora' ),
				'before_widget' => '<div id="%1$s" class="widget %2$s">',
				'after_widget'  => '</div>',
				'before_title'  => '<h4 class="widget-title">',
				'after_title'   => '</h4>',
			) );
		}
	}
}

add_action( 'widgets_init', 'factora_widgets_init' );

/**
 * Custom functions for the theme.
 */
require get_template_directory() . '/inc/functions/header.php';
require get_template_directory() . '/inc/functions/page-header.php';
require get_template_directory() . '/inc/functions/layout.php';
require get_template_directory() . '/inc/functions/entry.php';
require get_template_directory() . '/inc/functions/comments.php';
require get_template_directory() . '/inc/functions/breadcrumbs.php';
require get_template_directory() . '/inc/functions/style.php';

/**
 * Custom functions for the theme by hooking
 */

require get_template_directory() . '/inc/frontend/header.php';
require get_template_directory() . '/inc/frontend/page-header.php';
require get_template_directory() . '/inc/frontend/footer.php';
require get_template_directory() . '/inc/frontend/layout.php';
require get_template_directory() . '/inc/frontend/comments.php';
require get_template_directory() . '/inc/frontend/nav.php';
require get_template_directory() . '/inc/frontend/entry.php';

/**
 * Load WooCommerce compatibility file.
 */
if ( class_exists( 'WooCommerce' ) ) {
	require get_template_directory() . '/inc/woocommerce/woocommerce.php';
}

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer/customizer.php';

if ( is_admin() ) {
	require get_template_directory() . '/inc/libs/class-tgm-plugin-activation.php';
	require get_template_directory() . '/inc/backend/plugins.php';
	require get_template_directory() . '/inc/backend/meta-boxes.php';
}


