<?php
/**
 * Registering meta boxes
 *
 * All the definitions of meta boxes are listed below with comments.
 *
 * For more information, please visit:
 * @link http://www.deluxeblogtips.com/meta-box/
 */

/**
 * Enqueue script for handling actions with meta boxes
 *
 * @since 1.0
 *
 * @param string $hook
 */
function factora_meta_box_scripts( $hook ) {
	// Detect to load un-minify scripts when WP_DEBUG is enable
	if ( in_array( $hook, array( 'post.php', 'post-new.php' ) ) ) {
		wp_enqueue_script( 'factora-meta-boxes', get_template_directory_uri() . "/js/backend/meta-boxes.js", array( 'jquery' ), '20181221', true );
	}
}

add_action( 'admin_enqueue_scripts', 'factora_meta_box_scripts' );

/**
 * Registering meta boxes
 *
 * Using Meta Box plugin: http://www.deluxeblogtips.com/meta-box/
 *
 * @see http://www.deluxeblogtips.com/meta-box/docs/define-meta-boxes
 *
 * @param array $meta_boxes Default meta boxes. By default, there are no meta boxes.
 *
 * @return array All registered meta boxes
 */
function factora_register_meta_boxes( $meta_boxes ) {
	// Post format's meta box
	$meta_boxes[] = array(
		'id'       => 'post-format-settings',
		'title'    => esc_html__( 'Format Details', 'factora' ),
		'pages'    => array( 'post' ),
		'context'  => 'normal',
		'priority' => 'high',
		'autosave' => true,
		'fields'   => array(
			array(
				'name'             => esc_html__( 'Image', 'factora' ),
				'id'               => 'image',
				'type'             => 'image_advanced',
				'class'            => 'image',
				'max_file_uploads' => 1,
			),
			array(
				'name'  => esc_html__( 'Gallery', 'factora' ),
				'id'    => 'images',
				'type'  => 'image_advanced',
				'class' => 'gallery',
			),
			array(
				'name'  => esc_html__( 'Video', 'factora' ),
				'id'    => 'video',
				'type'  => 'textarea',
				'cols'  => 20,
				'rows'  => 2,
				'class' => 'video',
			),
		),
	);
	// Choose icon for archive page
	$meta_boxes[] = array(
		'id'       => 'feature-image',
		'title'    => esc_html__( 'Icon', 'factora' ),
		'pages'    => array( 'service', 'factora' ),
		'context'  => 'normal',
		'priority' => 'high',
		'autosave' => true,
		'fields'   => array(
			
			array(
				'name'            => 'Select',
				'id'              => 'icon_type',
				'type'            => 'select',
				'options'         => array(
					''          => esc_html__( 'Select Icon Type', 'factora' ),
					'svg'       => esc_html__( 'Svg', 'factora' ),
					'icon_font' => esc_html__( 'Elegant', 'factora' ),
				),
				'placeholder'     => 'Select Icon Type',
				'select_all_none' => true,
			),

			array(
				'name'  => esc_html__( 'Name Icon', 'factora' ),
				'id'    => 'icon',
				'type'  => 'text',
				'cols'  => 20,
				'rows'  => 1,
				'class' => 'social',
			),

		),
	);
	// Choose icon for archive page
	$meta_boxes[] = array(
		'id'       => 'job',
		'title'    => esc_html__( 'Job', 'factora' ),
		'pages'    => array( 'testimonial', 'factora' ),
		'context'  => 'normal',
		'priority' => 'high',
		'autosave' => true,
		'fields'   => array(
			array(
				'name'  => esc_html__( 'Job name', 'factora' ),
				'id'    => 'job_name',
				'type'  => 'text',
				'cols'  => 20,
				'rows'  => 1,
			),

			array(
				'name'    => esc_html__( 'Style', 'factora' ),
				'id'      => 'job_rating',
				'type'    => 'select',
				'options' => array(
					'0' => esc_html__( 'No Star', 'factora' ),
					'1' => esc_html__( '1 Star', 'factora' ),
					'2' => esc_html__( '2 Stars', 'factora' ),
					'3' => esc_html__( '3 Stars', 'factora' ),
					'4' => esc_html__( '4 Stars', 'factora' ),
					'5' => esc_html__( '5 Stars', 'factora' ),
				),
			),

		),
	);

	// Display Settings
	$meta_boxes[] = array(
		'id'       => 'page-header-settings',
		'title'    => esc_html__( 'Page Header Settings', 'factora' ),
		'pages'    => array( 'page', 'post', 'service', 'portfolio', 'testimonial' ),
		'context'  => 'normal',
		'priority' => 'high',
		'fields'   => array(
			array(
				'name'             => esc_html__( 'Hide Page Header', 'factora' ),
				'id'               => 'hide_page_header',
				'type'             => 'checkbox',
				'std'              => false,
			),
			array(
				'name'             => esc_html__( 'Hide Breadcrumb', 'factora' ),
				'id'               => 'hide_breadcrumb',
				'type'             => 'checkbox',
				'std'              => false,
			),
			array(
				'name'             => esc_html__( 'Hide Title', 'factora' ),
				'id'               => 'hide_title',
				'type'             => 'checkbox',
				'std'              => false,
			),
			array(
				'name'             => esc_html__( 'Hide Parallax', 'factora' ),
				'id'               => 'hide_parallax',
				'type'             => 'checkbox',
				'std'              => false,
			),
			array(
				'name'             => esc_html__( 'Text Center', 'factora' ),
				'id'               => 'text_center',
				'type'             => 'checkbox',
				'std'              => false,
			),
			array(
				'name'             => esc_html__( 'Background Image', 'factora' ),
				'id'               => 'page_header_bg',
				'type'             => 'image_advanced',
				'max_file_uploads' => 1,
				'std'              => false,
			),
			array(
				'name'             => esc_html__( 'Background Color', 'factora' ),
				'id'               => 'page_header_color',
				'type'             => 'color',
				'std'              => false,
			),
			array(
				'name'             => esc_html__( 'Title Color', 'factora' ),
				'id'               => 'page_header_title_color',
				'type'             => 'color',
				'std'              => false,
			),
			array(
				'name'             => esc_html__( 'Breadcrumb Color', 'factora' ),
				'id'               => 'page_header_br_color',
				'type'             => 'color',
				'std'              => false,
			),
			array(
				'name'             => esc_html__( 'Breadcrumb Link Color', 'factora' ),
				'id'               => 'page_header_br_link_color',
				'type'             => 'color',
				'std'              => false,
			),
			array(
				'name'             => esc_html__( 'Padding Top (px)', 'factora' ),
				'id'               => 'page_header_padding_top',
				'type'             => 'slider',
				'js_options'       => array(
					'min'          => 0,
					'max'          => 500,
				),
				'std'              => false,
			),
			array(
				'name'             => esc_html__( 'Padding Bottom (px)', 'factora' ),
				'id'               => 'page_header_padding_bottom',
				'type'             => 'slider',
				'js_options'       => array(
					'min'          => 0,
					'max'          => 500,
				),
				'std'              => false,
			),
		),
	);
	// Post format's meta box
	$meta_boxes[] = array(
		'id'       => 'team-settings',
		'title'    => esc_html__( 'Member Information', 'factora' ),
		'pages'    => array( 'team' ),
		'context'  => 'normal',
		'priority' => 'high',
		'autosave' => true,
		'fields'   => array(

			array(
				'name'  => esc_html__( 'Social Media', 'factora' ),
				'id'    => 'social',
				'type'  => 'text',
				'cols'  => 20,
				'rows'  => 1,
				'class' => 'social',
				'clone' => true,
			),
			array(
				'name'  => esc_html__( 'Job', 'factora' ),
				'id'    => 'job',
				'type'  => 'text',
				'cols'  => 20,
				'rows'  => 1,
				'class' => 'job',
			),

		),
	);
	// Display Settings
	$meta_boxes[] = array(
		'id'       => 'display-settings',
		'title'    => esc_html__( 'Display Settings', 'factora' ),
		'pages'    => array( 'service'),
		'context'  => 'normal',
		'priority' => 'high',
		'fields'   => array(
			array(
				'name' => esc_html__( 'Layout', 'factora' ),
				'id'   => 'heading_layout',
				'type' => 'heading',
			),
			array(
				'name' => esc_html__( 'Custom Layout', 'factora' ),
				'id'   => 'custom_layout',
				'type' => 'checkbox',
				'std'  => false,
			),
			array(
				'name'    => esc_html__( 'Layout', 'factora' ),
				'id'      => 'layout',
				'type'    => 'image_select',
				'class'   => 'custom-layout',
				'options' => array(
					'full-content'    => get_template_directory_uri() . '/images/sidebars/empty.png',
					'sidebar-content' => get_template_directory_uri() . '/images/sidebars/single-left.png',
					'content-sidebar' => get_template_directory_uri() . '/images/sidebars/single-right.png',
				),
			),
		),
	);
	return $meta_boxes;
}

add_filter( 'rwmb_meta_boxes', 'factora_register_meta_boxes' );
