<?php

/**
 * Add icon list as svg at the footer
 * It is hidden
 */
function factora_include_shadow_icons() {
	echo '<div id="del-svg-defs" class="del-svg-defs hidden">';
	include get_template_directory() . '/images/sprite.svg';
	echo '</div>';
}

add_action( 'factora_after_footer', 'factora_include_shadow_icons' );

/**
 * Get socials
 *
 * @since  1.0.0
 *
 *
 * @return string
 */
function factora_get_socials() {
	$socials = array(
		'facebook'   => esc_html__( 'Facebook', 'factora' ),
		'twitter'    => esc_html__( 'Twitter', 'factora' ),
		'google'     => esc_html__( 'Google Plus', 'factora' ),
		'tumblr'     => esc_html__( 'Tumblr', 'factora' ),
		'flickr'     => esc_html__( 'Flickr', 'factora' ),
		'vimeo'      => esc_html__( 'Vimeo', 'factora' ),
		'youtube'    => esc_html__( 'Youtube', 'factora' ),
		'linkedin'   => esc_html__( 'LinkedIn', 'factora' ),
		'pinterest'  => esc_html__( 'Pinterest', 'factora' ),
		'dribbble'   => esc_html__( 'Dribbble', 'factora' ),
		'spotify'    => esc_html__( 'Spotify', 'factora' ),
		'instagram'  => esc_html__( 'Instagram', 'factora' ),
		'tumbleupon' => esc_html__( 'Tumbleupon', 'factora' ),
		'wordpress'  => esc_html__( 'WordPress', 'factora' ),
		'rss'        => esc_html__( 'Rss', 'factora' ),
		'deviantart' => esc_html__( 'Deviantart', 'factora' ),
		'share'      => esc_html__( 'Sharethis', 'factora' ),
		'skype'      => esc_html__( 'Skype', 'factora' ),
		'behance'    => esc_html__( 'Behance', 'factora' ),
		'apple'      => esc_html__( 'Apple', 'factora' ),
		'yelp'       => esc_html__( 'Yelp', 'factora' ),
	);

	$socials = apply_filters( 'factora_team_socials', $socials );

	return $socials;
}

if ( ! function_exists( 'factora_blog_text_categories' ) ) :
	function factora_blog_text_categories() {
		$cat_filter = intval( factora_get_option( 'blog_cat_filter' ) );

		$title = '';
		if ( ! empty( factora_get_option( 'title_blog' ) ) ) {
			$title = factora_get_option( 'title_blog' );
		}

		if ( ! $cat_filter && $title == '' ) {
			return;
		}

		echo '<div class="factora-blog--top">';
		echo '<h3 class="post-title">' . esc_html( $title ) . '</h3>';
		if ( $cat_filter ) : factora_post_taxs_list(); endif;
		echo '</div>';
	}
endif;
add_action( 'factora_before_post_list', 'factora_blog_text_categories' );

if ( ! function_exists( 'factora_testimonial_title' ) ) :
	function factora_testimonial_title() {
		$title = factora_get_option( 'testimonial_title' );
		if ( empty( $title ) ) {
			return;
		}
		echo '<h2 class="testimonial-title">' . esc_html( $title ) . '</h2>';
	}
endif;
add_action( 'factora_before_testimonial_list', 'factora_testimonial_title' );

if ( ! function_exists( 'factora_testimonial_icon' ) ) :
	function factora_testimonial_icon() {
		$testimonial_icon = factora_get_option( 'testimonial_icon' );
		if ( empty( $testimonial_icon ) ) {
			return;
		}
		?>
        <div class="icon">
            <span class='factora-icon'><svg viewBox='0 0 20 20'><use xlink:href='#double-quotes'></use></svg></span>
        </div>
		<?php
	}
endif;
add_action( 'factora_before_testimonial_list', 'factora_testimonial_title' );


/*
 * Project categories filter
 */
if ( ! function_exists( 'factora_portfolio_isotope' ) ) {
	function factora_portfolio_isotope() {
		if ( ! intval( factora_get_option( 'portfolio_cats_filters' ) ) ) {
			return;
		}
		$taxonomy  = 'portfolio_category';
		$term_id   = 0;
		$cats      = $output = '';
		$found     = false;
		$number    = intval( factora_get_option( 'portfolio_cat_numbers' ) );
		$cats_slug = wp_kses_post( factora_get_option( 'portfolio_categories' ) );
		$id        = 'factora-taxs-list';

		if ( is_tax( $taxonomy ) || is_category() ) {

			$queried_object = get_queried_object();
			if ( $queried_object ) {
				$term_id = $queried_object->term_id;
			}
		}

		$param = apply_filters('fatora_get_param_url', '');

		if ( $cats_slug ) {
			$cats_slug = explode( ',', $cats_slug );

			foreach ( $cats_slug as $slug ) {
				$cat = get_term_by( 'slug', $slug, $taxonomy );

				if ( $cat ) {
					$cat_selected = '';
					if ( $cat->term_id == $term_id ) {
						$cat_selected = 'active';
						$found        = true;
					}

					$cats .= sprintf( '<a href="%s" class="button %s">%s</a>', esc_url( get_term_link( $cat ) . $param ), esc_attr( $cat_selected ), esc_html( $cat->name ) );
				}
			}

		} else {
			$args = array(
				'number'  => $number,
				'orderby' => 'count',
				'order'   => 'DESC',

			);

			$categories = get_terms( $taxonomy, $args );
			if ( ! is_wp_error( $categories ) && $categories ) {
				foreach ( $categories as $cat ) {
					$cat_selected = '';
					if ( $cat->term_id == $term_id ) {
						$cat_selected = 'active';
						$found        = true;
					}

					$cats .= sprintf( '<a href="%s" class="button %s">%s</a>', esc_url( get_term_link( $cat ) . $param ), esc_attr( $cat_selected ), esc_html( $cat->name ) );
				}
			}
		}

		$cat_selected = $found ? '' : 'active';

		if ( $cats ) {
			$url      = get_post_type_archive_link( 'portfolio' );
			$btn_all  = esc_html__( 'All Projects', 'factora' );
			$text_all = wp_kses_post( factora_get_option( 'portfolio_text_filter_all_items' ) );
			if ( ! empty( $text_all ) ) {
				$btn_all = $text_all;
			}
			if ( 'posts' == esc_html( get_option( 'show_on_front' ) ) ) {
				$url = home_url();
			}

			$url .= $param;

			$output = sprintf(
				'<a href="%s" class="button %s">%s</a>' .
				'%s',
				esc_url( $url ),
				esc_attr( $cat_selected ),
				$btn_all,
				$cats
			);
		}
		$title    = factora_get_option( 'portfolio_title' );
		$tx_title = sprintf( '<div class="portfolio-title"><h3 class="title">%s</h3></div>', esc_html( $title ) );
		printf( "<div class='container categories-filter portfolio-cats-filter' id='portfolio-cats-filters'>
						%s
						<div id='filters' class='button-group'>%s</div></div>",
			$tx_title, $output );
	}
}

add_action( 'factora_portfolio_before_content', 'factora_portfolio_isotope' );

/**
 * Check is portfolio
 *
 * @since  1.0
 */
if ( ! function_exists( 'factora_portfolio_slug' ) ) {
	function factora_portfolio_slug() {
		$terms = get_the_terms( get_the_ID(), 'portfolio_category' );
		if ( $terms && ! is_wp_error( $terms ) ) :
			printf( '%s', $terms[0]->slug );
		endif;
	}
}

/**
 * Check is portfolio
 *
 * @since  1.0
 */
if ( ! function_exists( 'factora_portfolio_pagination' ) ) {
	function factora_portfolio_pagination() {
		if ( factora_get_option( 'portfolio_pagination' ) == '1' ) {
			if ( factora_get_option( 'portfolio_pagination_style' ) == '2' ) {
				factora_load_pagination();
			} else {
				echo '<div class="col-xs-12 pag-1 numeric-navigation text-center">';
				echo get_the_posts_pagination( array(
					'prev_text' => "<span class='fa fa-angle-left'></span>",
					'next_text' => "<span class='fa fa-angle-right'></span>",
				) );
			}
		}
	}
}

/**
 * Check is portfolio
 *
 * @since  1.0
 */

if ( ! function_exists( 'factora_is_portfolio' ) ) :
	function factora_is_portfolio() {
		if ( is_post_type_archive( 'portfolio' ) || is_tax( 'portfolio_category' ) ) {
			return true;
		}

		return false;
	}
endif;
/**
 * Check is service
 *
 * @since  1.0
 */

if ( ! function_exists( 'factora_is_service' ) ) :
	function factora_is_service() {
		if ( is_post_type_archive( 'service' ) || is_tax( 'service_category' ) ) {
			return true;
		}

		return false;
	}
endif;
/**
 * Check is testimonial
 *
 * @since  1.0
 */

if ( ! function_exists( 'factora_is_testimonial' ) ) :
	function factora_is_testimonial() {
		if ( is_post_type_archive( 'testimonial' ) || is_tax( 'testimonial_category' ) ) {
			return true;
		}

		return false;
	}
endif;

if ( ! function_exists( 'factora_portfolio_thumbnail' ) ) :
	/**
	 * Displays an optional departments thumbnail.
	 *
	 * Wraps the departments thumbnail in an anchor element on index views, or a div
	 * element when on single views.
	 */
	function factora_portfolio_thumbnail() {
		if ( post_password_required() || is_attachment() ) {
			return;
		}

		if ( is_singular() ) :
			if ( factora_get_option( 'single_portfolio_layout' ) != 'full-content' ) {
				return;
			}
			?>

            <div class="post-thumbnail">
				<?php the_post_thumbnail(); ?>
            </div><!-- .post-thumbnail -->

		<?php else : ?>
            <a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true" tabindex="-1">
				<?php
				$layout = factora_portfolio_layout();
				if ( $layout == 'listing' ) {
					the_post_thumbnail( 'factora-portfolio-listing' );
				} else {
					the_post_thumbnail( 'factora-portfolio-grid' );
				}
				?>
            </a>
		<?php
		endif; // End is_singular().
	}
endif;


if ( ! function_exists( 'factora_service_thumbnail' ) ) :
	/**
	 * Displays an optional departments thumbnail.
	 *
	 * Wraps the departments thumbnail in an anchor element on index views, or a div
	 * element when on single views.
	 */
	function factora_service_thumbnail() {
		if ( post_password_required() || is_attachment() ) {
			return;
		}

		if ( is_singular() ) :
			?>

            <div class="post-thumbnail">
				<?php the_post_thumbnail(); ?>
            </div>

		<?php else : ?>
            <a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true" tabindex="-1">
				<?php
				the_post_thumbnail( 'factora-blog-grid' );
				?>
            </a>
		<?php
		endif;
	}
endif;

if ( ! function_exists( 'factora_portfolio_layout' ) ) :
	function factora_portfolio_layout() {
		$layout = factora_get_option( 'portfolio_layout' );

		return $layout;
	}
endif;

if ( ! function_exists( 'factora_portfolio_class' ) ) :
	function factora_portfolio_class() {
		if ( factora_portfolio_layout() == 'listing' ) :
			echo 'col-xs-12 col-sm-12';
		else:
			$columns = 12 / intval( factora_get_option( 'portfolio_columns' ) );
			echo 'col-xs-12 col-sm-4 col-md-' . $columns;
		endif;
	}
endif;

if ( ! function_exists( 'factora_service_class' ) ) :
	function factora_service_class() {
		$columns = 12 / intval( factora_get_option( 'service_columns' ) );
		echo 'col-xs-12 col-sm-' . $columns;
	}
endif;


if ( ! function_exists( 'factora_portfolio_title' ) ) :
	function factora_portfolio_title() {
		if ( is_singular() ) {
			?>
            <h3 class="entry-title"><?php echo get_the_title(); ?></h3>
			<?php
		} else {
			$title_length = factora_get_option( 'portfolio_title_length' );
			$title        = get_the_title();
			if ( ! empty( $title_length ) ) {
				$title = factora_title_limit( $title_length );
			}
			?>
            <h3 class="entry-title">
                <a class="title" href="<?php the_permalink(); ?>"><?php echo esc_attr( $title ); ?></a>
            </h3>
			<?php
		}
	}
endif;

if ( ! function_exists( 'factora_service_title' ) ) :
	function factora_service_title() {
		if ( is_singular() ) {
			?>
            <h3 class="entry-title"><?php echo get_the_title(); ?></h3>
			<?php
		} else {
			$title_length = factora_get_option( 'service_title_length' );
			$title        = get_the_title();
			if ( ! empty( $title_length ) ) {
				$title = factora_title_limit( $title_length );
			}
			?>
            <h3 class="entry-title">
                <a class="title" href="<?php the_permalink(); ?>"><?php echo esc_attr( $title ); ?></a>
            </h3>
			<?php
		}
	}
endif;

if ( ! function_exists( 'factora_portfolio_content' ) ) :
	function factora_portfolio_content() {
		if ( factora_get_option( 'portfolio_layout' ) == 'listing' ) {
			$excerpt_number = factora_get_option( 'portfolio_excerpt_length' );
			$desc           = get_the_excerpt();
			if ( ! empty( $desc ) ) {
				?>
                <div class="descr">
					<?php
					factora_content_limit( $excerpt_number, '' );
					?>
                </div>

				<?php
			}
		}
	}
endif;


/**
 * Check is portfolio
 *
 * @since  1.0
 */
if ( ! function_exists( 'factora_portfolio_category' ) ) {
	function factora_portfolio_category() {
		$terms = get_the_terms( get_the_ID(), 'portfolio_category' );
		if ( $terms && ! is_wp_error( $terms ) ) :
			printf(
				'<a class="category" href="%s">%s</a>',
				esc_url( get_term_link( $terms[0]->term_id, 'portfolio_category' ) ),
				$terms[0]->name
			);
		endif;
	}
}

if ( ! function_exists( 'factora_portfolio_readmore' ) ) :
	function factora_portfolio_readmore() {
		?>
        <a class="read-more" href="<?php the_permalink(); ?>"><?php echo esc_html__( 'See Project', 'factora' ); ?>
            <i class="elegant arrow_carrot-right"></i></a>
		<?php
	}
endif;

if ( ! function_exists( 'factora_service_readmore' ) ) :
	function factora_service_readmore() {
		$tx_readmore = esc_html__( 'Read More', 'factora' );
		?>
        <a class="read-more" href="<?php the_permalink(); ?>"><?php echo esc_attr( $tx_readmore ); ?></a>
		<?php
	}
endif;


if ( ! function_exists( 'factora_related_portfolio' ) ) :
	function factora_related_portfolio() {
		if ( ! factora_get_option( 'portfolio_related' ) ) {
			return;
		}

		$posts_per_page = intval( factora_get_option( 'portfolio_related_maximum_items' ) );
		$terms          = get_the_terms( get_the_ID(), 'portfolio_category' );
		$terms_id       = array();
		if ( $terms && ! is_wp_error( $terms ) ) :
			$terms_id[] = $terms[0]->term_taxonomy_id;
		endif;

		$args = array(
			'post_type'      => 'portfolio',
			'posts_per_page' => $posts_per_page,
			'tax_query'      => array(
				array(
					'taxonomy' => 'portfolio_category',
					'field'    => 'id',
					'terms'    => $terms_id,
				),
			),
		);

		$the_query = new WP_Query( $args );
		$value     = array();
		$count     = 0;

		if ( $the_query->have_posts() ) :

			while ( $the_query->have_posts() ) : $the_query->the_post();
				$permalink       = get_permalink();
				$id_post         = get_the_ID();
				$class           = 'col-xs-12 col-sm-4';
				$thumb           = get_the_post_thumbnail_url( $id_post, 'factora-lastest-blog-grid' );
				$img             = "<img src='$thumb'/>";
				$entry_thumbnail = sprintf( '<a class="post-thumbnail" href="%s">%s</a>', $permalink, $img );

				$title_length = factora_get_option( 'portfolio_title_length' );
				$title        = get_the_title();
				if ( ! empty( $title_length ) ) {
					$title = factora_title_limit( $title_length );
				}
				$title     = sprintf( '<h3 class="entry-title">%s</h3>', esc_attr( $title ) );
				$read_more = sprintf( ' <a class="read-more" href="%s">%s <i class="elegant arrow_carrot-right"></i></a>', get_permalink(), esc_html__( 'See Project', 'factora' ) );
				$value[]   = sprintf( '<li class="portfolio-item %s"><div class="wrapper"> %s<div class="portfolio-content">%s %s</div> <a class="hover" href="%s"></a></div></li>',
					$class, $entry_thumbnail, $title, $read_more, $permalink );
				$count ++;

			endwhile;
		endif;
		if ( $count > 3 ) :
			$class_related = 'related-dots';
		else: $class_related = 'related-no-dots';
		endif;
		?>
        <div class="related-portfolio <?php echo esc_attr( $class_related ); ?>">
            <div class="related-header">
                <h3 class="title"><?php echo esc_html__( 'Related Portfolio', 'factora' ); ?></h3>
				<?php if ( $count > 3 ) : ?>
                    <div class="arrow">
                        <div class="factora-left-arrow slick-arrow">
                            <i class="icon-chevron-left"></i>
                        </div>
                        <div class="factora-right-arrow slick-arrow">
                            <i class="icon-chevron-right"></i>
                        </div>
                    </div>
				<?php endif; ?>
            </div>
            <ul class="list-items row" id="factora-portfolio-related">
				<?php echo implode( '', $value ); ?>
            </ul>
        </div>
		<?php
	}
endif;
/**
 * Check is portfolio
 *
 * @since  1.0
 */
if ( ! function_exists( 'factora_service_pagination' ) ) {
	function factora_service_pagination() {
		if ( factora_get_option( 'service_pagination' ) == '1' ) {
			if ( factora_get_option( 'service_pagination_style' ) == '2' ) {
				$show_more = esc_html__( 'Load more', 'factora' );
				echo '<div class="col-xs-12 pag-2 numeric-navigation text-center">';
				$next = "<span>$show_more</span>";
				$prev = "";
			} else {
				echo '<div class="col-xs-12 pag-1 numeric-navigation text-center">';
				$next = "<span class='fa fa-angle-right'></span>";
				$prev = "<span class='fa fa-angle-left'></span>";
			}
			echo get_the_posts_pagination( array(
				'prev_text' => $prev,
				'next_text' => $next,
			) );
		}
	}
}

// Coming soon
if ( ! function_exists( 'factora_coming_soon_newletter' ) ) {
	function factora_coming_soon_newletter() {
		$newsletter = intval( factora_get_option( 'coming_soon_newsletter' ) );

		if ( ! $newsletter ) {
			return;
		}
		?>
        <div class="factora-coming-soon">
            <div class="container newsletter-form">
				<?php echo do_shortcode( wp_kses( factora_get_option( 'coming_soon_newsletter_form' ), wp_kses_allowed_html( 'post' ) ) ); ?>
            </div>
        </div>
		<?php
	}
}
add_action( 'factora_coming_soon_page_content', 'factora_coming_soon_newletter', 40 );

if ( ! function_exists( 'factora_coming_soon_socials' ) ) :
	function factora_coming_soon_socials() {

		$show_social = intval( factora_get_option( 'show_coming_soon_socials' ) );

		if ( ! $show_social ) {
			return;
		}
		$project_social = (array) factora_get_option( 'coming_soon_socials' );

		if ( $project_social ) {

			$socials = (array) factora_get_socials();

			printf( '<div class="container coming-soon__social">' );
			printf( '<ul class="list-socials">' );
			foreach ( $project_social as $social ) {
				foreach ( $socials as $name => $label ) {
					$link_url = $social['link_url'];

					if ( preg_match( '/' . $name . '/', $link_url ) ) {

						if ( $name == 'google' ) {
							$name = 'google-plus';
						}

						if ( $name == 'youtube' ) {
							$name = 'youtube-play';
						}

						printf( '<li><a href="%s" target="_blank"><i class="social_%s"></i></a></li>', esc_url( $link_url ), esc_attr( $name ) );
						break;
					}
				}
			}
			printf( '</ul>' );
			printf( '</div>' );

		}

	}

endif;

add_action( 'factora_coming_soon_page_content', 'factora_coming_soon_socials', 40 );


/**
 * Change markup of archive and category widget to include .count for post count
 *
 * @param string $output
 *
 * @return string
 */
function factora_widget_archive_count( $output ) {
	$output = preg_replace( '|\((\d+)\)|', '<span class="posts-count">(\\1)</span>', $output );

	return $output;
}

add_filter( 'wp_list_categories', 'factora_widget_archive_count' );
add_filter( 'get_archives_link', 'factora_widget_archive_count' );
?>