<?php
/**
 * Hooks for template footer
 *
 * @package Factora
 */

/**
 * Show Newsletter
 */

if ( ! function_exists( 'factora_show_newsletter' ) ) :
	function factora_show_newsletter() {
		if ( ! intval( factora_get_option( 'footer_newsletter' ) ) ) {
			return;
		}

		if ( is_page_template( 'template-coming-soon-page.php' ) ) {
			return;
		}

		$newsletter_title       = factora_get_option( 'footer_newsletter_title' );
		$newsletter_description = factora_get_option( 'footer_newsletter_description' );
		$newsletter_form        = factora_get_option( 'footer_newsletter_form' );
		?>
        <div id="newsletter-box" class="newsletter-box">
            <div class="container">
                <div class="content">
                    <div class="text">
						<?php if ( ! empty( $newsletter_title ) ) : ?>
                            <h3><?php echo esc_html( $newsletter_title ) ?></h3>
						<?php endif; ?>
						<?php echo do_shortcode( wp_kses( $newsletter_description, wp_kses_allowed_html( 'post' ) ) ) ?>
                    </div>
					<?php if ( ! empty( $newsletter_form ) ) : ?>
                        <div class="form">
							<?php echo do_shortcode( wp_kses( $newsletter_form, wp_kses_allowed_html( 'post' ) ) ) ?>
                        </div>
					<?php endif; ?>
                </div>
            </div>
        </div>
		<?php
	}

endif;

add_action( 'factora_before_footer', 'factora_show_newsletter' );


/**
 * Show background overlay
 */
if ( ! function_exists( 'factora_footer_background_overlay' ) ) :
	function factora_footer_background_overlay() {
		if ( empty( factora_get_option( 'footer_bg_overlay' ) ) ) {
			return;
		}
		?>
			<div class="footer-overlay"></div>
		<?php
	}
endif;

add_action( 'factora_footer', 'factora_footer_background_overlay', 10, 1 );


/**
 * Show footer
 */

if ( ! function_exists( 'factora_footer_widgets' ) ) :
	function factora_footer_widgets() {
		if ( ! intval( factora_get_option( 'footer_widget' ) ) ) {
			return;
		}

		if ( is_page_template( 'template-coming-soon-page.php' ) ) {
			return;
		}

		if ( is_active_sidebar( 'footer-1' ) == false &&
		     is_active_sidebar( 'footer-2' ) == false &&
		     is_active_sidebar( 'footer-3' ) == false &&
		     is_active_sidebar( 'footer-4' ) == false ) {
			return;
		}

		$footer_color = factora_get_option( 'footer_color' );
		$color = '';
		if($footer_color != 'dark'){
			$color = 'color-' . $footer_color;
		}
		?>

        <div id="footer-widgets" class="footer-widgets widgets-area <?php echo esc_attr( $color )?>">
            <div class="container">
                <div class="row">
					<?php
					$columns = max( 1, absint( factora_get_option( 'footer_widget_columns' ) ) );

					$col_class = 'col-xs-12 col-sm-6 col-md-4 col-lg-' . floor( 12 / $columns );
					for ( $i = 1; $i <= $columns; $i ++ ) :
						?>
                        <div class="footer-sidebar footer-<?php echo esc_attr( $i ) ?> <?php echo esc_attr( $col_class ) ?>">
							<?php dynamic_sidebar( "footer-$i" ); ?>
                        </div>
					<?php endfor; ?>
                </div>
            </div>
        </div>
		<?php
	}

endif;

add_action( 'factora_footer', 'factora_footer_widgets', 10, 1 );

/**
 * Show footer copyright
 */

if ( ! function_exists( 'factora_show_copyright' ) ) :
	function factora_show_copyright() {
		if ( ! intval( factora_get_option( 'footer_copyright' ) ) ) {
			return;
		}

		if ( is_page_template( 'template-coming-soon-page.php' ) ) {
			return;
		}

		$footer_color = factora_get_option( 'footer_color' );
		$color = '';
		if($footer_color != 'dark'){
			$color = 'color-' . $footer_color;
		}
		?>

        <div id="footer-copyright" class="footer-copyright <?php echo esc_attr( $color )?>">
            <div class="container">
                <div class="content">
	                <?php
                        factora_copyright_text();
                        factora_copyright_menu();
	                ?>
                </div>
            </div>
        </div>

		<?php
	}

endif;

add_action( 'factora_footer', 'factora_show_copyright', 20 );

/**
 * Copyright Text
 */
if ( ! function_exists( 'factora_copyright_text' ) ) :
	function factora_copyright_text() {
		$text = factora_get_option( 'footer_copyright_text' );
		if ( empty( $text ) ) {
			return;
		}

		echo '<div class="text">' . wp_kses( $text, wp_kses_allowed_html( 'post' ) ) . '</div>';
	}
endif;

/**
 * Copyright Social
 */
if ( ! function_exists( 'factora_copyright_menu' ) ) :
	function factora_copyright_menu() {

		$footer_copyright_menu = factora_get_option( 'footer_copyright_menu' );
		if(!intval(factora_get_option( 'footer_copyright_menu' ))){
			return;
		}

		?>
        <div class="footer-copyright-menu">
            <div class="footer-copyright-nav nav">
				<?php
				if ( has_nav_menu( 'footer-copyright' ) ) {
					wp_nav_menu(
						array(
							'theme_location' => 'footer-copyright',
							'container'      => false,
						) );
				}
				?>
	        </div>
        </div>
		<?php
	}
endif;

/**
 * Display back to top
 *
 * @since 1.0.0
 */
function factora_back_to_top() {
	if ( ! intval( factora_get_option( 'back_to_top' ) ) ) {
		return;
	}
	?>
    <a id="scroll-top" class="backtotop" href="#page-top">
        <i class="arrow_up"></i>
    </a>
	<?php
}

add_action( 'wp_footer', 'factora_back_to_top' );

/**
 * Add off mobile menu to footer
 *
 * @since 1.0.0
 */
function factora_off_canvas_mobile_menu() {
	?>
    <div class="primary-mobile-nav" id="primary-mobile-nav" role="navigation">
        <div class="mobile-nav-content">
            <div class="close-btn">
                <a href="#" class="close-canvas-mobile-panel"></a>
            </div>
            <div class="box-nav">
				<?php
				wp_nav_menu( array(
					'theme_location' => 'primary',
					'container'      => false,
				) );
				?>
            </div>
        </div>
    </div>
	<?php
}

add_action( 'wp_footer', 'factora_off_canvas_mobile_menu' );

/**
 * Display a layer to close canvas panel everywhere inside page
 *
 * @since 1.0.0
 */

if ( ! function_exists( 'factora_site_canvas_layer' ) ) :
	function factora_site_canvas_layer() {
		?>
        <div id="off-canvas-layer" class="factora-off-canvas-layer"></div>
		<?php
	}

endif;

add_action( 'wp_footer', 'factora_site_canvas_layer' );

/**
 * Adds photoSwipe dialog element
 */
function factora_gallery_images_lightbox() {
	?>
	<div id="pswp" class="pswp" tabindex="-1" role="dialog" aria-hidden="true">

		<div class="pswp__bg"></div>

		<div class="pswp__scroll-wrap">

			<div class="pswp__container">
				<div class="pswp__item"></div>
				<div class="pswp__item"></div>
				<div class="pswp__item"></div>
			</div>

			<div class="pswp__ui pswp__ui--hidden">

				<div class="pswp__top-bar">


					<div class="pswp__counter"></div>

					<button class="pswp__button pswp__button--close"
							title="<?php esc_attr_e( 'Close (Esc)', 'factora' ) ?>"></button>

					<button class="pswp__button pswp__button--share"
							title="<?php esc_attr_e( 'Share', 'factora' ) ?>"></button>

					<button class="pswp__button pswp__button--fs"
							title="<?php esc_attr_e( 'Toggle fullscreen', 'factora' ) ?>"></button>

					<button class="pswp__button pswp__button--zoom"
							title="<?php esc_attr_e( 'Zoom in/out', 'factora' ) ?>"></button>

					<div class="pswp__preloader">
						<div class="pswp__preloader__icn">
							<div class="pswp__preloader__cut">
								<div class="pswp__preloader__donut"></div>
							</div>
						</div>
					</div>
				</div>

				<div class="pswp__share-modal pswp__share-modal--hidden pswp__single-tap">
					<div class="pswp__share-tooltip"></div>
				</div>

				<button class="pswp__button pswp__button--arrow--left"
						title="<?php esc_attr_e( 'Previous (arrow left)', 'factora' ) ?>">
				</button>

				<button class="pswp__button pswp__button--arrow--right"
						title="<?php esc_attr_e( 'Next (arrow right)', 'factora' ) ?>">
				</button>

				<div class="pswp__caption">
					<div class="pswp__caption__center"></div>
				</div>

			</div>

		</div>

	</div>
	<?php
}

add_action( 'factora_after_footer', 'factora_gallery_images_lightbox' );
