<?php
/**
 * Hooks for template header
 *
 * @package Factora
 */


/**
 * Enqueue scripts and styles.
 */
function factora_scripts() {
	/**
	 * Register and enqueue styles
	 */
	wp_register_style( 'factora-fonts', factora_fonts_url(), array(), '20170801' );
	wp_register_style( 'bootstrap', get_template_directory_uri() . '/css/bootstrap.min.css', array(), '3.3.7' );
	wp_register_style( 'font-awesome', get_template_directory_uri() . '/css/font-awesome.min.css', array(), '4.7.0' );
	wp_register_style( 'eleganticons', get_template_directory_uri() . '/css/eleganticons.min.css', array(), '1.0.0' );
	wp_register_style( 'linearicons', get_template_directory_uri() . '/css/linearicons.min.css', array(), '1.0.0' );
	wp_register_style( 'slick', get_template_directory_uri() . '/css/slick.css', array(), '4.7.0' );
	wp_register_style( 'photoswipe', get_template_directory_uri() . '/css/photoswipe.min.css', array(), '4.7.0' );
	wp_register_style( 'swiper', get_template_directory_uri() . '/css/swiper.min.css', array(), '4.7.0' );
	wp_register_style( 'magnific', get_template_directory_uri() . '/css/magnific-popup.css', array(), '4.7.0' );

	wp_enqueue_style(
		'factora', get_template_directory_uri() . '/style.css', array(
		'factora-fonts',
		'font-awesome',
		'bootstrap',
		'eleganticons',
		'linearicons',
		'slick',
		'photoswipe',
		'swiper',
		'magnific',
	), '20181221' );

	wp_add_inline_style( 'factora', factora_get_inline_style() );

	/**
	 * Register and enqueue scripts
	 */
	$min = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

	wp_enqueue_script( 'html5shiv', get_template_directory_uri() . '/js/plugins/html5shiv.min.js', array(), '3.7.2' );
	wp_script_add_data( 'html5shiv', 'conditional', 'lt IE 9' );

	wp_enqueue_script( 'respond', get_template_directory_uri() . '/js/plugins/respond.min.js', array(), '1.4.2' );
	wp_script_add_data( 'respond', 'conditional', 'lt IE 9' );

	wp_register_script( 'photoswipe', get_template_directory_uri() . '/js/plugins/photoswipe.min.js', array(), '4.1.1', true );
	wp_register_script( 'photoswipe-ui', get_template_directory_uri() . '/js/plugins/photoswipe-ui.min.js', array( 'photoswipe' ), '4.1.1', true );
	wp_register_script( 'isotope', get_template_directory_uri() . '/js/plugins/isotope.pkgd.min.js', array(), '2.2.2', true );
	wp_register_script( 'slick', get_template_directory_uri() . '/js/plugins/slick.min.js', array(), '1.0', true );
	wp_register_script( 'countdown', get_template_directory_uri() . '/js/plugins/jquery.countdown.js', array( 'imagesloaded' ), '1.0', true );
	wp_register_script( 'event-move', get_template_directory_uri() . '/js/plugins/jquery.event.move.js', array(), '2.0', true );
	wp_register_script( 'twentytwenty', get_template_directory_uri() . '/js/plugins/jquery.twentytwenty.js', array(), '1.0', true );
	wp_register_script( 'mapbox', get_template_directory_uri() . '/js/plugins/mapbox.min.js', array(), '1.0', true );
	wp_register_script( 'mapboxgl', get_template_directory_uri() . '/js/plugins/mapbox-gl.min.js', array(), '1.0', true );
	wp_register_script( 'mapbox-sdk', get_template_directory_uri() . '/js/plugins/mapbox-sdk.min.js', array(), '1.0', true );
	wp_register_script( 'flipclock', get_template_directory_uri() . '/js/plugins/flipclock.min.js', array(), '1.0', true );
	wp_register_script( 'swiper', get_template_directory_uri() . '/js/plugins/swiper.min.js', array(), '1.0', true );
	wp_register_script( 'counterup', get_template_directory_uri() . '/js/plugins/jquery.counterup.min.js', array(), '1.0', true );
	wp_register_script( 'waypoints', get_template_directory_uri() . '/js/plugins/waypoints.min.js', array(), '1.0', true );
	wp_register_script( 'magnific-popup', get_template_directory_uri() . '/js/plugins/jquery.magnific-popup.min.js', array(), '1.0', true );
	wp_register_script( 'scrollmagic', get_template_directory_uri() . '/js/plugins/ScrollMagic.min.js', array(), '1.0', true );
	wp_register_script( 'tweenmax', get_template_directory_uri() . '/js/plugins/TweenMax.min.js', array(), '1.0', true );
	wp_register_script( 'animationgsap', get_template_directory_uri() . '/js/plugins/animation.gsap.js', array(), '1.0', true );

	wp_enqueue_style( 'photoswipe' );
	wp_enqueue_script( 'photoswipe-ui' );

	$photoswipe_skin = 'photoswipe-default-skin';
	if ( wp_style_is( $photoswipe_skin, 'registered' ) && ! wp_style_is( $photoswipe_skin, 'enqueued' ) ) {
		wp_enqueue_style( $photoswipe_skin );
	}

	wp_enqueue_script( 'factora', get_template_directory_uri() . "/js/scripts$min.js", array(
		'jquery',
		'slick',
		'countdown',
		'event-move',
		'twentytwenty',
		'mapbox',
		'mapboxgl',
		'mapbox-sdk',
		'imagesloaded',
		'isotope',
		'photoswipe',
		'flipclock',
		'swiper',
		'counterup',
		'waypoints',
		'magnific-popup',
		'scrollmagic',
		'tweenmax',
		'animationgsap',
	), '20181221', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	wp_localize_script(
		'factora', 'factoraData', array(
			'direction'           => is_rtl() ? 'true' : 'false',
			'days'                => esc_html__( 'Days', 'factora' ),
			'hours'               => esc_html__( 'Hours', 'factora' ),
			'minutes'             => esc_html__( 'Minutes', 'factora' ),
			'seconds'             => esc_html__( 'Seconds', 'factora' ),
		)
	);
}

add_action( 'wp_enqueue_scripts', 'factora_scripts' );

/**
 * Display show top bar
 *
 * @since 1.0.0
 */
if ( ! function_exists( 'factora_show_topbar' ) ) :
	function factora_show_topbar() {
		if ( is_page_template( 'template-coming-soon-page.php' ) ) {
			return;
		}
		if ( factora_get_option( 'topbar' ) == 0 ) {
			return;
		}
		get_template_part( 'template-parts/headers/topbar' );
	}
endif;
add_action( 'factora_before_header', 'factora_show_topbar', 10, 1 );

/**
 * Display show top bar mobile
 *
 * @since 1.0.0
 */
if ( ! function_exists( 'factora_show_topbar_mobile' ) ) :
	function factora_show_topbar_mobile() {
		if ( is_page_template( 'template-coming-soon-page.php' ) ) {
			return;
		}
		if ( factora_get_option( 'topbar_mobile' ) == 0 ) {
			return;
		}
		get_template_part( 'template-parts/headers/topbar-mobile' );
	}
endif;
add_action( 'factora_before_header', 'factora_show_topbar_mobile', 10, 1 );

/**
 * Display the site header
 *
 * @since 1.0.0
 */
if ( ! function_exists( 'factora_show_header' ) ) :
	function factora_show_header() {
		if ( is_page_template( 'template-coming-soon-page.php' ) ) {
			return;
		}
		$header_layout = factora_get_option( 'header_layout' );
		get_template_part( 'template-parts/headers/layout', $header_layout );
	}
endif;
add_action( 'factora_header', 'factora_show_header' );

/**
 * Returns CSS for the color schemes.
 *
 *
 * @param array $colors Color scheme colors.
 *
 * @return string Color scheme CSS.
 */
function factora_get_color_scheme_css( $colors ) {
	return <<<CSS
	/* Color Scheme */
	/* Background Color */
	.factora-images-carousel .slide-arrow:hover,
    .factora-social .item a:hover,
    .factora-contact-form-7.factora--style-2,
    .factora-button a,
    .factora-button a:hover, .factora-button a:focus,
    .factora-portfolio-carousel.style-2 .portfolio-content,
    .factora-portfolio-carousel .slick-dots li.slick-active button:before,
    .factora-portfolio-masonry .portfolio-content,
    .factora-service-carousel .slick-dots li.slick-active button:before,
    .service-section-title .entry-title:before,
    .service-section-title .view-all,
    .factora-team-carousel .slick-dots li.slick-active button:before,
    .factora-faq__style-1 .factora-faq__box.active .factora-faq__question,
    .factora-faq__style-2 .factora-faq__box.active .factora-faq__question,
    .factora-partner-carousel .slide-arrow:hover,
    .factora-testimonial-carousel--style-1 ul.slick-dots li.slick-active button:before,
    .factora-testimonial-carousel--style-1 .slick-dots li.slick-active button:before,
    .btn-primary,
    .btn-primary:hover, .btn-primary:focus,
    button:not(.search-submit),input[type=button]:not(.search-submit),input[type=reset],input[type=submit]:not(.search-submit),
    button:not(.search-submit):hover, button:not(.search-submit):focus,input[type=button]:not(.search-submit):hover,input[type=button]:not(.search-submit):focus,input[type=reset]:hover,input[type=reset]:focus,input[type=submit]:not(.search-submit):hover,input[type=submit]:not(.search-submit):focus,
    button:not(.search-submit).alt,input[type=button]:not(.search-submit).alt,input[type=reset].alt,input[type=submit]:not(.search-submit).alt,
    button:not(.search-submit).alt:hover, button:not(.search-submit).alt:focus,input[type=button]:not(.search-submit).alt:hover,input[type=button]:not(.search-submit).alt:focus,input[type=reset].alt:hover,input[type=reset].alt:focus,input[type=submit]:not(.search-submit).alt:hover,input[type=submit]:not(.search-submit).alt:focus,
    .blog-navigation .nav-previous-ajax a,
    .widget_mc4wp_form_widget,
    .primary-nav > ul > li .ft-active-menu,
    .header-v2 .primary-nav > ul > li.current-menu-parent > a:after, .header-v2 .primary-nav > ul > li.current-menu-item > a:after, .header-v2 .primary-nav > ul > li.current-menu-ancestor > a:after,.header-v4 .primary-nav > ul > li.current-menu-parent > a:after,.header-v4 .primary-nav > ul > li.current-menu-item > a:after,.header-v4 .primary-nav > ul > li.current-menu-ancestor > a:after,
    .header-v2 .primary-nav > ul > li > a:after,.header-v4 .primary-nav > ul > li > a:after,
    .site-header .menu-extras .extra-menu-item .mini-item-counter,
    .woocommerce ul.cart_list .woocommerce-mini-cart__buttons .button,.woocommerce .widget_shopping_cart_content .woocommerce-mini-cart__buttons .button,
    .woocommerce ul.cart_list .woocommerce-mini-cart__buttons .button:hover, .woocommerce ul.cart_list .woocommerce-mini-cart__buttons .button:focus,.woocommerce .widget_shopping_cart_content .woocommerce-mini-cart__buttons .button:hover,.woocommerce .widget_shopping_cart_content .woocommerce-mini-cart__buttons .button:focus,
    .header-button .content,
    .newsletter-box .content,
    .portfolio-listing .numeric-navigation.pag-2 .pagination .page-numbers.next, .portfolio-grid .numeric-navigation.pag-2 .pagination .page-numbers.next, .portfolio-full-width .numeric-navigation.pag-2 .pagination .page-numbers.next,
    .portfolio-listing .portfolio-item:hover .wrapper,
    .single-portfolio .related-portfolio .list-items .slick-dots li.slick-active button:before,
    .factora-service-widget .service-item:hover .item, .factora-service-widget .service-item.active .item,
    table.woocommerce-cart-form__contents.shop_table tr td.actions .continue,
	table.woocommerce-cart-form__contents.shop_table tr td.actions .continue:hover, table.woocommerce-cart-form__contents.shop_table tr td.actions .continue:focus,
	table.woocommerce-cart-form__contents.shop_table tr td.actions .clear-cart:hover, table.woocommerce-cart-form__contents.shop_table tr td.actions .update_cart:hover,
	table.woocommerce-cart-form__contents .cart-actions .btn-shop,
	table.woocommerce-cart-form__contents .cart-actions .btn-shop:hover, table.woocommerce-cart-form__contents .cart-actions .btn-shop:focus,
	ul.products li.product .button,
	ul.products li.product .added_to_cart,
	.single-product div.product p.stock:before,
	.single-product div.product form.cart .button,
	.single-product div.product .woocommerce-tabs .wc-tabs li:after,
	.cart-collaterals .checkout-button,
	.cart-collaterals .checkout-button:hover, .cart-collaterals .checkout-button:focus,
	.woocommerce-checkout .woocommerce-checkout-payment .button,
	.woocommerce-checkout .woocommerce-checkout-payment .button:hover, .woocommerce-checkout .woocommerce-checkout-payment .button:focus,
	.woocommerce-pagination ul .page-numbers:hover:after, .woocommerce-pagination ul .page-numbers.current:after,
	.woocommerce-pagination ul .page-numbers.next:hover, .woocommerce-pagination ul .page-numbers.prev:hover,
	.woocommerce-message .button,.woocommerce-info .button,.woocommerce-error .button,.woocommerce-noreviews .button,p.no-comments .button,
	.footer-widgets .factora-social-links-widget .socials-list li a:hover,
	.widget .tagcloud a:hover
	{background-color: $colors;}
	
	/* Border Color */
	.factora-faq__style-1 .factora-faq__box.active .factora-faq__question, 
	.factora-post__taxs-list a:hover,.factora-post__entry-header .title-post a:hover, 
	.factora-post__taxs-list ul li a.selected,
	.service-section-title .view-all,
	.factora-service-widget .service-item:hover .item, 
	.factora-service-widget .service-item.active .item
	{border-color: $colors;}
	
	/* Border Left Color */
	.factora-section-title.factora-style-2
	{border-left-color: $colors;}

	/* Color */
	blockquote cite, 
    .factora-portfolio-carousel.style-1 .portfolio-content .read-more, 
    .factora-portfolio-carousel.style-1 .slick-arrow:hover .arrow, 
    .portfolio-grid-header .button-group .button.active, .portfolio-grid-header .button-group .button:hover, 
    .factora-service-icons .service-icons-item .entry-thumbnail span, 
    .factora-team-carousel .slick-arrow:hover, 
    .factora-faq__box.active .factora-faq__question, 
    .factora-icon-box-carousel .factora-icon, 
    .factora-icon-box .factora-icon, 
    .factora-counter .number, .factora-counter .tx_after, 
    .factora-testimonial-carousel__box .rating .icon_star, 
    .factora-testimonial-carousel--style-1 .field-icon svg, 
    .factora-testimonial-carousel--style-1 .testimonial--arrow:hover, 
    .factora-testimonial-carousel--style-2 .rating .icon_star, 
    .factora-testimonial-carousel--style-2 .testimonial--arrow:hover, 
    .mfp-iframe-holder button.mfp-close:hover, 
    .primary-mobile-nav ul.menu li > a:hover, 
    .primary-mobile-nav ul.menu li.active > a, 
    .primary-mobile-nav ul.menu li.current_page_parent > a, .primary-mobile-nav ul.menu li.current-menu-item > a, .primary-mobile-nav ul.menu li.current-menu-ancestor > a, .primary-mobile-nav ul.menu li.current-menu-parent > a, 
    .primary-mobile-nav a:hover, .primary-mobile-nav a:focus, .primary-mobile-nav a:active, 
    .widget_tag_cloud a:hover,.widget ul li a:hover, 
    .widget_product_categories ul li:hover:before, 
    .widget_product_categories ul li:hover a, 
    .factora-post__taxs-list a:hover,.factora-post__entry-header .title-post a:hover, 
    .factora-post__taxs-list ul li a.selected, 
    .factora-post__socials-share ul li a:hover, 
    .factora-post__related .slick-arrow:hover i, 
    .error404 .error-404 .icon, 
    .error404 .error-404 .description a, 
    .comment-list li .comment-edit-link,.comment-list li .comment-reply-link, 
    .comment-respond .logged-in-as a:hover, 
    .topbar .widget ul li a:hover, 
    .topbar a:hover, 
    .primary-nav a:hover, .primary-nav a:focus, .primary-nav a:active, 
    .primary-nav > ul > li.current-menu-parent > a, .primary-nav > ul > li.current-menu-item > a, .primary-nav > ul > li.current-menu-ancestor > a, 
    .primary-nav ul ul > .current-menu-item > a, 
    .primary-nav li li a:hover, 
    .primary-nav li li.menu-item-has-children:hover:after,
    .header-hotline .content .number, 
    .main-color, 
    .page-header .site-breadcrumb, 
    .page-header .site-breadcrumb li a:hover, 
    .footer-widgets .widget ul li a:hover, 
    .footer-widgets .widget .menu li.current_page_item > a, 
    .footer-copyright .content a, 
    .footer-copyright .content .footer-social .social a:hover, 
    .portfolio-listing .portfolio-cats-filter .button-group .button:hover, .portfolio-listing .portfolio-cats-filter .button-group .button.active, .portfolio-grid .portfolio-cats-filter .button-group .button:hover, .portfolio-grid .portfolio-cats-filter .button-group .button.active, .portfolio-full-width .portfolio-cats-filter .button-group .button:hover, .portfolio-full-width .portfolio-cats-filter .button-group .button.active, 
    .portfolio-listing .numeric-navigation.pag-2 .pagination .loader:before, .portfolio-grid .numeric-navigation.pag-2 .pagination .loader:before, .portfolio-full-width .numeric-navigation.pag-2 .pagination .loader:before, 
    .single-portfolio .portfolio-navigation .nav-links a:hover .arrow, 
    .single-portfolio .portfolio-navigation .nav-links .nav-project a:hover, 
    .single-portfolio .related-portfolio .related-header .slick-arrow:hover, 
    .factora-archive-service .service-item .service-content .content-wrapper .read-more, 
    .factora-service-widget .service-icon .service-item .factora-icon,
    ul.products li.product .woocommerce-loop-product__title:hover a,ul.products li.product .woocommerce-loop-category__title:hover a, 
	.single-product div.product .flex-control-nav .slick-arrow:hover, 
	.single-product div.product .woocommerce-tabs .wc-tabs .active a, 
	.factora-related-products .slick-arrow:hover,.factora-upsells-products .slick-arrow:hover,.factora-cross-sells-products .slick-arrow:hover, 
	.woocommerce-checkout .woocommerce-terms-and-conditions-wrapper .woocommerce-form__label-for-checkbox > span a, 
	.woocommerce-MyAccount-navigation ul li:hover a, .woocommerce-MyAccount-navigation ul li.is-active a, 
	.woocommerce-pagination ul .page-numbers:hover, .woocommerce-pagination ul .page-numbers.current,
	.footer-copyright.color-light .content .footer-copyright-menu .menu li a:hover,
	.footer-widgets.color-light .widget a:hover,
	.widget_archive li:hover, .widget_categories li:hover,
	.widget_archive li:hover a, .widget_categories li:hover a,
	.widget_archive li:hover a:before, .widget_categories li:hover a:before
	{color: $colors;}

	/* Background */
	.factora-service-grid.style-1 .service-section-title, 
    .factora-service-icons .service-icons-item:hover, 
    .factora-brochure, 
    .factora-service-carousel .read-more, 
    .factora-team-carousel .content-item:hover .team-content, 
    .widget_price_filter .ui-slider .ui-slider-handle, 
    .widget_price_filter .ui-slider .ui-slider-range, 
    .backtotop, 
    .portfolio-grid .portfolio-item .hover, .portfolio-full-width .portfolio-item .hover,
    .factora-portfolio-grid .entry-content
	{background: $colors;}

CSS;
}

/**
 * Get typography CSS base on settings
 *
 * @since 1.1.6
 */
if ( ! function_exists( 'factora_typography_css' ) ) :
	function factora_typography_css() {
		$css        = '';
		$properties = array(
			'font-family'    => 'font-family',
			'font-size'      => 'font-size',
			'variant'        => 'font-weight',
			'line-height'    => 'line-height',
			'letter-spacing' => 'letter-spacing',
			'color'          => 'color',
			'text-transform' => 'text-transform',
			'text-align'     => 'text-align',
		);

		$settings = array(
			'body_typo'        => 'body',
			'heading1_typo'    => 'h1',
			'heading2_typo'    => 'h2',
			'heading3_typo'    => 'h3, .factora-section-title .title',
			'heading4_typo'    => 'h4, .footer-widgets .widget-title',
			'heading5_typo'    => 'h5',
			'heading6_typo'    => 'h6',
			'menu_typo'        => '.primary-nav a, .primary-mobile-nav a',
			'sub_menu_typo'    => '.primary-nav li li a, .primary-mobile-nav ul.menu ul li a',
			'button_typo'      => '',
			'footer_text_typo' => '.footer-widgets, .footer-widgets a, .footer-widgets .widget a, .footer-copyright, .footer-copyright a',
		);

		foreach ( $settings as $setting => $selector ) {
			$typography = factora_get_option( $setting );
			$default    = (array) factora_get_option_default( $setting );
			$style      = '';

			foreach ( $properties as $key => $property ) {
				if ( isset( $typography[ $key ] ) && ! empty( $typography[ $key ] ) ) {
					if ( isset( $default[ $key ] ) && strtoupper( $default[ $key ] ) == strtoupper( $typography[ $key ] ) ) {
						continue;
					}

					$value = 'font-family' == $key ? '"' . rtrim( trim( $typography[ $key ] ), ',' ) . '"' : $typography[ $key ];
					$value = 'variant' == $key ? str_replace( 'regular', '400', $value ) : $value;

					if ( $value ) {
						$style .= $property . ': ' . $value . ';';
					}
				}
			}

			if ( ! empty( $style ) ) {
				$css .= $selector . '{' . $style . '}';
			}
		}

		return $css;
	}
endif;
/**
 * Returns CSS for the typography.
 *
 * @return string typography CSS.
 */
function factora_get_heading_typography_css() {

	$headings   = array(
		'h1' => 'heading1_typo',
		'h2' => 'heading2_typo',
		'h3' => 'heading3_typo',
		'h4' => 'heading4_typo',
		'h5' => 'heading5_typo',
		'h6' => 'heading6_typo'
	);
	$inline_css = '';
	foreach ( $headings as $heading ) {
		$keys = array_keys( $headings, $heading );
		if ( $keys ) {
			$inline_css .= factora_get_heading_font( $keys[0], $heading );
		}
	}

	return $inline_css;

}

/**
 * Returns CSS for the typography.
 *
 *
 * @param array $body_typo Color scheme body typography.
 *
 * @return string typography CSS.
 */
function factora_get_heading_font( $key, $heading ) {

	$inline_css   = '';
	$heading_typo = factora_get_option( $heading );

	if ( $heading_typo ) {
		if ( isset( $heading_typo['font-family'] ) && strtolower( $heading_typo['font-family'] ) !== 'Lato' ) {
			$inline_css .= $key . '{font-family:' . rtrim( trim( $heading_typo['font-family'] ), ',' ) . ', Arial, sans-serif}';
		}
	}

	if ( empty( $inline_css ) ) {
		return;
	}

	return <<<CSS
	{$inline_css}
CSS;
}


/**
 * Display the header minimized
 *
 * @since 1.0.0
 */
function factora_header_minimized() {
	if ( ! intval( factora_get_option( 'header_sticky' ) ) ) {
		return;
	}

	$css_class = 'factora-header-' . factora_get_option( 'header_layout' );

	printf( '<div id="factora-header-minimized" class="factora-header-minimized %s"></div>', esc_attr( $css_class ) );

}

add_action( 'factora_before_header', 'factora_header_minimized' );
