<?php
/**
 * Custom layout functions  by hooking templates
 *
 * @package Factora
 */


/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 *
 * @return array
 */
function factora_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	$blog_view = factora_get_option( 'blog_view' );

	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	if ( is_singular( 'post' ) ) {
		$classes[] = 'factora-blog';
		$classes[] = factora_get_option( 'single_post_layout' );
	} elseif ( factora_is_blog() ) {
		$classes[] = 'factora-blog';
		if ( $blog_view == 'list' ) {
			$classes[] = factora_get_option( 'blog_layout' );
		}
	}
	if ( intval( factora_get_option( 'header_sticky' ) ) ) {
		$classes[] = 'header-sticky';
	}

	if ( factora_is_portfolio() ) {
		if ( ! is_singular() ) {
			$classes[] = 'portfolio-' . factora_get_option( 'portfolio_layout' );
		}
	}

	if ( factora_is_catalog() || ( function_exists( 'is_product' ) && is_product() ) ) {
		$classes[] = 'factora-catalog';
		$classes[] = factora_get_option( 'catalog_layout' );
	}

	if ( factora_is_service() ) {
		$classes[] = 'factora-archive-service';
	}

	if ( intval( factora_get_option( 'footer_newsletter' ) ) ) {
		$classes[] = 'footer-newsletter';
	}

	$header_layout = factora_get_option( 'header_layout' );

	$classes[] = 'header-v' . $header_layout;
	$classes[] = factora_get_layout();

	if ( $skin = factora_get_option( 'color_skin' ) ) {
		$classes[] = 'factora-' . $skin . '-skin';
	}

	return $classes;
}

add_filter( 'body_class', 'factora_body_classes' );

/**
 * Print the open tags of site content container
 */

if ( ! function_exists( 'factora_open_site_content_container' ) ) :
	function factora_open_site_content_container() {

		printf( '<div class="%s"><div class="row">', esc_attr( apply_filters( 'factora_site_content_container_class', factora_content_container_class() ) ) );
	}
endif;

add_action( 'factora_after_site_content_open', 'factora_open_site_content_container' );

/**
 * Print the close tags of site content container
 */

if ( ! function_exists( 'factora_close_site_content_container' ) ) :
	function factora_close_site_content_container() {
		print( '</div></div>' );
	}

endif;

add_action( 'factora_before_site_content_close', 'factora_close_site_content_container' );