<?php
/**
 * Custom functions that act on page header templates
 *
 * @package factora
 */

/**
 * Get page header
 *
 * @since  1.0
 *
 *
 */

if ( ! function_exists( 'factora_page_header' ) ) :
	function factora_page_header() {
		get_template_part( 'template-parts/page', 'header' );
	}

endif;
add_action( 'factora_after_header', 'factora_page_header' );

/**
 * The archive title
 *
 * @since  1.0
 *
 * @param  array $title
 *
 * @return mixed
 */
function factora_the_archive_title( $title ) {
	if ( is_search() ) {
		$title = sprintf( esc_html__( 'Search Results', 'factora' ) );
	} elseif ( is_404() ) {
		$title = sprintf( esc_html__( 'Page Not Found', 'factora' ) );
	} elseif ( is_page() ) {
		$title = get_the_title();
	} elseif ( is_home() && is_front_page() ) {
		$title = esc_html__( 'The Latest Posts', 'factora' );
	} elseif ( is_home() && ! is_front_page() ) {
		$title = get_the_title( intval(get_option( 'page_for_posts' )) );
	} elseif ( function_exists( 'is_shop' ) && is_shop() ) {
		$title = get_the_title( intval(get_option( 'woocommerce_shop_page_id' )) );
	} elseif ( function_exists( 'is_product' ) && is_product() ) {
		$title = get_the_title();
	} elseif ( is_single() ) {
		$title = get_the_title();
	} elseif ( is_post_type_archive( 'portfolio' ) ) {
		$title = esc_html__( 'Portfolio', 'factora' );
	}elseif ( is_post_type_archive( 'testimonial' ) ) {
		$title = esc_html__( 'Testimonial', 'factora' );
	} elseif ( is_tax() || is_category() ) {
		$title = single_term_title( '', false );
	}

	if ( intval(get_option( 'woocommerce_shop_page_id' )) ) {
		if ( is_front_page() && ( get_option( 'woocommerce_shop_page_id' ) == get_option( 'page_on_front' ) ) ) {
			$title = get_the_title( get_option( 'woocommerce_shop_page_id' ) );
		}
	}


	return $title;
}

add_filter( 'get_the_archive_title', 'factora_the_archive_title', 30 );

if ( ! function_exists( 'factora_page_header_style' ) ) :
	/**
	 * Get inline style data
	 */
	function factora_page_header_style( $inline_css ) {
		if ( factora_is_blog() ) {
			$padding_top      = factora_get_option( 'page_header_blog_padding_top' );
			$padding_bottom   = factora_get_option( 'page_header_blog_padding_bottom' );
			$background_img   = factora_get_option( 'page_header_blog_bg' );
			$background_color = factora_get_option( 'page_header_blog_color' );
			$title_color      = factora_get_option( 'page_header_blog_title_color' );
			$breadcrumb_color = factora_get_option( 'page_header_blog_br_color' );
			$breadcrumb_link  = factora_get_option( 'page_header_blog_br_link_color' );
		} elseif ( is_singular( 'post' ) ) {
			$padding_top      = factora_get_option( 'page_header_post_padding_top' );
			$padding_bottom   = factora_get_option( 'page_header_post_padding_bottom' );
			$background_img   = factora_get_option( 'page_header_post_bg' );
			$background_color = factora_get_option( 'page_header_post_color' );
			$title_color      = factora_get_option( 'page_header_post_title_color' );
			$breadcrumb_color = factora_get_option( 'page_header_post_br_color' );
			$breadcrumb_link  = factora_get_option( 'page_header_post_br_link_color' );
		} elseif ( is_page() ) {
			$padding_top      = factora_get_option( 'page_header_page_padding_top' );
			$padding_bottom   = factora_get_option( 'page_header_page_padding_bottom' );
			$background_img   = factora_get_option( 'page_header_page_bg' );
			$background_color = factora_get_option( 'page_header_page_color' );
			$title_color      = factora_get_option( 'page_header_page_title_color' );
			$breadcrumb_color = factora_get_option( 'page_header_page_br_color' );
			$breadcrumb_link  = factora_get_option( 'page_header_page_br_link_color' );

		} elseif ( factora_is_service() ) {
			$padding_top      = factora_get_option( 'page_header_service_padding_top' );
			$padding_bottom   = factora_get_option( 'page_header_service_padding_bottom' );
			$background_img   = factora_get_option( 'page_header_service_bg' );
			$background_color = factora_get_option( 'page_header_service_color' );
			$title_color      = factora_get_option( 'page_header_service_title_color' );
			$breadcrumb_color = factora_get_option( 'page_header_service_br_color' );
			$breadcrumb_link  = factora_get_option( 'page_header_service_br_link_color' );
		} elseif ( is_singular( 'service' ) ) {
			$padding_top      = factora_get_option( 'page_header_service_single_padding_top' );
			$padding_bottom   = factora_get_option( 'page_header_service_single_padding_bottom' );
			$background_img   = factora_get_option( 'page_header_service_single_bg' );
			$background_color = factora_get_option( 'page_header_service_single_color' );
			$title_color      = factora_get_option( 'page_header_service_single_title_color' );
			$breadcrumb_color = factora_get_option( 'page_header_service_single_br_color' );
			$breadcrumb_link  = factora_get_option( 'page_header_service_single_br_link_color' );
		}elseif ( factora_is_portfolio() ) {
			$padding_top      = factora_get_option( 'page_header_portfolio_padding_top' );
			$padding_bottom   = factora_get_option( 'page_header_portfolio_padding_bottom' );
			$background_img   = factora_get_option( 'page_header_portfolio_bg' );
			$background_color = factora_get_option( 'page_header_portfolio_color' );
			$title_color      = factora_get_option( 'page_header_portfolio_title_color' );
			$breadcrumb_color = factora_get_option( 'page_header_portfolio_br_color' );
			$breadcrumb_link  = factora_get_option( 'page_header_portfolio_br_link_color' );
		} elseif ( is_singular( 'portfolio' ) ) {
			$padding_top      = factora_get_option( 'page_header_portfolio_single_padding_top' );
			$padding_bottom   = factora_get_option( 'page_header_portfolio_single_padding_bottom' );
			$background_img   = factora_get_option( 'page_header_portfolio_single_bg' );
			$background_color = factora_get_option( 'page_header_portfolio_single_color' );
			$title_color      = factora_get_option( 'page_header_portfolio_single_title_color' );
			$breadcrumb_color = factora_get_option( 'page_header_portfolio_single_br_color' );
			$breadcrumb_link  = factora_get_option( 'page_header_portfolio_single_br_link_color' );
		} else {
			$padding_top      = factora_get_option( 'page_header_padding_top' );
			$padding_bottom   = factora_get_option( 'page_header_padding_bottom' );
			$background_img   = factora_get_option( 'page_header_bg' );
			$background_color = factora_get_option( 'page_header_color' );
			$title_color      = factora_get_option( 'page_header_title_color' );
			$breadcrumb_color = factora_get_option( 'page_header_br_color' );
			$breadcrumb_link  = factora_get_option( 'page_header_br_link_color' );
		}

		$post_id = get_the_ID();
		if ( function_exists( 'is_shop' ) && is_shop() ) {
			$post_id = intval(get_option( 'woocommerce_shop_page_id' ));
		}

		$background_inline = get_post_meta( $post_id, 'page_header_bg', true );
		if ( ! empty( $background_inline ) ) {
			$background_img = wp_get_attachment_url( $background_inline );
		}

		$background_color_inline = get_post_meta( $post_id, 'page_header_color', true );
		if ( ! empty( $background_color_inline ) ) {
			$background_color = $background_color_inline;
		}

		$title_color_inline = get_post_meta( $post_id, 'page_header_title_color', true );
		if ( ! empty( $title_color_inline ) ) {
			$title_color = $title_color_inline;
		}

		$breadcrumb_color_inline = get_post_meta( $post_id, 'page_header_br_color', true );
		if ( ! empty( $breadcrumb_color_inline ) ) {
			$breadcrumb_color = $breadcrumb_color_inline;
		}

		$breadcrumb_title_color_inline = get_post_meta( $post_id, 'page_header_br_link_color', true );
		if ( ! empty( $breadcrumb_title_color_inline ) ) {
			$breadcrumb_link = $breadcrumb_title_color_inline;
		}

		$padding_top_inline = get_post_meta( $post_id, 'page_header_padding_top', true );
		if ( $padding_top_inline != 0 ) {
			$padding_top = $padding_top_inline;
		}

		$padding_bottom_inline = get_post_meta( $post_id, 'page_header_padding_bottom', true );
		if ( $padding_bottom_inline != 0 ) {
			$padding_bottom = $padding_bottom_inline;
		}

		if ( ! empty( $background_img ) ) {
			$inline_css .= '.page-header { background-image: url(' . esc_url( $background_img ) . ')}';
		}

		if ( ! empty( $background_color ) ) {
			$inline_css .= '.page-header { background-color: ' . esc_attr( $background_color ) . '}';
		}

		if ( ! empty( $title_color ) ) {
			$inline_css .= '.page-header .page-title { color: ' . esc_attr( $title_color ) . '}';
		}

		if ( ! empty( $breadcrumb_color ) ) {
			$inline_css .= '.page-header .site-breadcrumb { color: ' . esc_attr( $breadcrumb_color ) . '}';
		}

		if ( ! empty( $breadcrumb_link ) ) {
			$inline_css .= '.page-header .site-breadcrumb li a { color: ' . esc_attr( $breadcrumb_link ) . '}';
		}

		if ( $padding_top != '50' ) {
			$inline_css .= '.page-header { padding-top: ' . intval( $padding_top ) . 'px; }';
		}
		if ( $padding_bottom != '50' ) {
			$inline_css .= '.page-header { padding-bottom: ' . intval( $padding_bottom ) . 'px; }';
		}

		return $inline_css;


	}

endif;
add_filter( 'factora_inline_style', 'factora_page_header_style' );