<?php
/**
 * Custom functions that act on header templates
 *
 * @package Factora
 */

/**
 * Register fonts
 *
 * @since  1.0.0
 *
 * @return string
 */

if ( ! function_exists( 'factora_fonts_url' ) ):
	function factora_fonts_url() {
		$fonts_url = '';

		/* Translators: If there are characters in your language that are not
		* supported by Montserrat, translate this to 'off'. Do not translate
		* into your own language.
		*/
		if ( 'off' !== _x( 'on', 'Rubik font: on or off', 'factora' ) ) {
			$font_families[] = 'Rubik:300,400,500,600,700';
		}

		if ( 'off' !== _x( 'on', 'Montserrat font: on or off', 'factora' ) ) {
			$font_families[] = 'Montserrat:300,400,500,600,700';
		}

		if ( ! empty( $font_families ) ) {
			$query_args = array(
				'family' => urlencode( implode( '|', $font_families ) ),
				'subset' => urlencode( 'latin,latin-ext' ),
			);

			$fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
		}

		return esc_url_raw( $fonts_url );
	}
endif;

/**
 * Get nav menu
 *
 * @since  1.0.0
 *
 *
 * @return string
 */
if ( ! function_exists( 'factora_nav_menu' ) ) :
	function factora_nav_menu() {

		?>
        <div class="primary-nav nav">
			<?php
			if ( has_nav_menu( 'primary' ) ) {
				wp_nav_menu(
					array(
						'theme_location' => 'primary',
						'container'      => false,
					) );
			}
			?>
        </div>
		<?php
	}
endif;

/**
 * Get header sidebar
 *
 * @since  1.0.0
 *
 *
 * @return string
 */
if ( ! function_exists( 'factora_header_sidebar' ) ) :
	function factora_header_sidebar() {
		if ( ! is_active_sidebar( 'header-sidebar' ) ) {
			return;
		}
		?>
        <div class="header-sidebar">
			<?php dynamic_sidebar( 'header-sidebar' ); ?>
        </div>
		<?php
	}
endif;

/**
 * Get header menu
 *
 * @since  1.0.0
 *
 *
 * @return string
 */
if ( ! function_exists( 'factora_extra_menu' ) ) :
	function factora_extra_menu() {
		$header_layout = factora_get_option( 'header_layout' );
		$menu_extras   = factora_get_option( 'menu_extras' );

		if ( $header_layout == '2' ) {
			$menu_extras = factora_get_option( 'menu_extras_2' );
		} elseif ( $header_layout == '3' ) {
			$menu_extras = factora_get_option( 'menu_extras_3' );
		} elseif ( $header_layout == '4' ) {
			$menu_extras = factora_get_option( 'menu_extras_4' );
		}

		if ( empty( $menu_extras ) ) {
			return;
		}

		echo '<div class="menu-extras">';

		foreach ( $menu_extras as $item ) {
			if ( $item == 'hotline' ) {
				$item = '';
			}
			get_template_part( 'template-parts/headers/' . $item );
		}

		echo '</div>';

	}
endif;

/**
 * Get header menu
 *
 * @since  1.0.0
 *
 *
 * @return string
 */
if ( ! function_exists( 'factora_get_hotline' ) ) :
	function factora_get_hotline() {
		$menu_extras = factora_get_option( 'menu_extras_3' );
		if ( empty( $menu_extras ) ) {
			return;
		}
		foreach ( $menu_extras as $item ) {
			if ( $item == 'search' ) {
				$item = '';
			}
			get_template_part( 'template-parts/headers/' . $item );
		}

	}
endif;

/**
 * Get header container
 *
 * @since  1.0.0
 *
 *
 * @return string
 */
if ( ! function_exists( 'factora_header_container' ) ) :
	function factora_header_container() {
		if ( factora_get_option( 'header_layout' ) == '3' ) {
			return 'factora-container';
		}

		return 'container';

	}
endif;