<?php
/**
 * Custom layout functions
 *
 * @package Factora
 */


/**
 * Get classes for content area
 *
 * @since  1.0
 *
 * @return string of classes
 */

if ( ! function_exists( 'factora_content_container_class' ) ) :
	function factora_content_container_class() {
		if ( ! is_singular() && factora_is_portfolio() && factora_portfolio_layout() == 'full-width' ) {
			$container = 'col-xs-12';
		} else {
			$container = 'container';
		}

		if ( is_page_template( 'template-homepage-5.php' ) ) {
			return 'container-fluid';
		}

		return $container;
	}
endif;


if ( ! function_exists( 'factora_get_layout' ) ) :
	function factora_get_layout() {
		$layout = factora_get_option( 'blog_layout' );

		if ( is_page() ) {
			$layout = 'full-content';
		} elseif ( is_404() ) {
			$layout = 'full-content';
		} elseif ( is_page_template( array( 'template-fullwidth.php', 'template-homepage.php', 'template-homepage-5.php' ) ) ) {
			$layout = 'full-content';
		} elseif ( factora_is_blog() && factora_get_option( 'blog_view' ) == 'grid' ) {
			$layout = 'full-content';
		} elseif ( factora_is_catalog() ) {
			$layout = factora_get_option( 'catalog_layout' );
		} elseif ( is_singular( 'product' ) ) {
			$layout = factora_get_option( 'product_page_sidebar' );
		} elseif ( is_singular( 'service' ) ) {
			$layout = factora_get_option( 'single_service_layout' );
			if ( get_post_meta( get_the_ID(), 'custom_layout', true ) ) {
				$layout = get_post_meta( get_the_ID(), 'layout', true );
			}
		} elseif ( ! is_active_sidebar( 'blog-sidebar' ) ) {
			$layout = 'full-content';
		}

		return apply_filters( 'factora_site_layout', $layout );
	}

endif;

/**
 * Get Bootstrap column classes for content area
 *
 * @since  1.0
 *
 * @return array Array of classes
 */

if ( ! function_exists( 'factora_get_content_columns' ) ) :
	function factora_get_content_columns( $layout = null ) {
		$layout  = $layout ? $layout : factora_get_layout();
		$classes = array( 'col-md-9', 'col-sm-12', 'col-xs-12' );

		if ( is_singular( 'service' ) ) {
			$classes = array( 'col-md-8', 'col-sm-12', 'col-xs-12' );
		}

		if ( $layout == 'full-content' ) {
			$classes = array( 'col-md-12', 'col-sm-12', 'col-xs-12' );
		}

		return $classes;
	}

endif;

/**
 * Echos Bootstrap column classes for content area
 *
 * @since 1.0
 */

if ( ! function_exists( 'factora_content_columns' ) ) :
	function factora_content_columns( $layout = null ) {
		echo implode( ' ', factora_get_content_columns( $layout ) );
	}
endif;
