<?php
/**
 * Custom functions that act on page header templates
 *
 * @package factora
 */

/**
 * Get page header layout
 *
 * @return array
 */

if ( ! function_exists( 'factora_get_page_header' ) ) :
	function factora_get_page_header() {
		if ( is_404() || is_page_template( 'template-homepage.php' ) || is_page_template( 'template-homepage-5.php' ) || is_page_template( 'template-coming-soon-page.php' ) ) {
			return false;
		}
		$page_header = array();
		if ( factora_is_blog() ) {
			if ( ! intval( factora_get_option( 'page_header_blog' ) ) ) {
				return false;
			}
			$page_header = factora_get_option( 'page_header_blog_els' );

			if( intval( factora_get_option( 'page_header_blog_parallax' ) ) ) {
				array_push( $page_header, 'parallax' );
			}

			if( intval( factora_get_option( 'page_header_blog_align' ) ) ) {
				array_push( $page_header, 'align' );
			}

		} elseif ( is_singular( 'post' ) ) {
			if ( ! intval( factora_get_option( 'page_header_post' ) ) ) {
				return false;
			}
			$page_header = factora_get_option( 'page_header_post_els' );

			if( intval( factora_get_option( 'page_header_post_parallax' ) ) ) {
				array_push( $page_header, 'parallax' );
			}

			if( intval( factora_get_option( 'page_header_post_align' ) ) ) {
				array_push( $page_header, 'align' );
			}

		} elseif ( is_page() ) {
			if ( ! intval( factora_get_option( 'page_header_page' ) ) ) {
				return false;
			}

			$page_header = factora_get_option( 'page_header_page_els' );

			if( intval( factora_get_option( 'page_header_page_parallax' ) ) ) {
				array_push( $page_header, 'parallax' );
			}

			if( intval( factora_get_option( 'page_header_page_align' ) ) ) {
				array_push( $page_header, 'align' );
			}

		} elseif ( factora_is_service() ) {
			if ( ! intval( factora_get_option( 'page_header_service' ) ) ) {
				return false;
			}
			$page_header = factora_get_option( 'page_header_service_els' );

			if( intval( factora_get_option( 'page_header_service_parallax' ) ) ) {
				array_push( $page_header, 'parallax' );
			}

			if( intval( factora_get_option( 'page_header_service_align' ) ) ) {
				array_push( $page_header, 'align' );
			}

		} elseif ( is_singular( 'service' ) ) {
			if ( ! intval( factora_get_option( 'page_header_service_single' ) ) ) {
				return false;
			}
			$page_header = factora_get_option( 'page_header_service_single_els' );

			if( intval( factora_get_option( 'page_header_service_single_parallax' ) ) ) {
				array_push( $page_header, 'parallax' );
			}

			if( intval( factora_get_option( 'page_header_service_single_align' ) ) ) {
				array_push( $page_header, 'align' );
			}

		}elseif ( factora_is_portfolio() ) {

			if ( ! intval( factora_get_option( 'page_header_portfolio' ) ) ) {
				return false;
			}
			$page_header = factora_get_option( 'page_header_portfolio_els' );

			if( intval( factora_get_option( 'page_header_portfolio_parallax' ) ) ) {
				array_push( $page_header, 'parallax' );
			}

			if( intval( factora_get_option( 'page_header_portfolio_align' ) ) ) {
				array_push( $page_header, 'align' );
			}

		} elseif ( is_singular( 'portfolio' ) ) {
			if ( ! intval( factora_get_option( 'page_header_portfolio_single' ) ) ) {
				return false;
			}
			$page_header = factora_get_option( 'page_header_portfolio_single_els' );

			if( intval( factora_get_option( 'page_header_portfolio_single_parallax' ) ) ) {
				array_push( $page_header, 'parallax' );
			}

			if( intval( factora_get_option( 'page_header_portfolio_single_align' ) ) ) {
				array_push( $page_header, 'align' );
			}

		} else {
			if ( ! intval( factora_get_option( 'page_header' ) ) ) {
				return false;
			}
			$page_header = factora_get_option( 'page_header_els' );


			if( intval( factora_get_option( 'page_header_parallax' ) ) ) {
				array_push( $page_header, 'parallax' );
			}


			if( intval( factora_get_option( 'page_header_align' ) ) ) {
				array_push( $page_header, 'align' );
			}
		}

		$page_header = factora_custom_page_header( $page_header );

		return $page_header;


	}

endif;


/**
 * Get custom page header layout
 *
 * @return array
 */
if ( ! function_exists( 'factora_custom_page_header' ) ) :
	function factora_custom_page_header( $page_header ) {

		if ( ! is_singular( 'page' ) && ! is_singular( 'post' ) && ! is_singular( 'product' ) && ! ( function_exists( 'is_shop' ) && is_shop() ) ) {
			return $page_header;
		}
		$post_id = get_the_ID();
		if ( function_exists( 'is_shop' ) && is_shop() ) {
			$post_id = intval(get_option( 'woocommerce_shop_page_id' ));
		}

		if ( empty( $page_header ) ) {
			return false;
		}

		$hide_page_header = get_post_meta( $post_id, 'hide_page_header', true );
		if ( $hide_page_header ) {
			return false;
		}
		if ( get_post_meta( $post_id, 'hide_breadcrumb', true ) ) {

			$key = array_search( 'breadcrumb', $page_header );
			if ( $key !== false ) {
				unset( $page_header[ $key ] );
			}
		}

		if ( get_post_meta( $post_id, 'hide_title', true ) ) {

			$key = array_search( 'title', $page_header );
			if ( $key !== false ) {
				unset( $page_header[ $key ] );
			}
		}

		if ( get_post_meta( $post_id, 'hide_parallax', true ) ) {
			$key = array_search( 'parallax', $page_header );
			if ( $key !== false ) {
				unset( $page_header[ $key ] );
			}
		}

		if ( get_post_meta( $post_id, 'text_center', true ) ) {
			$key = array_search( 'align', $page_header );
			if ( $key == false ) {
				array_push( $page_header, 'align' );
			}
		}

		return $page_header;
	}
endif;