<?php
/**
 * Template Product hooks.
 *
 * @package Factora
 */

/**
 * Class of general template.
 */
class Factora_WooCommerce_Template_Catalog {
	/**
	 * Initialize.
	 */
	public static function init() {
		// Need an early hook to ajaxify update mini shop cart
		add_filter( 'woocommerce_add_to_cart_fragments', array( __CLASS__, 'add_to_cart_fragments' ) );

		// Remove shop page title
		add_filter( 'woocommerce_show_page_title', '__return_false' );

		// remove add to cart link
		remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart' );

		// Wrap product loop content
		add_action( 'woocommerce_before_shop_loop_item', array( __CLASS__, 'open_product_inner' ), 1 );
		add_action( 'woocommerce_after_shop_loop_item', array( __CLASS__, 'close_product_inner' ), 100 );

		add_action( 'woocommerce_shop_loop_item_title', array( __CLASS__, 'open_product_details' ), 5 );
		add_action( 'woocommerce_after_shop_loop_item', array( __CLASS__, 'close_product_details' ), 100 );

		// Add div before shop loop
		add_action( 'woocommerce_before_shop_loop', array( __CLASS__, 'before_shop_loop' ), 40 );

		// Add div after shop loop
		add_action( 'woocommerce_after_shop_loop', array( __CLASS__, 'after_shop_loop' ), 20 );

		// Remove product link
		remove_action( 'woocommerce_before_shop_loop_item', 'woocommerce_template_loop_product_link_open', 10 );
		remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_product_link_close', 5 );

		// Add product thumbnail inner
		add_action( 'woocommerce_before_shop_loop_item', array( __CLASS__, 'open_product_thumbnail' ), 10 );
		add_action( 'woocommerce_before_shop_loop_item_title', array( __CLASS__, 'close_product_thumbnail' ), 100 );

		// Add product link
		add_action( 'woocommerce_before_shop_loop_item', array( __CLASS__, 'product_link_open' ), 10 );
		add_action( 'woocommerce_before_shop_loop_item_title', array( __CLASS__, 'product_link_close' ), 20 );

		// Add product action button
		add_action( 'woocommerce_before_shop_loop_item_title', array( __CLASS__, 'product_action_button' ), 20 );

		// Add product title link
		remove_action( 'woocommerce_shop_loop_item_title', 'woocommerce_template_loop_product_title', 10 );
		add_action( 'woocommerce_shop_loop_item_title', array( __CLASS__, 'template_loop_product_title' ), 10 );

		// Remove catalog ordering
		remove_action( 'woocommerce_before_shop_loop', 'woocommerce_catalog_ordering', 30 );

		// Remove shop result count
		remove_action( 'woocommerce_before_shop_loop', 'woocommerce_result_count', 20 );

		// Add shop toolbar
		add_action( 'woocommerce_before_shop_loop', array( __CLASS__, 'get_shop_toolbar' ), 20 );

		// Change label orderby option default
		add_filter( 'woocommerce_catalog_orderby', array( __CLASS__, 'factora_catalog_get_orderby_options' ) );
		add_filter( 'woocommerce_default_catalog_orderby', array( __CLASS__, 'factora_catalog_get_orderby_default' ) );

		// Add loading icon ajax
		add_action( 'woocommerce_before_shop_loop', array( __CLASS__, 'shop_loading' ), 60 );

		// Pagination
		add_filter( 'woocommerce_pagination_args', array( __CLASS__, 'pagination_args' ) );

	}


	/**
	 * Need an early hook to ajaxify update mini shop cart
	 *
	 * @since 1.0
	 */
	public static function add_to_cart_fragments( $fragments ) {
		ob_start();
		?>
        <a class="cart-contents" href="<?php echo esc_url( wc_get_cart_url() ); ?>">
            <i class="icon-bag2 extra-icon"></i>
            <span class="mini-item-counter"><?php echo WC()->cart->get_cart_contents_count(); ?></span>
        </a>

		<?php
		$fragments['a.cart-contents'] = ob_get_clean();

		return $fragments;
	}

	/**
	 * Before Shop
	 *
	 * @since  1.0.0
	 * @return string
	 */
	public static function before_shop_loop() {
		if ( ! factora_is_catalog() ) {
			return;
		}
		echo '<div id="factora-shop-content" class="factora-shop-content">';
	}

	/**
	 * After Shop
	 *
	 * @since  1.0.0
	 * @return string
	 */
	public static function after_shop_loop() {
		if ( ! factora_is_catalog() ) {
			return;
		}
		echo '</div>';
	}

	/**
	 * Wrap product content
	 * Open a div
	 *
	 * @since 1.0
	 */
	public static function open_product_inner() {
		echo '<div class="product-inner  clearfix">';
	}

	/**
	 * Wrap product content
	 * Close a div
	 *
	 * @since 1.0
	 */
	public static function close_product_inner() {
		echo '</div>';
	}

	/**
	 * Open product detail
	 *
	 * @since  1.0
	 *
	 *
	 * @return string
	 */
	public static function open_product_details() {
		echo '<div class="product-details">';
	}

	/**
	 * Close product detail
	 *
	 * @since  1.0
	 *
	 *
	 * @return string
	 */
	public static function close_product_details() {
		echo '</div>';
	}

	public static function open_product_thumbnail() {
		echo '<div class="product-thumbnail factora-product-thumbnail">';
	}

	public static function close_product_thumbnail() {
		echo '</div>';
	}

	public static function product_link_open() {
		echo '<a href="' . esc_url( get_the_permalink() ) . '" class="woocommerce-LoopProduct-link woocommerce-loop-product__link">';
	}

	public static function product_link_close() {
		echo '</a>';
	}

	public static function product_action_button() {
		if ( function_exists( 'woocommerce_template_loop_add_to_cart' ) ) {
			woocommerce_template_loop_add_to_cart();
		}
	}

	/**
	 * Show the product title in the product loop. By default this is an H2.
	 */
	public static function template_loop_product_title() {
		echo '<h2 class="woocommerce-loop-product__title"><a href="' . get_the_permalink() . '">' . get_the_title() . '</a></h2>';
	}

	/**
	 * Get shop toolbar
	 *
	 */
	public static function get_shop_toolbar() {
		if ( ! factora_is_catalog() ) {
			return;
		}

		?>
        <div id="factora-shop-toolbar" class="shop-toolbar">
            <div class="row-flex">
                <div class="shop-toolbar__element shop-toolbar__result col-flex-sm-6">
					<?php woocommerce_result_count(); ?>
                </div>
                <div class="shop-toolbar__element shop-toolbar__ordering col-flex-sm-6">
					<?php woocommerce_catalog_ordering(); ?>
                </div>
            </div>
        </div>
		<?php
	}

	public static function factora_catalog_get_orderby_options( $catalog_orderby_options = '' ) {
		$catalog_orderby_options['menu_order'] = esc_html__( 'Default sorting', 'factora' );
		$catalog_orderby_options['popularity'] = esc_html__( 'Popularity', 'factora' );
		$catalog_orderby_options['rating']     = esc_html__( 'Average rating', 'factora' );
		$catalog_orderby_options['date']       = esc_html__( 'Newness', 'factora' );
		$catalog_orderby_options['price']      = esc_html__( 'Price: low to high', 'factora' );
		$catalog_orderby_options['price-desc'] = esc_html__( 'Price: high to low', 'factora' );

		return $catalog_orderby_options;
	}

	public static function factora_catalog_get_orderby_default( $orderby ) {
		$orderby = empty( $orderby ) ? 'menu_order' : $orderby;

		return $orderby;
	}

	/**
	 * Shop loading
	 *
	 * @since  1.0.0
	 * @return string
	 */
	public static function shop_loading() {
		if ( ! factora_is_catalog() ) {
			return;
		}
		echo '<div class="factora-catalog-loading">
				<span class="factora-loader"></span>
			</div>';
	}

	public static function pagination_args( $args ) {
		$args['prev_text'] = '<i class="arrow_carrot-left"></i>';
		$args['next_text'] = '<i class="arrow_carrot-right"></i>';
		return $args;
	}


}