<?php
/**
 * Template Product hooks.
 *
 * @package Factora
 */

/**
 * Class of general template.
 */
class Factora_WooCommerce_Template_Product {
	/**
	 * Initialize.
	 */

	public static function init() {
		add_action( 'woocommerce_before_single_product_summary', array( __CLASS__, 'wrapper_before_summary' ), 5 );
		add_action( 'woocommerce_after_single_product_summary', array( __CLASS__, 'wrapper_after_summary' ), 5 );

		add_filter( 'woocommerce_get_availability_text', array( __CLASS__, 'get_product_availability_text' ), 20, 2 );

		add_filter( 'woocommerce_product_description_heading', '__return_false' );

		add_filter( 'woocommerce_product_additional_information_heading', '__return_false' );

		if ( ! intval( factora_get_option( 'related_products' ) ) ) {
			remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20 );
		}
		add_filter( 'woocommerce_output_related_products_args', array( __CLASS__, 'get_related_products_args' ) );

		if ( ! intval( factora_get_option( 'upsells_products' ) ) ) {
			remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_upsell_display', 15 );
		}
		add_filter( 'woocommerce_upsell_display_args', array( __CLASS__, 'get_upsell_products_args' ) );

		// Change variable text
		add_filter(
			'woocommerce_dropdown_variation_attribute_options_args', array(
				__CLASS__,
				'variation_attribute_options'
			)
		);

		// Single Product Button
		add_action( 'woocommerce_before_add_to_cart_button', array( __CLASS__, 'open_button_group' ), 10 );
		add_action( 'woocommerce_after_add_to_cart_button', array( __CLASS__, 'close_button_group' ), 100 );

		add_filter( 'woocommerce_get_image_size_gallery_thumbnail', array( __CLASS__, 'gallery_thumb_size' ) );

		// Remove default tab title
		add_filter( 'woocommerce_product_reviews_tab_title', array( __CLASS__, 'factora_product_review_tab_title' ) );

	}

	/**
	 * Before Summary
	 *
	 * @return void
	 */
	public static function wrapper_before_summary() {
		?>
        <div class="factora-product-detail clearfix">
		<?php

	}

	/**
	 * After Summary
	 *
	 * @return void
	 */
	public static function wrapper_after_summary() {
		?>
        </div>
		<?php

	}

	/**
	 * Product availability text
	 *
	 * @return string
	 */
	public static function get_product_availability_text( $availability, $product ) {
		if ( ! $product->get_type() == 'simple' ) {
			return $availability;
		}

		if ( ! $product->managing_stock() && $product->is_in_stock() ) {
			$availability = esc_html__( 'In stock', 'factora' );
		}

		return $availability;
	}

	/**
	 * Related products args
	 *
	 * @return array
	 */
	public static function get_related_products_args( $args ) {
		$args['posts_per_page'] = intval( factora_get_option( 'related_products_numbers' ) );

		return $args;
	}

	/**
	 * Upsells products args
	 *
	 * @return array
	 */
	public static function get_upsell_products_args( $args ) {
		$args['posts_per_page'] = intval( factora_get_option( 'upsells_products_numbers' ) );

		return $args;
	}


	/**
	 * Change variation text
	 *
	 * @since 1.0
	 */
	public static function variation_attribute_options( $args ) {
		$attribute = $args['attribute'];
		if ( function_exists( 'wc_attribute_label' ) && $attribute ) {
			$args['show_option_none'] = esc_html__( 'Select', 'factora' ) . ' ' . wc_attribute_label( $attribute );
		}

		return $args;
	}

	/**
	 * Wrap button group
	 * Open a div
	 *
	 * @since 1.0
	 */
	public static function open_button_group() {
		echo '<div class="single-button-wrapper">';
	}

	/**
	 * Wrap button group
	 * Close a div
	 *
	 * @since 1.0
	 */
	public static function close_button_group() {
		echo '</div>';
	}

	public static function gallery_thumb_size() {
		$size = array(
			'width'  => 130,
			'height' => 150
		);

		return $size;
	}

	/**
	 * Add product tabs to product pages.
	 *
	 * @return string
	 */
	public static function factora_product_review_tab_title() {
		global $product;

		$title = sprintf( '%s <span class="count">(%s)</span>', esc_html__( 'Reviews', 'factora' ), $product->get_review_count() );

		return $title;
	}

}
