<?php
/**
 * Theme options of WooCommerce.
 *
 * @package Factora
 */

/**
 * Adds theme options sections of WooCommerce.
 *
 * @param array $sections Theme options sections.
 *
 * @return array
 */
function factora_woocommerce_customize_sections( $sections ) {
	$sections = array_merge(
		$sections, array(
			'single_product'      => array(
				'title'    => esc_html__( 'Single Product', 'factora' ),
				'priority' => 60,
				'panel'    => 'woocommerce',
			),
			'upsells_product'     => array(
				'title'    => esc_html__( 'Upsells Products', 'factora' ),
				'priority' => 60,
				'panel'    => 'woocommerce',
			),
			'related_product'     => array(
				'title'    => esc_html__( 'Related Products', 'factora' ),
				'priority' => 60,
				'panel'    => 'woocommerce',
			),
			'cross_sells_product' => array(
				'title'    => esc_html__( 'Cross-sells Products', 'factora' ),
				'priority' => 60,
				'panel'    => 'woocommerce',
			),
		)
	);

	return $sections;
}

add_filter( 'factora_customize_sections', 'factora_woocommerce_customize_sections' );

/**
 * Adds theme options of WooCommerce.
 *
 * @param array $settings Theme options.
 *
 * @return array
 */
function factora_woocommerce_customize_fields( $fields ) {


	// Product page.
	$fields = array_merge(
		$fields, array(
			//Shop
			'catalog_layout'               => array(
				'type'        => 'select',
				'label'       => esc_html__( 'Catalog Layout', 'factora' ),
				'default'     => 'full-content',
				'section'     => 'woocommerce_product_catalog',
				'priority'    => 9,
				'description' => esc_html__( 'Select layout for catalog.', 'factora' ),
				'choices'     => array(
					'sidebar-content' => esc_html__( 'Left Sidebar', 'factora' ),
					'content-sidebar' => esc_html__( 'Right Sidebar', 'factora' ),
					'full-content'    => esc_html__( 'Full Content', 'factora' ),
				),
			),

			//Badge
			'catalog_badges'               => array(
				'type'        => 'toggle',
				'label'       => esc_html__( 'Catalog Badges', 'factora' ),
				'section'     => 'shop_badge',
				'default'     => 1,
				'priority'    => 20,
				'description' => esc_html__( 'Check this to show badges in the catalog page.', 'factora' ),
			),
			'badges'                       => array(
				'type'        => 'multicheck',
				'label'       => esc_html__( 'Badges', 'factora' ),
				'section'     => 'shop_badge',
				'default'     => array( 'hot', 'new', 'sale', 'outofstock' ),
				'priority'    => 20,
				'choices'     => array(
					'hot'        => esc_html__( 'Hot', 'factora' ),
					'new'        => esc_html__( 'New', 'factora' ),
					'sale'       => esc_html__( 'Sale', 'factora' ),
					'outofstock' => esc_html__( 'Out Of Stock', 'factora' ),
				),
				'description' => esc_html__( 'Select which badges you want to show', 'factora' ),
			),
			'hot_text'                     => array(
				'type'            => 'text',
				'label'           => esc_html__( 'Custom Hot Text', 'factora' ),
				'section'         => 'shop_badge',
				'default'         => 'Hot',
				'priority'        => 20,
				'active_callback' => array(
					array(
						'setting'  => 'badges',
						'operator' => 'contains',
						'value'    => 'hot',
					),
				),
			),
			'hot_color'                    => array(
				'type'            => 'color',
				'label'           => esc_html__( 'Custom Hot Color', 'factora' ),
				'default'         => '',
				'section'         => 'shop_badge',
				'priority'        => 20,
				'choices'         => array(
					'alpha' => true,
				),
				'active_callback' => array(
					array(
						'setting'  => 'badges',
						'operator' => 'contains',
						'value'    => 'hot',
					),
				),
			),
			'hot_color_custom'             => array(
				'type'     => 'custom',
				'section'  => 'shop_badge',
				'default'  => '<hr>',
				'priority' => 20,
			),
			'outofstock_text'              => array(
				'type'            => 'text',
				'label'           => esc_html__( 'Custom Out Of Stock Text', 'factora' ),
				'section'         => 'shop_badge',
				'default'         => 'Out Of Stock',
				'priority'        => 20,
				'active_callback' => array(
					array(
						'setting'  => 'badges',
						'operator' => 'contains',
						'value'    => 'outofstock',
					),
				),
			),
			'outofstock_color'             => array(
				'type'            => 'color',
				'label'           => esc_html__( 'Custom Out Of Stock Color', 'factora' ),
				'default'         => '',
				'section'         => 'shop_badge',
				'priority'        => 20,
				'choices'         => array(
					'alpha' => true,
				),
				'active_callback' => array(
					array(
						'setting'  => 'badges',
						'operator' => 'contains',
						'value'    => 'outofstock',
					),
				),
			),
			'outofstock_color_custom'      => array(
				'type'     => 'custom',
				'section'  => 'shop_badge',
				'default'  => '<hr>',
				'priority' => 20,
			),
			'new_text'                     => array(
				'type'            => 'text',
				'label'           => esc_html__( 'Custom New Text', 'factora' ),
				'section'         => 'shop_badge',
				'default'         => 'New',
				'priority'        => 20,
				'active_callback' => array(
					array(
						'setting'  => 'badges',
						'operator' => 'contains',
						'value'    => 'new',
					),
				),
			),
			'new_color'                    => array(
				'type'            => 'color',
				'label'           => esc_html__( 'Custom New Color', 'factora' ),
				'default'         => '',
				'section'         => 'shop_badge',
				'priority'        => 20,
				'choices'         => array(
					'alpha' => true,
				),
				'active_callback' => array(
					array(
						'setting'  => 'badges',
						'operator' => 'contains',
						'value'    => 'new',
					),
				),
			),
			'new_color_custom'             => array(
				'type'     => 'custom',
				'section'  => 'shop_badge',
				'default'  => '<hr>',
				'priority' => 20,
			),
			'sale_color'                   => array(
				'type'            => 'color',
				'label'           => esc_html__( 'Custom Sale Color', 'factora' ),
				'default'         => '',
				'section'         => 'shop_badge',
				'priority'        => 20,
				'choices'         => array(
					'alpha' => true,
				),
				'active_callback' => array(
					array(
						'setting'  => 'badges',
						'operator' => 'contains',
						'value'    => 'sale',
					),
				),
			),
			'sale_color_custom'            => array(
				'type'     => 'custom',
				'section'  => 'shop_badge',
				'default'  => '<hr>',
				'priority' => 20,
			),
			'product_newness'              => array(
				'type'            => 'number',
				'label'           => esc_html__( 'Product Newness', 'factora' ),
				'section'         => 'shop_badge',
				'default'         => 3,
				'priority'        => 20,
				'description'     => esc_html__( 'Display the "New" badge for how many days?', 'factora' ),
				'active_callback' => array(
					array(
						'setting'  => 'badges',
						'operator' => 'contains',
						'value'    => 'new',
					),
				),
			),

			//Product
			'product_page_sidebar'         => array(
				'type'        => 'select',
				'label'       => esc_html__( 'Product Layout', 'factora' ),
				'section'     => 'single_product',
				'default'     => 'full-content',
				'priority'    => 10,
				'choices'     => array(
					'full-content'    => esc_html__( 'Full Content', 'factora' ),
					'sidebar-content' => esc_html__( 'Left Sidebar', 'factora' ),
					'content-sidebar' => esc_html__( 'Right Sidebar', 'factora' ),
				),
				'description' => esc_html__( 'Select default sidebar for product page.', 'factora' ),

			),

			// Upsells Products
			'upsells_products'             => array(
				'type'        => 'toggle',
				'label'       => esc_html__( 'Upsells Products', 'factora' ),
				'section'     => 'upsells_product',
				'default'     => 1,
				'priority'    => 40,
				'description' => esc_html__( 'Check this option to show upsells products in single product page', 'factora' ),
			),
			'upsells_products_title'       => array(
				'type'     => 'text',
				'label'    => esc_html__( 'Upsells Products Title', 'factora' ),
				'section'  => 'upsells_product',
				'default'  => esc_html__( 'You may also like', 'factora' ),
				'priority' => 40,
			),
			'upsells_products_columns'     => array(
				'type'        => 'select',
				'label'       => esc_html__( 'Upsells Products Columns', 'factora' ),
				'section'     => 'upsells_product',
				'default'     => '4',
				'priority'    => 40,
				'description' => esc_html__( 'Specify how many columns of upsells products you want to show on single product page', 'factora' ),
				'choices'     => array(
					'3' => esc_html__( '3 Columns', 'factora' ),
					'4' => esc_html__( '4 Columns', 'factora' ),
					'5' => esc_html__( '5 Columns', 'factora' ),
					'6' => esc_html__( '6 Columns', 'factora' ),
				),
			),
			'upsells_products_numbers'     => array(
				'type'        => 'number',
				'label'       => esc_html__( 'Upsells Products Numbers', 'factora' ),
				'section'     => 'upsells_product',
				'default'     => 6,
				'priority'    => 40,
				'description' => esc_html__( 'Specify how many numbers of upsells products you want to show on single product page', 'factora' ),
			),
			// Related Products
			'related_products'             => array(
				'type'        => 'toggle',
				'label'       => esc_html__( 'Related Products', 'factora' ),
				'section'     => 'related_product',
				'default'     => 0,
				'priority'    => 40,
				'description' => esc_html__( 'Check this option to show related products in single product page', 'factora' ),
			),
			'related_products_title'       => array(
				'type'     => 'text',
				'label'    => esc_html__( 'Related Products Title', 'factora' ),
				'section'  => 'related_product',
				'default'  => esc_html__( 'Related products', 'factora' ),
				'priority' => 40,
			),
			'related_products_columns'     => array(
				'type'        => 'select',
				'label'       => esc_html__( 'Related Products Columns', 'factora' ),
				'section'     => 'related_product',
				'default'     => '4',
				'priority'    => 40,
				'description' => esc_html__( 'Specify how many columns of related products you want to show on single product page', 'factora' ),
				'choices'     => array(
					'3' => esc_html__( '3 Columns', 'factora' ),
					'4' => esc_html__( '4 Columns', 'factora' ),
					'5' => esc_html__( '5 Columns', 'factora' ),
					'6' => esc_html__( '6 Columns', 'factora' ),
				),
			),
			'related_products_numbers'     => array(
				'type'        => 'number',
				'label'       => esc_html__( 'Related Products Numbers', 'factora' ),
				'section'     => 'related_product',
				'default'     => 6,
				'priority'    => 40,
				'description' => esc_html__( 'Specify how many numbers of related products you want to show on single product page', 'factora' ),
			),
			// Cross Sells Products
			'cross_sells_products'         => array(
				'type'        => 'toggle',
				'label'       => esc_html__( 'Cross Sells Products', 'factora' ),
				'section'     => 'cross_sells_product',
				'default'     => 1,
				'priority'    => 40,
				'description' => esc_html__( 'Check this option to show cross-sells products in the cart page', 'factora' ),
			),
			'cross_sells_products_title'   => array(
				'type'     => 'text',
				'label'    => esc_html__( 'Cross Sells Products Title', 'factora' ),
				'section'  => 'cross_sells_product',
				'default'  => esc_html__( 'You may be interested in...', 'factora' ),
				'priority' => 40,
			),
			'cross_sells_products_columns' => array(
				'type'        => 'select',
				'label'       => esc_html__( 'Cross Sells Products Columns', 'factora' ),
				'section'     => 'cross_sells_product',
				'default'     => '4',
				'priority'    => 40,
				'description' => esc_html__( 'Specify how many columns of upsells products you want to show on the cart page', 'factora' ),
				'choices'     => array(
					'3' => esc_html__( '3 Columns', 'factora' ),
					'4' => esc_html__( '4 Columns', 'factora' ),
					'5' => esc_html__( '5 Columns', 'factora' ),
					'6' => esc_html__( '6 Columns', 'factora' ),
				),
			),
			'cross_sells_products_numbers' => array(
				'type'        => 'number',
				'label'       => esc_html__( 'Cross Sells Products Numbers', 'factora' ),
				'section'     => 'cross_sells_product',
				'default'     => 6,
				'priority'    => 40,
				'description' => esc_html__( 'Specify how many numbers of upsells products you want to show on the cart page', 'factora' ),
			),
		)
	);

	return $fields;
}

add_filter( 'factora_customize_fields', 'factora_woocommerce_customize_fields' );