<?php

class Factora_Service_Widget extends WP_Widget {
	/**
	 * Holds widget settings defaults, populated in constructor.
	 *
	 * @var array
	 */
	protected $default;

	/**
	 * List of supported socials
	 *
	 * @var array
	 */
	protected $socials;

	/**
	 * Constructor
	 */
	function __construct() {
		$this->default = array(
			'title'    => '',
			'order'    => '',
			'order_by' => '',
			'number'   => '',
			'type'     => '',
		);

		parent::__construct( 'factora-service-widget',
			esc_html__( 'Factora - Service Sidebar', 'factora' ),
			array(
				'classname'   => 'factora-service-widget',
				'description' => esc_html__( 'Setup Service Sidebar.', 'factora' ),
			)
		);
	}

	/**
	 * Outputs the HTML for this widget.
	 *
	 * @param array $args An array of standard parameters for widgets in this theme
	 * @param array $instance An array of settings for this widget instance
	 *
	 * @return void Echoes it's output
	 */
	function widget( $args, $instance ) {
		$number  = isset( $instance['number'] ) ? $instance['number'] : '';
		$order   = isset( $instance['order'] ) ? $instance['order'] : '';
		$orderby = isset( $instance['order_by'] ) ? $instance['order_by'] : '';
		$type    = isset( $instance['type'] ) ? $instance['type'] : '';

		echo wp_kses_post( $args['before_widget'] );

		$type = apply_filters('factora_service_widget_type',$type);

		echo '<ul class="list-services service-' . esc_attr( $type ) . '">';
		$output = array();

		$query_args = array(
			'posts_per_page'      => $number,
			'post_type'           => 'service',
			'ignore_sticky_posts' => true,
			'orderby'             => $orderby,
			'order'               => $order,
		);

		$query = new WP_Query( $query_args );
		global $wp_query;
		$current_id = $wp_query->get_queried_object_id();


		while ( $query->have_posts() ) : $query->the_post();

			$the_title = get_the_title();

			$permalink = get_permalink();

			$icon = get_post_meta( get_the_ID(), 'icon', true );

			if ( $current_id == get_the_ID() ) {
				$class = 'active';
			} else {
				$class = '';
			}

			if ( $type == 'icon' ) {
				$output[] = sprintf( '<li class="service-item %s"><a class="item" href="%s"><span class="factora-icon"><svg viewBox="0 0 20 20"><use xlink:href="#%s"></use></svg></span>%s</a></li>', $class, $permalink, $icon, $the_title );
			} else {
				$output[] = sprintf( '<li class="service-item %s"><a class="item" href="%s">%s<i class="elegant-icon arrow_carrot-right"></i></a></li>', $class, $permalink, $the_title );
			}

		endwhile;
		echo implode( '', $output );
		echo '</ul>';

		echo wp_kses_post( $args['after_widget'] );
	}

	/**
	 * Displays the form for this widget on the Widgets page of the WP Admin area.
	 *
	 * @param array $instance
	 *
	 * @return string|void
	 */
	function form( $instance ) {
		global $wp_customize;
		$order   = isset( $instance['order'] ) ? $instance['order'] : '';
		$orderby = isset( $instance['order_by'] ) ? $instance['order_by'] : '';
		$type    = isset( $instance['type'] ) ? $instance['type'] : '';

		$instance = wp_parse_args( $instance, $this->default );
		?>

        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title', 'factora' ); ?></label>
            <input type="text" class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"
                   name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>"
                   value="<?php echo esc_attr( $instance['title'] ); ?>"/>
        </p>

        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'order' ) ); ?>"><?php esc_html_e( 'Order', 'factora' ); ?></label>
            <select class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'order' ) ); ?>"
                    name="<?php echo esc_attr( $this->get_field_name( 'order' ) ); ?>">
                <option value="desc" <?php selected( $order, 'DESC' ); ?>><?php esc_html_e( 'DESC', 'factora' ) ?></option>
                <option value="asc" <?php selected( $order, 'ASC' ); ?>><?php esc_html_e( 'ASC', 'factora' ) ?></option>
            </select>
        </p>

        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'order_by' ) ); ?>"><?php esc_html_e( 'order By', 'factora' ); ?></label>
            <select class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'order_by' ) ); ?>"
                    name="<?php echo esc_attr( $this->get_field_name( 'order_by' ) ); ?>">
                <option value=" date" <?php selected( $orderby, 'date' ); ?>><?php esc_html_e( 'Date', 'factora' ) ?></option>
                <option value="id" <?php selected( $orderby, 'id' ); ?>><?php esc_html_e( 'ID', 'factora' ) ?></option>
                <option value="title" <?php selected( $orderby, 'title' ); ?>><?php esc_html_e( 'Name', 'factora' ) ?></option>
                <option value="count" <?php selected( $orderby, 'count' ); ?>><?php esc_html_e( 'Count', 'factora' ) ?></option>
            </select>
        </p>

        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>"><?php esc_html_e( 'Number', 'factora' ); ?></label>
            <input type="number" class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>"
                   name="<?php echo esc_attr( $this->get_field_name( 'number' ) ); ?>"
                   value="<?php echo esc_attr( $instance['number'] ); ?>"/>
        </p>

        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'type' ) ); ?>"><?php esc_html_e( 'Type', 'factora' ); ?></label>
            <select class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'type' ) ); ?>"
                    name="<?php echo esc_attr( $this->get_field_name( 'type' ) ); ?>">
                <option value="default" <?php selected( $type, 'default' ); ?>><?php esc_html_e( 'Default', 'factora' ) ?></option>
                <option value="icon" <?php selected( $type, 'icon' ); ?>><?php esc_html_e( 'Icon', 'factora' ) ?></option>
            </select>
        </p>
		<?php
	}
}
